package flink.zanxiangnet.ad.monitoring;

import com.google.common.util.concurrent.ThreadFactoryBuilder;
import flink.zanxiangnet.ad.monitoring.stream.BatchStream;
import flink.zanxiangnet.ad.monitoring.stream.KeyedBatchStream;
import flink.zanxiangnet.ad.monitoring.util.DateUtil;
import flink.zanxiangnet.ad.monitoring.util.JsonUtil;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.apache.flink.api.common.eventtime.SerializableTimestampAssigner;
import org.apache.flink.api.common.eventtime.WatermarkStrategy;
import org.apache.flink.api.common.state.MapState;
import org.apache.flink.api.common.state.MapStateDescriptor;
import org.apache.flink.api.common.typeinfo.Types;
import org.apache.flink.api.java.functions.KeySelector;
import org.apache.flink.api.java.tuple.Tuple2;
import org.apache.flink.api.java.tuple.Tuple3;
import org.apache.flink.configuration.Configuration;
import org.apache.flink.streaming.api.datastream.DataStreamSource;
import org.apache.flink.streaming.api.datastream.SingleOutputStreamOperator;
import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
import org.apache.flink.streaming.api.functions.source.RichSourceFunction;
import org.apache.flink.streaming.api.functions.windowing.ProcessWindowFunction;
import org.apache.flink.streaming.api.windowing.windows.GlobalWindow;
import org.apache.flink.table.planner.expressions.In;
import org.apache.flink.util.Collector;

import java.time.Duration;
import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.LinkedBlockingQueue;
import java.util.concurrent.ThreadPoolExecutor;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.atomic.AtomicLong;
import java.util.stream.Collectors;

public class Test {
    public static void main(String[] args) throws Exception {
        StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();

        env.setParallelism(1);

        DataStreamSource<Pojo> source = env.addSource(new PojoSource());
        // 打水印，延迟 2秒，同时指定时间流
        SingleOutputStreamOperator<Pojo> pojoStream = source.assignTimestampsAndWatermarks(WatermarkStrategy.<Pojo>forBoundedOutOfOrderness(Duration.ofHours(2))
                .withTimestampAssigner((SerializableTimestampAssigner<Pojo>) (pojo, l) -> pojo.getCreateTime())
        );
        /*pojoStream.keyBy(Pojo::getUserId)
                .window(TumblingEventTimeWindows.of(Time.days(1L), Time.hours(-8)))
                .aggregate(new AggregateFunction<Pojo, Tuple5<Integer, Long, Long, Integer, List<Long>>, String>() {

                    @Override
                    public Tuple5<Integer, Long, Long, Integer, List<Long>> createAccumulator() {
                        return new Tuple5<>(0, Long.MAX_VALUE, 0L, 0, new ArrayList<>());
                    }

                    @Override
                    public Tuple5<Integer, Long, Long, Integer, List<Long>> add(Pojo pojo, Tuple5<Integer, Long, Long, Integer, List<Long>> tuple5) {
                        tuple5.f4.add(pojo.getIndex());
                        return new Tuple5<>(pojo.getUserId(), Math.min(pojo.getCreateTime(), tuple5.f1), Math.max(pojo.getCreateTime(), tuple5.f2), tuple5.f3 + 1, tuple5.f4);
                    }

                    @Override
                    public String getResult(Tuple5<Integer, Long, Long, Integer, List<Long>> tuple5) {
                        return tuple5.f0 + "-" + DateUtil.formatLocalDateTime(DateUtil.milliToLocalDateTime(tuple5.f1)) + " : " + DateUtil.formatLocalDateTime(DateUtil.milliToLocalDateTime(tuple5.f2)) + " : " + tuple5.f3 + " : " + tuple5.f4;
                    }

                    @Override
                    public Tuple5<Integer, Long, Long, Integer, List<Long>> merge(Tuple5<Integer, Long, Long, Integer, List<Long>> tuple5, Tuple5<Integer, Long, Long, Integer, List<Long>> acc) {
                        List<Long> temp = new ArrayList<>(tuple5.f4);
                        temp.addAll(acc.f4);
                        return new Tuple5<>(tuple5.f0, Math.min(acc.f1, tuple5.f1), Math.max(acc.f2, tuple5.f2), tuple5.f3 + acc.f3, temp);
                    }
                }).print();*/
        SingleOutputStreamOperator<String> ff = pojoStream.keyBy(Pojo::getUserId).countWindow(1)
                .process(new ProcessWindowFunction<Pojo, String, Integer, GlobalWindow>() {
                    private final Map<Integer, Tuple3<LocalDateTime, LocalDateTime, List<Pojo>>> oldData = new ConcurrentHashMap<>();

                    private MapState<Integer, Tuple3<LocalDateTime, LocalDateTime, List<Pojo>>> mapState;
                    @Override
                    public void open(Configuration conf) {
                        mapState = getRuntimeContext().getMapState(new MapStateDescriptor<>("testState", Types.INT, Types.TUPLE(Types.LOCAL_DATE_TIME, Types.LOCAL_DATE_TIME, Types.LIST(Types.POJO(Pojo.class)))));
                    }

                    @Override
                    public void process(Integer integer, ProcessWindowFunction<Pojo, String, Integer, GlobalWindow>.Context context,
                                        Iterable<Pojo> elements, Collector<String> out) throws Exception {
                        Pojo pojo = elements.iterator().next();
                        LocalDateTime createTime = DateUtil.milliToLocalDateTime(pojo.getCreateTime());
                        // Tuple3<LocalDateTime, LocalDateTime, List<Pojo>> temp = oldData.get(pojo.getUserId());
                        Tuple3<LocalDateTime, LocalDateTime, List<Pojo>> temp = mapState.get(pojo.getUserId());
                        System.out.println(mapState.get(1));
                        System.out.println(mapState.get(2));
                        if (temp == null || createTime.getDayOfYear() != temp.f1.getDayOfYear()) {
                            temp = new Tuple3<>(createTime, createTime, new ArrayList<>(200));
                        }
                        temp.f2.add(pojo);
                        temp.setField(createTime, 1);
                        mapState.put(pojo.getUserId(), temp);
                        out.collect(JsonUtil.toString(temp.f2.stream().map(Pojo::getIndex).collect(Collectors.toList())));
                    }
                });
        new BatchStream<>("ff", ff, 10L, 60 * 1000L).toBatch().print();
        // new BatchSink<>(ff, 60 * 1000L, 10L).toBatch().print();
/*        .apply(new WindowFunction<Pojo, String, Integer, GlobalWindow>() {
            private Tuple3<LocalDateTime, LocalDateTime, List<Pojo>> oldData = null;
            @Override
            public void apply(Integer integer, GlobalWindow window, Iterable<Pojo> input, Collector<String> out) throws Exception {
                Pojo pojo = null;
                for(Pojo obj : input) {
                    pojo = obj;
                }
                LocalDateTime createTime = DateUtil.milliToLocalDateTime(pojo.getCreateTime());
                if (oldData == null || createTime.getDayOfYear() != oldData.f1.getDayOfYear()) {
                    oldData = new Tuple3<>(createTime, createTime, new ArrayList<>(200));
                }
                oldData.f2.add(pojo);
                oldData.setField(createTime, 1);
                out.collect(JsonUtil.toString(oldData.f2.stream().map(Pojo::getIndex).collect(Collectors.toList())));
            }
        })*/

        env.execute();
    }

    /**
     * 模拟从 2021-01-01开始，每小时打一次卡
     */
    public static class PojoSource extends RichSourceFunction<Pojo> {
        // 2021-01-01 00:00:00
        private static final long BEGIN = 1609430400000L;

        // 对象锁，防止MaxCompute的 Tunnel对象多次初始化
        private static final Object DUMMY_LOCK = new Object();

        private static AtomicLong index1;
        private static AtomicLong index2;
        private boolean isRun = false;
        private static ThreadPoolExecutor threadPool;

        @Override
        public void open(Configuration configuration) {
            isRun = true;
            if (index1 == null) {
                synchronized (DUMMY_LOCK) {
                    if (index1 == null) {
                        index1 = new AtomicLong(12);
                        index2 = new AtomicLong(0);
                        threadPool = new ThreadPoolExecutor(
                                60,
                                60,
                                0L,
                                TimeUnit.MILLISECONDS,
                                new LinkedBlockingQueue<>(),
                                new ThreadFactoryBuilder()
                                        .setNameFormat("maxcompute-writer-%d").build());
                    }
                }
            }
        }

        @Override
        public void run(SourceContext<Pojo> sourceContext) {
            while (isRun) {
                try {
                    long user1 = index1.incrementAndGet();
                    Pojo pojo = Pojo.builder()
                            .userId(1)
                            .index(user1)
                            .createTime(BEGIN + ((user1 - 1) * 60 * 60 * 1000))
                            .build();
                    if (user1 % 24 == 0) {
                        // 模拟数据延迟，每天 24点的数据延迟 25秒
                        threadPool.execute(() -> {
                            try {
                                Thread.sleep(25);
                            } catch (InterruptedException e) {
                                e.printStackTrace();
                            }
                            System.out.println("延迟1发送： " + pojo);
                            sourceContext.collect(pojo);
                        });
                    } else {
                        System.out.println("1发送： " + pojo);
                        sourceContext.collect(pojo);
                    }
                    long user2 = index2.incrementAndGet();
                    Pojo pojo2 = Pojo.builder()
                            .userId(2)
                            .index(user2)
                            .createTime(BEGIN + ((user2 - 1) * 60 * 60 * 1000))
                            .build();
                    if (user2 % 24 == 0) {
                        // 模拟数据延迟，每天 24点的数据延迟 25秒
                        threadPool.execute(() -> {
                            try {
                                Thread.sleep(25);
                            } catch (InterruptedException e) {
                                e.printStackTrace();
                            }
                            System.out.println("延迟2发送： " + pojo2);
                            sourceContext.collect(pojo2);
                        });
                    } else {
                        System.out.println("2发送： " + pojo2);
                        sourceContext.collect(pojo2);
                    }
                    Thread.sleep(1000);
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        }

        @Override
        public void cancel() {
            isRun = false;
        }
    }

    @Data
    @NoArgsConstructor
    @AllArgsConstructor
    @Builder
    public static class Pojo {
        private int userId;
        private long index;
        private long createTime;

        @Override
        public String toString() {
            return "{\"userId\":" + userId + ",\"index\":" + index + ",\"createTime\":" + DateUtil.formatLocalDateTime(DateUtil.milliToLocalDateTime(createTime)) + "}";
        }
    }
}
