package flink.zanxiangnet.ad.monitoring.kafka;

import org.apache.flink.api.common.serialization.SimpleStringSchema;
import org.apache.flink.connector.kafka.source.KafkaSource;
import org.apache.flink.connector.kafka.source.enumerator.initializer.OffsetsInitializer;
import org.apache.kafka.clients.CommonClientConfigs;
import org.apache.kafka.clients.consumer.OffsetResetStrategy;
import org.apache.kafka.common.config.SaslConfigs;
import org.apache.kafka.common.config.SslConfigs;

import java.util.Properties;

public class KafkaComponent {
    public static class KafkaTopic {
        public static final String adHourTopic = "ad_cost_topic";
        public static final String adDayTopic = "ad_day_cost_topic";

        public static class KafkaGroupId {
            public static final String adHourConsumerGroup = "ad_hour_consumer_group";
            public static final String adDayConsumerGroup = "ad_day_consumer_group";

            public static final String planHourConsumerGroup = "plan_hour_consumer_group";
            public static final String planDayConsumerGroup = "plan_day_consumer_group";
        }
    }

    public static KafkaSource<String> buildKafkaSource(Properties props, String topic, String groupId) {
        String connModule = props.getProperty(KafkaProperties.KAFKA_MODULE);
        Properties kafkaProps = new Properties();
        if (connModule.equals(KafkaProperties.KAFKA_MODULE_SASL_SSL)) {
            System.setProperty("javax.net.ssl.trustStore", props.getProperty(KafkaProperties.KAFKA_SSL_PATH));
            System.setProperty("javax.net.ssl.trustStorePassword", "KafkaOnsClient");

            kafkaProps.put(SaslConfigs.SASL_JAAS_CONFIG, "org.apache.kafka.common.security.plain.PlainLoginModule required username=\""
                    + props.getProperty(KafkaProperties.KAFKA_USERNAME)
                    + "\" password=\"" + props.getProperty(KafkaProperties.KAFKA_PASSWORD) + "\";");
            kafkaProps.put(SslConfigs.SSL_TRUSTSTORE_LOCATION_CONFIG, props.getProperty(KafkaProperties.KAFKA_SSL_PATH));
            kafkaProps.put(SslConfigs.SSL_TRUSTSTORE_PASSWORD_CONFIG, "KafkaOnsClient");
            kafkaProps.put(CommonClientConfigs.SECURITY_PROTOCOL_CONFIG, "SASL_SSL");
            kafkaProps.put(SaslConfigs.SASL_MECHANISM, "PLAIN");
            kafkaProps.put(SslConfigs.SSL_ENDPOINT_IDENTIFICATION_ALGORITHM_CONFIG, "");
        }
        return KafkaSource.<String>builder()
                .setBootstrapServers(props.getProperty(KafkaProperties.KAFKA_SERVERS))
                .setTopics(topic)
                .setGroupId(groupId)
                .setProperties(kafkaProps)
                .setStartingOffsets(OffsetsInitializer.committedOffsets(OffsetResetStrategy.EARLIEST))
                .setValueOnlyDeserializer(new SimpleStringSchema())
                .build();
    }
}
