package flink.zanxiangnet.ad.monitoring.maxcompute.bean;

import lombok.Getter;

import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.LocalDateTime;

@Getter
public enum DataTypeEnum {
    /**
     * 8位有符号整型。
     * 取值范围：-128~127。
     */
    TINYINT(Byte.class),
    /**
     * 16位有符号整型。
     * 取值范围：-32768~32767。
     */
    SMALLINT(Integer.class),
    /**
     * 32位有符号整型。
     * 取值范围：-2 31~2 31-1。
     */
    INT(Integer.class),
    /**
     * 64位有符号整型。
     * 取值范围：-2 63+1~2 63 -1。
     */
    BIGINT(Long.class),
    /**
     * 二进制数据类型，目前长度限制为8MB。
     */
    // BINARY(Byte[].class),
    /**
     * 32位二进制浮点型。
     */
    FLOAT(Double.class),
    /**
     * 64位二进制浮点型。
     */
    DOUBLE(Double.class),
    /**
     * DECIMAL(precision,scale) 10进制精确数字类型。
     * precision：表示最多可以表示多少位的数字。取值范围：1 <= precision <= 38。
     * scale：表示小数部分的位数。取值范围：0 <= scale <= 38。
     * 如果不指定以上两个参数，则默认为decimal(10,0)。
     */
    DECIMAL(BigDecimal.class),
    /**
     * 变长字符类型，n为长度。
     * 取值范围：1~65535。
     */
    VARCHAR(String.class),
    /**
     * 固定长度字符类型，n为长度。最大取值255。长度不足则会填充空格，但空格不参与比较。
     */
    CHAR(String.class),
    /**
     * 字符串类型，长度限制为8 MB。
     */
    STRING(String.class),
    /**
     * 日期类型，格式为yyyy-mm-dd。
     * 取值范围：0000-01-01~9999-12-31。
     */
    DATE(LocalDate.class),
    /**
     * 日期类型，格式为yyyy-mm-dd。
     * 取值范围：0000-01-01~9999-12-31。
     */
    DATETIME(LocalDateTime.class),
    /**
     * 与时区无关的时间戳类型。
     * 取值范围：0000-01-01 00:00:00.000000000~9999-12-31 23.59:59.999999999，精确到纳秒。
     */
    TIMESTAMP(LocalDateTime.class),
    /**
     * 与时区无关的时间戳类型。
     * 取值范围：0000-01-01 00:00:00.000000000~9999-12-31 23.59:59.999999999，精确到纳秒。
     */
    BOOLEAN(Boolean.class);

    private final Class<?> defaultJavaType;

    DataTypeEnum(Class<?> javaType) {
        this.defaultJavaType = javaType;
    }
}
