package flink.zanxiangnet.ad.monitoring.maxcompute.sink;

import com.aliyun.odps.Odps;
import com.aliyun.odps.PartitionSpec;
import com.aliyun.odps.account.Account;
import com.aliyun.odps.account.AliyunAccount;
import com.aliyun.odps.data.Record;
import com.aliyun.odps.tunnel.TableTunnel;
import com.aliyun.odps.tunnel.TunnelException;
import flink.zanxiangnet.ad.monitoring.maxcompute.MaxComputeLog;
import flink.zanxiangnet.ad.monitoring.maxcompute.bean.BeanUtil;
import flink.zanxiangnet.ad.monitoring.maxcompute.bean.annotation.MaxComputeTable;
import flink.zanxiangnet.ad.monitoring.pojo.properties.ApplicationProperties;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.apache.flink.configuration.Configuration;
import org.apache.flink.streaming.api.functions.sink.RichSinkFunction;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.util.CollectionUtils;

import java.io.IOException;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import java.util.stream.Collectors;

/**
 * 该类有严重 bug，请勿使用
 *
 * @param <IN>
 */
@Deprecated
public class TunnelStreamSink<IN> extends RichSinkFunction<IN> {
    private static final Logger log = LoggerFactory.getLogger(TunnelStreamSink.class);

    // 没有分区表的 key
    private static final String DEFAULT_PART = "DEFAULT_PART";
    // uploadSession的生命周期（2小时）
    private static final Long SESSION_TIMEOUT = 2 * 60 * 60 * 1000L;

    // 对象锁，防止MaxCompute的 Tunnel对象多次初始化
    private static final Object DUMMY_LOCK = new Object();

    private final Class<IN> clazz;
    private String projectName;
    private String tableName;

    // 缓存刷新的间隔时间
    private final Long bufferRefreshTime;
    // 缓存的最大数据量
    private final Long maxBufferCount;
    // 可能同时存在的分区数
    private final Integer partitionCount;

    private volatile transient TableTunnel tunnel;
    private volatile transient List<BeanUtil.FieldInfo> fieldInfoList;
    private volatile transient Map<String, Method> partitionFieldMethods;

    private volatile transient ConcurrentHashMap<String, UploadPartition> partitionUploadInfo;

    private transient Thread coreThread;
    private volatile boolean isRun = false;

    public TunnelStreamSink(Class<IN> clazz, Long bufferRefreshTime, Long maxBufferCount, Integer partitionCount) {
        this.clazz = clazz;
        this.bufferRefreshTime = Math.max(bufferRefreshTime, 60 * 1000);
        this.maxBufferCount = Math.max(maxBufferCount, 1000);
        this.partitionCount = Math.max(partitionCount, 1);
    }

    @Override
    public void open(Configuration config) {
        if (tunnel == null) {
            synchronized (DUMMY_LOCK) {
                if (tunnel == null) {
                    long start = System.currentTimeMillis();
                    Map<String, String> params = getRuntimeContext()
                            .getExecutionConfig()
                            .getGlobalJobParameters()
                            .toMap();
                    MaxComputeTable tableAnnotation = clazz.getAnnotation(MaxComputeTable.class);

                    Account account = new AliyunAccount(params.get(ApplicationProperties.MAX_COMPUTE_ACCOUNT_ID),
                            params.get(ApplicationProperties.MAX_COMPUTE_ACCOUNT_KEY));
                    Odps odps = new Odps(account);
                    odps.getRestClient().setRetryLogger(new MaxComputeLog());
                    odps.setEndpoint(params.get(ApplicationProperties.MAX_COMPUTE_ACCOUNT_ENDPOINT));
                    odps.setDefaultProject(params.get(ApplicationProperties.MAX_COMPUTE_ACCOUNT_PROJECT_NAME));
                    tunnel = new TableTunnel(odps);
                    tunnel.setEndpoint(params.get(ApplicationProperties.MAX_COMPUTE_ACCOUNT_TUNNEL_ENDPOINT));
                    projectName = params.get(ApplicationProperties.MAX_COMPUTE_ACCOUNT_PROJECT_NAME);
                    tableName = tableAnnotation.value();
                    fieldInfoList = BeanUtil.parseBeanField(clazz);
                    partitionFieldMethods = fieldInfoList.stream().filter(BeanUtil.FieldInfo::isUsePartitioned).collect(Collectors.toMap(BeanUtil.FieldInfo::getColumnName, BeanUtil.FieldInfo::getGetMethod));
                    partitionUploadInfo = new ConcurrentHashMap<>(partitionCount);
                    // Table table = odps.tables().get(tableAnnotation.value());
                    initThread();
                }
            }
        }
    }

    /**
     * 定时清理刷新缓存中的数据
     */
    private void initThread() {
        // 定时清理数据
        coreThread = new Thread(() -> {
            while (isRun) {
                try {
                    if (partitionUploadInfo != null && !partitionUploadInfo.isEmpty()) {
                        long now = System.currentTimeMillis();
                        for (Map.Entry<String, UploadPartition> entry : partitionUploadInfo.entrySet()) {
                            if (now - entry.getValue().getLastFlushTime() >= bufferRefreshTime) {
                                synchronized (DUMMY_LOCK) {
                                    if (now - entry.getValue().getLastFlushTime() >= bufferRefreshTime) {
                                        if (entry.getValue().getPack().getRecordCount() > 0) {
                                            int retry = 0;
                                            do {
                                                try {
                                                    // 大概用时 100ms ~ 3s
                                                    entry.getValue().getPack().flush();
                                                    break;
                                                } catch (IOException e) {
                                                    // flush失败，老的 pack就不可用了
                                                    entry.getValue().setPack(entry.getValue().getUploadSession().newRecordPack());
                                                    if (retry == 3) {
                                                        log.error("Flush data error！");
                                                        throw e;
                                                    }
                                                }
                                            } while (retry++ < 3);
                                        }
                                        entry.getValue().setLastFlushTime(now);
                                    }
                                }
                            }
                        }
                    }
                    try {
                        // 等 6s
                        Thread.sleep(6000);
                    } catch (InterruptedException e) {
                        // 等 6s
                        Thread.sleep(6000);
                    }
                } catch (Exception e) {
                    log.error(e.getMessage(), e);
                }
            }
        });
        isRun = true;
        coreThread.start();
    }

    /**
     * 将值写入到 Sink。每个值都会调用此函数
     *
     * @param value
     * @param context
     */
    @Override
    public void invoke(IN value, Context context) throws TunnelException, IOException, InvocationTargetException, IllegalAccessException {
        String partitionStr = generatePartitionStr(value);
        UploadPartition uploadPartition = partitionUploadInfo.get(partitionStr);
        if (uploadPartition == null || sessionTimeout(uploadPartition)) {
            synchronized (DUMMY_LOCK) {
                uploadPartition = partitionUploadInfo.get(partitionStr);
                if (uploadPartition == null || sessionTimeout(uploadPartition)) {
                    long start = System.currentTimeMillis();
                    PartitionSpec partitionSpec = partitionStr.equals(DEFAULT_PART) ? null : new PartitionSpec(partitionStr);
                    uploadPartition = UploadPartition.builder()
                            .partition(partitionStr)
                            .uploadSession(tunnel.createStreamUploadSession(projectName, tableName, partitionSpec, true))
                            .partitionSpec(partitionSpec)
                            .createTime(System.currentTimeMillis())
                            .build();
                    uploadPartition.setPack(uploadPartition.getUploadSession().newRecordPack());
                    partitionUploadInfo.put(partitionStr, uploadPartition);
                }
            }
        }
        Record record = uploadPartition.getUploadSession().newRecord();
        for (BeanUtil.FieldInfo fieldInfo : fieldInfoList) {
            if (fieldInfo.isUsePartitioned()) {
                // 分区字段不在这里设值
                continue;
            }
            Object obj = fieldInfo.getGetMethod().invoke(value);
            record.set(fieldInfo.getColumnName(), obj);
        }
        // append只是写入内存
        uploadPartition.getPack().append(record);

        flush(uploadPartition);
    }

    @Override
    public void close() throws Exception {
        isRun = false;
        coreThread.interrupt();
        super.close();
    }

    private void flush(UploadPartition uploadPartition) throws IOException {
        if (uploadPartition.getPack().getDataSize() >= maxBufferCount) {
            synchronized (DUMMY_LOCK) {
                if (uploadPartition.getPack().getDataSize() >= maxBufferCount) {
                    int retry = 0;
                    do {
                        try {
                            // 大概用时 100ms ~ 3s
                            uploadPartition.getPack().flush();
                            uploadPartition.setLastFlushTime(System.currentTimeMillis());
                            break;
                        } catch (IOException e) {
                            // flush失败，老的 pack就不可用了
                            uploadPartition.setPack(uploadPartition.getUploadSession().newRecordPack());
                            if (retry == 3) {
                                log.error("Flush data error！");
                                throw e;
                            }
                        }
                    } while (retry++ < 3);
                }
            }
        }
    }

    private boolean sessionTimeout(UploadPartition uploadPartition) {
        return System.currentTimeMillis() - uploadPartition.getCreateTime() > SESSION_TIMEOUT;
    }

    private String generatePartitionStr(IN t) {
        if (CollectionUtils.isEmpty(partitionFieldMethods)) {
            return DEFAULT_PART;
        }
        StringBuilder partition = new StringBuilder();
        for (Map.Entry<String, Method> entry : partitionFieldMethods.entrySet()) {
            partition.append(entry.getKey()).append("=");
            try {
                partition.append(entry.getValue().invoke(t));
            } catch (InvocationTargetException | IllegalAccessException e) {
                // 获取分区字段的值失败
                log.error(e.getMessage(), e);
                throw new RuntimeException("Failed get partition field value!");
            }
            partition.append(",");
        }
        partition = new StringBuilder(partition.substring(0, partition.length() - 1));
        return partition.toString();
    }

    @Data
    @NoArgsConstructor
    @AllArgsConstructor
    @Builder
    private static class UploadPartition {
        private String partition;
        private Long createTime;
        private PartitionSpec partitionSpec;
        private TableTunnel.StreamUploadSession uploadSession;
        private TableTunnel.StreamRecordPack pack;
        private long lastFlushTime = System.currentTimeMillis();
    }
}
