package flink.zanxiangnet.ad.monitoring.pojo.entity;

import com.google.gson.annotations.SerializedName;
import flink.zanxiangnet.ad.monitoring.maxcompute.bean.annotation.MaxComputeColumn;
import flink.zanxiangnet.ad.monitoring.maxcompute.bean.annotation.MaxComputeTable;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * 原始数据
 * 每 5分钟拉取的广告原始数据
 */
@Data
@MaxComputeTable("ad_data_of_hour_ods")
public class AdDataOfHourODS implements Serializable {
    private static final long serialVersionUID = 1L;

    /**
     * 统计日期（用于 MaxCompute分区）
     */
    @MaxComputeColumn(isPartitioned = true)
    @SerializedName("stat_day")
    private String statDay;

    /**
     * 统计的小时
     */
    @SerializedName("hour")
    private Integer hour;

    /**
     * 统计发起时间（分、秒、毫秒应该都是 0）
     */
    @SerializedName("stat_time")
    private Long statTime;

    /**
     * 应用下的账号 id
     */
    @SerializedName("account_id")
    private Long accountId;

    /**
     * 计划 id
     */
    @SerializedName("campaign_id")
    private Long campaignId;

    /**
     * 服务商账号 id
     */
    @SerializedName("agency_account_id")
    private Long agencyAccountId;

    /**
     * 微信账号id
     */
    @SerializedName("wechat_account_id")
    private String wechatAccountId;

    /**
     * 微信服务商id
     */
    @SerializedName("wechat_agency_id")
    private String wechatAgencyId;

    /**
     * 广告组 id
     */
    @SerializedName("adgroup_id")
    private Long adgroupId;

    /**
     * 广告 id
     */
    @SerializedName("ad_id")
    private Long adId;

    /**
     * 数据创建时间
     */
    @SerializedName("create_time")
    private Date createTime;

    /**
     * 当日成本偏差。反映广告今日的实际成本与目标成本直接的差异，注：该项成本相关数据按小时更新，与实时更新的「转化目标成本」数据存在出入属于正常情况。
     */
    @SerializedName("cost_deviation_rate")
    private Double costDeviationRate;

    /**
     * 消耗
     */
    @SerializedName("cost")
    private Long cost;

    /**
     * 赔付金额。智能优化成本保障政策下，广告超成本时的赔付金额。
     */
    @SerializedName("compensation_amount")
    private Long compensationAmount;

    /**
     * 曝光次数。用户观看广告的次数。
     */
    @SerializedName("view_count")
    private Long viewCount;

    /**
     * 千次曝光成本。平均每千次曝光的花费。
     */
    @SerializedName("thousand_display_price")
    private Long thousandDisplayPrice;

    /**
     * 人均曝光次数。每个用户观看广告的平均次数。
     */
    @SerializedName("avg_view_per_user")
    private Double avgViewPerUser;

    /**
     * 点击次数。用户在广告外层进行点击操作的次数。包括点击图片/视频，及朋友圈广告“文字链、头像、昵称、门店、选择按钮”等所有广告外层区域的点击。
     */
    @SerializedName("valid_click_count")
    private Long validClickCount;

    /**
     * 点击率。看到广告后执行点击操作的百分比。计算逻辑：广告点击次数/广告曝光次数。
     */
    @SerializedName("ctr")
    private Double ctr;

    /**
     * 点击均价。一次广告点击的平均花费。计算逻辑：广告花费/广告点击次数。
     */
    @SerializedName("cpc")
    private Long cpc;

    /**
     * 可转化点击次数。朋友圈：可转化点击是指可能产生转化的外层点击次数。对于“公众号推广”的广告，包括外层的公众号头像、公众号昵称、详情页查看、原生推广页查看； 对于其他类型的广告，包括外层的详情页查看和原生推广页查看。公众号：可转化点击是指可能产生转化的点击次数。
     */
    @SerializedName("valuable_click_count")
    private Long valuableClickCount;

    /**
     * 可转化点击率。用户看到广告后执行可转化点击操作的百分比。计算逻辑：广告可转化点击次数/广告曝光次数。
     */
    @SerializedName("valuable_click_rate")
    private Double valuableClickRate;

    /**
     * 可转化点击成本。一次可转化点击的平均花费。计算逻辑：广告花费/可转化点击次数。
     */
    @SerializedName("valuable_click_cost")
    private Long valuableClickCost;

    /**
     * 转化目标量。「转化目标」的具体数量，代表该广告的转化效果量级。
     */
    @SerializedName("conversions_count")
    private Long conversionsCount;

    /**
     * 转化目标成本。广告产生一次转化目标的平均费用。计算逻辑：广告花费/转化目标量。
     */
    @SerializedName("conversions_cost")
    private Long conversionsCost;

    /**
     * 目标转化率。朋友圈：转化目标量/可转化点击次数。公众号：转化目标量/点击次数。
     */
    @SerializedName("conversions_rate")
    private Double conversionsRate;

    /**
     * 深度转化目标量-灰度中。根据您选择的深度智能优化目标，该广告对应的具体数量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_count")
    private Long deepConversionsCount;

    /**
     * 深度转化目标成本-灰度中。根据您选择的深度智能优化目标，该广告产生一次转化的平均费用。计算逻辑：广告花费/深度转化目标量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_cost")
    private Long deepConversionsCost;

    /**
     * 深度目标转化率-灰度中。朋友圈：深度转化目标量/可转化点击次数。公众号：深度转化目标量/点击次数。指标随深度转化功能灰度中。接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_rate")
    private Double deepConversionsRate;

    /**
     * 下单量。用户通过该广告进行商品成交（如下单提交、在线支付）的次数。接入转化跟踪后可统计。
     */
    @SerializedName("order_count")
    private Long orderCount;

    /**
     * 首日新增下单量。广告推广获取的用户，点击广告当日，带来的下单次数。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_count")
    private Long firstDayOrderCount;

    /**
     * 下单成本（次数）。产生一次下单的成本。
     */
    @SerializedName("web_order_cost")
    private Long webOrderCost;

    /**
     * 下单率。一次点击到下单的转化率。
     */
    @SerializedName("order_rate")
    private Double orderRate;

    /**
     * 下单金额。广告带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("order_amount")
    private Long orderAmount;

    /**
     * 首日新增下单金额。广告推广获取的用户，点击广告当日，带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_amount")
    private Long firstDayOrderAmount;

    /**
     * 下单客单价。下单金额/下单量。接入转化跟踪后可统计。
     */
    @SerializedName("order_unit_price")
    private Long orderUnitPrice;

    /**
     * 下单ROI。下单金额/广告花费。接入转化跟踪后可统计。
     */
    @SerializedName("order_roi")
    private Double orderRoi;

    /**
     * 签收次数。签收从广告主处购买的商品的次数。接入转化跟踪后可统计。
     */
    @SerializedName("sign_in_count")
    private Long signInCount;

    /**
     * 加企业微信客服人数。添加企业微信好友成功的独立用户数。
     */
    @SerializedName("scan_follow_count")
    private Long scanFollowCount;

    /**
     * 小游戏注册人数。通过广告首次登录小游戏的独立用户数。
     */
    @SerializedName("wechat_app_register_uv")
    private Long wechatAppRegisterUv;

    /**
     * 小游戏注册成本（人数）。产生一个小游戏注册人数的成本。
     */
    @SerializedName("wechat_minigame_register_cost")
    private Long wechatMinigameRegisterCost;

    /**
     * 小游戏注册率。一次点击到小游戏注册的转化率。
     */
    @SerializedName("wechat_minigame_register_rate")
    private Double wechatMinigameRegisterRate;

    /**
     * 首日新增广告ARPU。广告带来的注册用户，在注册当日，产生的平均广告变现收入。注：该指标天更新，可以查看昨天及以前的数据。
     */
    @SerializedName("wechat_minigame_arpu")
    private Double wechatMinigameArpu;

    /**
     * 小游戏次留人数。通过广告首次登录小游戏，并在第二天再次登录的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_retention_count")
    private Long wechatMinigameRetentionCount;

    /**
     * 小游戏付费次数。通过广告进入小游戏并完成付费的次数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_count")
    private Long wechatMinigameCheckoutCount;

    /**
     * 小游戏付费金额。通过广告进入小游戏并完成付费的金额。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_amount")
    private Long wechatMinigameCheckoutAmount;

    /**
     * 公众号关注次数。用户通过广告关注公众号成功的次数。
     */
    @SerializedName("official_account_follow_count")
    private Long officialAccountFollowCount;

    /**
     * 公众号关注成本（次数）。产生一次公众号关注的成本。
     */
    @SerializedName("official_account_follow_cost")
    private Long officialAccountFollowCost;

    /**
     * 公众号关注率。一次点击到公众号关注的转化率。
     */
    @SerializedName("official_account_follow_rate")
    private Double officialAccountFollowRate;

    /**
     * 公众号内注册人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的注册行为的人数（UV）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_user_count")
    private Long officialAccountRegisterUserCount;

    /**
     * 公众号内注册比例。公众号内注册独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_rate")
    private Double officialAccountRegisterRate;

    /**
     * 公众号内注册成本。广告花费/广告产生的注册行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_cost")
    private Long officialAccountRegisterCost;

    /**
     * 公众号内注册订单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的订单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_amount")
    private Long officialAccountRegisterAmount;

    /**
     * 公众号内注册ROI。注册产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_roi")
    private Long officialAccountRegisterRoi;

    /**
     * 公众号内填单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_count")
    private Long officialAccountApplyCount;

    /**
     * 公众号内填单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_user_count")
    private Long officialAccountApplyUserCount;

    /**
     * 公众号内填单比例。公众号内填单的独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_rate")
    private Double officialAccountApplyRate;

    /**
     * 公众号内填单成本。广告花费/广告产生的填单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_cost")
    private Long officialAccountApplyCost;

    /**
     * 公众号内填单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_amount")
    private Long officialAccountApplyAmount;

    /**
     * 公众号内填单ROI。填单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_roi")
    private Long officialAccountApplyRoi;

    /**
     * 公众号内下单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_count")
    private Long officialAccountOrderCount;

    /**
     * 首日公众号内下单次数。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为数量。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_count")
    private Long officialAccountFirstDayOrderCount;

    /**
     * 公众号内下单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_user_count")
    private Long officialAccountOrderUserCount;

    /**
     * 公众号内下单比例。公众号内下单独立用户数（UV）/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_rate")
    private Double officialAccountOrderRate;

    /**
     * 公众号内下单成本。广告花费/广告产生的下单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_cost")
    private Long officialAccountOrderCost;

    /**
     * 公众号内下单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_amount")
    private Long officialAccountOrderAmount;

    /**
     * 首日公众号内下单金额。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_amount")
    private Long officialAccountFirstDayOrderAmount;

    /**
     * 公众号内下单ROI。下单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_roi")
    private Long officialAccountOrderRoi;

    /**
     * 公众号内发消息人数。用户关注公众号后，在公众号对话框内发送消息的独立用户数。
     */
    @SerializedName("official_account_consult_count")
    private Long officialAccountConsultCount;

    /**
     * 阅读粉丝量。近3日新增的粉丝中产生阅读行为的用户数。
     */
    @SerializedName("official_account_reader_count")
    private Long officialAccountReaderCount;

    /**
     * 公众号内进件人数。在公众号内完整提交贷款申请资料的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_apply_user_count")
    private Long officialAccountCreditApplyUserCount;

    /**
     * 公众号内授信人数。在公众号内完整提交贷款申请资料，并通过放款方的资质审核的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_user_count")
    private Long officialAccountCreditUserCount;

    /**
     * 广告分享次数。用户将广告落地页分享给好友和朋友圈的次数。
     */
    @SerializedName("forward_count")
    private Long forwardCount;

    /**
     * 广告分享人数。将广告落地页分享给好友和朋友圈的独立用户数。
     */
    @SerializedName("forward_user_count")
    private Long forwardUserCount;

    /**
     * 不感兴趣点击次数。用户点击“不感兴趣”的次数。
     */
    @SerializedName("no_interest_count")
    private Long noInterestCount;
}
