package flink.zanxiangnet.ad.monitoring.pojo.entity;

import com.aliyun.odps.data.Record;
import com.google.gson.annotations.SerializedName;
import flink.zanxiangnet.ad.monitoring.maxcompute.bean.annotation.MaxComputeColumn;
import flink.zanxiangnet.ad.monitoring.maxcompute.bean.annotation.MaxComputeTable;
import flink.zanxiangnet.ad.monitoring.util.ObjectUtil;
import flink.zanxiangnet.ad.monitoring.util.PlanUtil;
import lombok.Data;
import org.springframework.beans.BeanUtils;

import java.io.Serializable;
import java.util.*;

@Data
@MaxComputeTable("plan_stat_of_day_dwd")
public class PlanStatOfDayDWD implements Serializable {
    private static final long serialVersionUID = 1L;

    /**
     * 统计日 yyyy-MM-dd（用于 MaxCompute分区）
     */
    @MaxComputeColumn(isPartitioned = true)
    @SerializedName("stat_day")
    private String statDay;

    /**
     * 应用下的账号 id
     */
    @SerializedName("account_id")
    private Long accountId;

    /**
     * 计划 id
     */
    @SerializedName("campaign_id")
    private Long campaignId;

    /**
     * 服务商账号 id
     */
    @SerializedName("agency_account_id")
    private Long agencyAccountId;

    /**
     * 微信账号id
     */
    @SerializedName("wechat_account_id")
    private String wechatAccountId;

    /**
     * 微信服务商id
     */
    @SerializedName("wechat_agency_id")
    private String wechatAgencyId;

    /**
     * 广告组与广告的映射关系
     */
    @MaxComputeColumn(ignore = true)
    @SerializedName("ad_group_map")
    private Map<Long, Set<Long>> adGroupMap;

    /**
     * 广告组与广告的映射关系
     */
    @SerializedName("ad_group_map_str")
    private String adGroupMapStr;

    /**
     * 广告 id列表
     */
    @MaxComputeColumn(ignore = true)
    @SerializedName("ad_ids")
    private Set<Long> adIds;

    /**
     * 广告 id列表
     */
    @SerializedName("ad_ids_str")
    private String adIdsStr;

    /**
     * 记录创建时间
     */
    @SerializedName("create_time")
    private Date createTime;

    /**
     * 当日成本偏差。反映广告今日的实际成本与目标成本直接的差异，注：该项成本相关数据按小时更新，与实时更新的「转化目标成本」数据存在出入属于正常情况。
     */
    @SerializedName("cost_deviation_rate_total")
    private Double costDeviationRateTotal;

    /**
     * 当日成本偏差。反映广告今日的实际成本与目标成本直接的差异，注：该项成本相关数据按小时更新，与实时更新的「转化目标成本」数据存在出入属于正常情况。
     */
    @SerializedName("cost_deviation_rate_day")
    private Double costDeviationRateDay;

    /**
     * 消耗
     */
    @SerializedName("cost_total")
    private Long costTotal;

    /**
     * 消耗
     */
    @SerializedName("cost_day")
    private Long costDay;

    /**
     * 赔付金额。智能优化成本保障政策下，广告超成本时的赔付金额。
     */
    @SerializedName("compensation_amount_total")
    private Long compensationAmountTotal;

    /**
     * 赔付金额。智能优化成本保障政策下，广告超成本时的赔付金额。
     */
    @SerializedName("compensation_amount_day")
    private Long compensationAmountDay;

    /**
     * 曝光次数。用户观看广告的次数。
     */
    @SerializedName("view_count_total")
    private Long viewCountTotal;

    /**
     * 曝光次数。用户观看广告的次数。
     */
    @SerializedName("view_count_day")
    private Long viewCountDay;

    /**
     * 千次曝光成本。平均每千次曝光的花费。
     */
    @SerializedName("thousand_display_price_all")
    private Long thousandDisplayPriceAll;

    /**
     * 千次曝光成本。平均每千次曝光的花费。
     */
    @SerializedName("thousand_display_price_day")
    private Long thousandDisplayPriceDay;

    /**
     * 曝光人数。观看广告的独立用户数。
     */
    @SerializedName("view_user_count_total")
    private Long viewUserCountTotal;

    /**
     * 曝光人数。观看广告的独立用户数。
     */
    @SerializedName("view_user_count_day")
    private Long viewUserCountDay;

    /**
     * 人均曝光次数。每个用户观看广告的平均次数。
     */
    @SerializedName("avg_view_per_user_all")
    private Double avgViewPerUserAll;

    /**
     * 人均曝光次数。每个用户观看广告的平均次数。
     */
    @SerializedName("avg_view_per_user_day")
    private Double avgViewPerUserDay;

    /**
     * 点击次数。用户在广告外层进行点击操作的次数。包括点击图片/视频，及朋友圈广告“文字链、头像、昵称、门店、选择按钮”等所有广告外层区域的点击。
     */
    @SerializedName("valid_click_count_total")
    private Long validClickCountTotal;

    /**
     * 点击次数。用户在广告外层进行点击操作的次数。包括点击图片/视频，及朋友圈广告“文字链、头像、昵称、门店、选择按钮”等所有广告外层区域的点击。
     */
    @SerializedName("valid_click_count_day")
    private Long validClickCountDay;

    /**
     * 点击人数。在广告外层进行点击操作的独立用户数。
     */
    @SerializedName("click_user_count_total")
    private Long clickUserCountTotal;

    /**
     * 点击人数。在广告外层进行点击操作的独立用户数。
     */
    @SerializedName("click_user_count_day")
    private Long clickUserCountDay;

    /**
     * 点击率。看到广告后执行点击操作的百分比。计算逻辑：广告点击次数/广告曝光次数。
     */
    @SerializedName("ctr_all")
    private Double ctrAll;

    /**
     * 点击率。看到广告后执行点击操作的百分比。计算逻辑：广告点击次数/广告曝光次数。
     */
    @SerializedName("ctr_day")
    private Double ctrDay;

    /**
     * 点击均价。一次广告点击的平均花费。计算逻辑：广告花费/广告点击次数。
     */
    @SerializedName("cpc_all")
    private Long cpcAll;

    /**
     * 点击均价。一次广告点击的平均花费。计算逻辑：广告花费/广告点击次数。
     */
    @SerializedName("cpc_day")
    private Long cpcDay;

    /**
     * 可转化点击次数。朋友圈：可转化点击是指可能产生转化的外层点击次数。对于“公众号推广”的广告，包括外层的公众号头像、公众号昵称、详情页查看、原生推广页查看； 对于其他类型的广告，包括外层的详情页查看和原生推广页查看。公众号：可转化点击是指可能产生转化的点击次数。
     */
    @SerializedName("valuable_click_count_total")
    private Long valuableClickCountTotal;

    /**
     * 可转化点击次数。朋友圈：可转化点击是指可能产生转化的外层点击次数。对于“公众号推广”的广告，包括外层的公众号头像、公众号昵称、详情页查看、原生推广页查看； 对于其他类型的广告，包括外层的详情页查看和原生推广页查看。公众号：可转化点击是指可能产生转化的点击次数。
     */
    @SerializedName("valuable_click_count_day")
    private Long valuableClickCountDay;

    /**
     * 可转化点击率。用户看到广告后执行可转化点击操作的百分比。计算逻辑：广告可转化点击次数/广告曝光次数。
     */
    @SerializedName("valuable_click_rate_all")
    private Double valuableClickRateAll;

    /**
     * 可转化点击率。用户看到广告后执行可转化点击操作的百分比。计算逻辑：广告可转化点击次数/广告曝光次数。
     */
    @SerializedName("valuable_click_rate_day")
    private Double valuableClickRateDay;

    /**
     * 可转化点击成本。一次可转化点击的平均花费。计算逻辑：广告花费/可转化点击次数。
     */
    @SerializedName("valuable_click_cost_all")
    private Long valuableClickCostAll;

    /**
     * 可转化点击成本。一次可转化点击的平均花费。计算逻辑：广告花费/可转化点击次数。
     */
    @SerializedName("valuable_click_cost_day")
    private Long valuableClickCostDay;

    /**
     * 转化目标量。「转化目标」的具体数量，代表该广告的转化效果量级。
     */
    @SerializedName("conversions_count_total")
    private Long conversionsCountTotal;

    /**
     * 转化目标量。「转化目标」的具体数量，代表该广告的转化效果量级。
     */
    @SerializedName("conversions_count_day")
    private Long conversionsCountDay;

    /**
     * 转化目标成本。广告产生一次转化目标的平均费用。计算逻辑：广告花费/转化目标量。
     */
    @SerializedName("conversions_cost_all")
    private Long conversionsCostAll;

    /**
     * 转化目标成本。广告产生一次转化目标的平均费用。计算逻辑：广告花费/转化目标量。
     */
    @SerializedName("conversions_cost_day")
    private Long conversionsCostDay;

    /**
     * 目标转化率。朋友圈：转化目标量/可转化点击次数。公众号：转化目标量/点击次数。
     */
    @SerializedName("conversions_rate_all")
    private Double conversionsRateAll;

    /**
     * 目标转化率。朋友圈：转化目标量/可转化点击次数。公众号：转化目标量/点击次数。
     */
    @SerializedName("conversions_rate_day")
    private Double conversionsRateDay;

    /**
     * 深度转化目标量-灰度中。根据您选择的深度智能优化目标，该广告对应的具体数量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_count_total")
    private Long deepConversionsCountTotal;

    /**
     * 深度转化目标量-灰度中。根据您选择的深度智能优化目标，该广告对应的具体数量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_count_day")
    private Long deepConversionsCountDay;

    /**
     * 深度转化目标成本-灰度中。根据您选择的深度智能优化目标，该广告产生一次转化的平均费用。计算逻辑：广告花费/深度转化目标量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_cost_all")
    private Long deepConversionsCostAll;

    /**
     * 深度转化目标成本-灰度中。根据您选择的深度智能优化目标，该广告产生一次转化的平均费用。计算逻辑：广告花费/深度转化目标量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_cost_day")
    private Long deepConversionsCostDay;

    /**
     * 深度目标转化率-灰度中。朋友圈：深度转化目标量/可转化点击次数。公众号：深度转化目标量/点击次数。指标随深度转化功能灰度中。接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_rate_all")
    private Double deepConversionsRateAll;

    /**
     * 深度目标转化率-灰度中。朋友圈：深度转化目标量/可转化点击次数。公众号：深度转化目标量/点击次数。指标随深度转化功能灰度中。接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_rate_day")
    private Double deepConversionsRateDay;

    /**
     * 关键页面访问人数。点击广告原生落地页的APP跳转按钮，并到达APP内关键页面的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("key_page_uv_total")
    private Long keyPageUvTotal;

    /**
     * 关键页面访问人数。点击广告原生落地页的APP跳转按钮，并到达APP内关键页面的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("key_page_uv_day")
    private Long keyPageUvDay;

    /**
     * 下单量。用户通过该广告进行商品成交（如下单提交、在线支付）的次数。接入转化跟踪后可统计。
     */
    @SerializedName("order_count_total")
    private Long orderCountTotal;

    /**
     * 下单量。用户通过该广告进行商品成交（如下单提交、在线支付）的次数。接入转化跟踪后可统计。
     */
    @SerializedName("order_count_day")
    private Long orderCountDay;

    /**
     * 首日新增下单量。广告推广获取的用户，点击广告当日，带来的下单次数。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_count_total")
    private Long firstDayOrderCountTotal;

    /**
     * 首日新增下单量。广告推广获取的用户，点击广告当日，带来的下单次数。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_count_day")
    private Long firstDayOrderCountDay;

    /**
     * 下单成本（次数）。产生一次下单的成本。
     */
    @SerializedName("web_order_cost_all")
    private Long webOrderCostAll;

    /**
     * 下单成本（次数）。产生一次下单的成本。
     */
    @SerializedName("web_order_cost_day")
    private Long webOrderCostDay;

    /**
     * 下单率。一次点击到下单的转化率。
     */
    @SerializedName("order_rate_all")
    private Double orderRateAll;

    /**
     * 下单率。一次点击到下单的转化率。
     */
    @SerializedName("order_rate_day")
    private Double orderRateDay;

    /**
     * 下单金额。广告带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("order_amount_total")
    private Long orderAmountTotal;

    /**
     * 下单金额。广告带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("order_amount_day")
    private Long orderAmountDay;

    /**
     * 首日新增下单金额。广告推广获取的用户，点击广告当日，带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_amount_total")
    private Long firstDayOrderAmountTotal;

    /**
     * 首日新增下单金额。广告推广获取的用户，点击广告当日，带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_amount_day")
    private Long firstDayOrderAmountDay;

    /**
     * 下单客单价。下单金额/下单量。接入转化跟踪后可统计。
     */
    @SerializedName("order_unit_price_all")
    private Long orderUnitPriceAll;

    /**
     * 下单客单价。下单金额/下单量。接入转化跟踪后可统计。
     */
    @SerializedName("order_unit_price_day")
    private Long orderUnitPriceDay;

    /**
     * 下单ROI。下单金额/广告花费。接入转化跟踪后可统计。
     */
    @SerializedName("order_roi_all")
    private Double orderRoiAll;

    /**
     * 下单ROI。下单金额/广告花费。接入转化跟踪后可统计。
     */
    @SerializedName("order_roi_day")
    private Double orderRoiDay;

    /**
     * 签收次数。签收从广告主处购买的商品的次数。接入转化跟踪后可统计。
     */
    @SerializedName("sign_in_count_total")
    private Long signInCountTotal;

    /**
     * 签收次数。签收从广告主处购买的商品的次数。接入转化跟踪后可统计。
     */
    @SerializedName("sign_in_count_day")
    private Long signInCountDay;

    /**
     * 加收藏次数。用户将广告主商品加入收藏的次数，接入转化跟踪后可统计。
     */
    @SerializedName("add_wishlist_count_total")
    private Long addWishlistCountTotal;

    /**
     * 加收藏次数。用户将广告主商品加入收藏的次数，接入转化跟踪后可统计。
     */
    @SerializedName("add_wishlist_count_day")
    private Long addWishlistCountDay;

    /**
     * 商品详情页浏览人数。浏览广告主商品详情页的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("view_commodity_page_uv_total")
    private Long viewCommodityPageUvTotal;

    /**
     * 商品详情页浏览人数。浏览广告主商品详情页的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("view_commodity_page_uv_day")
    private Long viewCommodityPageUvDay;

    /**
     * 销售线索次数。广告带来的用户销售线索数量。H5推广需接入转化跟踪后可统计。
     */
    @SerializedName("page_reservation_count_total")
    private Long pageReservationCountTotal;

    /**
     * 销售线索次数。广告带来的用户销售线索数量。H5推广需接入转化跟踪后可统计。
     */
    @SerializedName("page_reservation_count_day")
    private Long pageReservationCountDay;

    /**
     * 首次付费人数。广告带来的有付费行为的销售线索数量按用户去重，同一个用户多次提交仅计算一次（原付费销售线索人数）。H5推广需接入转化跟踪后可统计。
     */
    @SerializedName("leads_purchase_uv_total")
    private Long leadsPurchaseUvTotal;

    /**
     * 首次付费人数。广告带来的有付费行为的销售线索数量按用户去重，同一个用户多次提交仅计算一次（原付费销售线索人数）。H5推广需接入转化跟踪后可统计。
     */
    @SerializedName("leads_purchase_uv_day")
    private Long leadsPurchaseUvDay;

    /**
     * 首次付费成本（人数）。产生一个首次付费用户的成本（原付费销售线索成本）。H5推广需接入转化跟踪后可统计。
     */
    @SerializedName("leads_purchase_cost_all")
    private Long leadsPurchaseCostAll;

    /**
     * 首次付费成本（人数）。产生一个首次付费用户的成本（原付费销售线索成本）。H5推广需接入转化跟踪后可统计。
     */
    @SerializedName("leads_purchase_cost_day")
    private Long leadsPurchaseCostDay;

    /**
     * 首次付费转化率（人数）。一次点击到产生一个首次付费用户的转化率（原付费销售线索转化率）。H5推广需接入转化跟踪后可统计。
     */
    @SerializedName("leads_purchase_rate_all")
    private Double leadsPurchaseRateAll;

    /**
     * 首次付费转化率（人数）。一次点击到产生一个首次付费用户的转化率（原付费销售线索转化率）。H5推广需接入转化跟踪后可统计。
     */
    @SerializedName("leads_purchase_rate_day")
    private Double leadsPurchaseRateDay;

    /**
     * 加企业微信客服人数。添加企业微信好友成功的独立用户数。
     */
    @SerializedName("scan_follow_count_total")
    private Long scanFollowCountTotal;

    /**
     * 加企业微信客服人数。添加企业微信好友成功的独立用户数。
     */
    @SerializedName("scan_follow_count_day")
    private Long scanFollowCountDay;

    /**
     * 小游戏注册人数。通过广告首次登录小游戏的独立用户数。
     */
    @SerializedName("wechat_app_register_uv_total")
    private Long wechatAppRegisterUvTotal;

    /**
     * 小游戏注册人数。通过广告首次登录小游戏的独立用户数。
     */
    @SerializedName("wechat_app_register_uv_day")
    private Long wechatAppRegisterUvDay;

    /**
     * 小游戏注册成本（人数）。产生一个小游戏注册人数的成本。
     */
    @SerializedName("wechat_minigame_register_cost_all")
    private Long wechatMinigameRegisterCostAll;

    /**
     * 小游戏注册成本（人数）。产生一个小游戏注册人数的成本。
     */
    @SerializedName("wechat_minigame_register_cost_day")
    private Long wechatMinigameRegisterCostDay;

    /**
     * 小游戏注册率。一次点击到小游戏注册的转化率。
     */
    @SerializedName("wechat_minigame_register_rate_all")
    private Double wechatMinigameRegisterRateAll;

    /**
     * 小游戏注册率。一次点击到小游戏注册的转化率。
     */
    @SerializedName("wechat_minigame_register_rate_day")
    private Double wechatMinigameRegisterRateDay;

    /**
     * 首日新增广告ARPU。广告带来的注册用户，在注册当日，产生的平均广告变现收入。注：该指标天更新，可以查看昨天及以前的数据。
     */
    @SerializedName("wechat_minigame_arpu_all")
    private Double wechatMinigameArpuAll;

    /**
     * 首日新增广告ARPU。广告带来的注册用户，在注册当日，产生的平均广告变现收入。注：该指标天更新，可以查看昨天及以前的数据。
     */
    @SerializedName("wechat_minigame_arpu_day")
    private Double wechatMinigameArpuDay;

    /**
     * 小游戏次留人数。通过广告首次登录小游戏，并在第二天再次登录的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_retention_count_total")
    private Long wechatMinigameRetentionCountTotal;

    /**
     * 小游戏次留人数。通过广告首次登录小游戏，并在第二天再次登录的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_retention_count_day")
    private Long wechatMinigameRetentionCountDay;

    /**
     * 小游戏付费次数。通过广告进入小游戏并完成付费的次数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_count_total")
    private Long wechatMinigameCheckoutCountTotal;

    /**
     * 小游戏付费次数。通过广告进入小游戏并完成付费的次数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_count_day")
    private Long wechatMinigameCheckoutCountDay;

    /**
     * 小游戏付费金额。通过广告进入小游戏并完成付费的金额。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_amount_total")
    private Long wechatMinigameCheckoutAmountTotal;

    /**
     * 小游戏付费金额。通过广告进入小游戏并完成付费的金额。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_amount_day")
    private Long wechatMinigameCheckoutAmountDay;

    /**
     * 公众号关注次数。用户通过广告关注公众号成功的次数。
     */
    @SerializedName("official_account_follow_count_total")
    private Long officialAccountFollowCountTotal;

    /**
     * 公众号关注次数。用户通过广告关注公众号成功的次数。
     */
    @SerializedName("official_account_follow_count_day")
    private Long officialAccountFollowCountDay;

    /**
     * 公众号关注成本（次数）。产生一次公众号关注的成本。
     */
    @SerializedName("official_account_follow_cost_all")
    private Long officialAccountFollowCostAll;

    /**
     * 公众号关注成本（次数）。产生一次公众号关注的成本。
     */
    @SerializedName("official_account_follow_cost_day")
    private Long officialAccountFollowCostDay;

    /**
     * 公众号关注率。一次点击到公众号关注的转化率。
     */
    @SerializedName("official_account_follow_rate_all")
    private Double officialAccountFollowRateAll;

    /**
     * 公众号关注率。一次点击到公众号关注的转化率。
     */
    @SerializedName("official_account_follow_rate_day")
    private Double officialAccountFollowRateDay;

    /**
     * 公众号内注册人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的注册行为的人数（UV）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_user_count_total")
    private Long officialAccountRegisterUserCountTotal;

    /**
     * 公众号内注册人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的注册行为的人数（UV）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_user_count_day")
    private Long officialAccountRegisterUserCountDay;

    /**
     * 公众号内注册比例。公众号内注册独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_rate_all")
    private Double officialAccountRegisterRateAll;

    /**
     * 公众号内注册比例。公众号内注册独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_rate_day")
    private Double officialAccountRegisterRateDay;

    /**
     * 公众号内注册成本。广告花费/广告产生的注册行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_cost_all")
    private Long officialAccountRegisterCostAll;

    /**
     * 公众号内注册成本。广告花费/广告产生的注册行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_cost_day")
    private Long officialAccountRegisterCostDay;

    /**
     * 公众号内注册订单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的订单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_amount_total")
    private Long officialAccountRegisterAmountTotal;

    /**
     * 公众号内注册订单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的订单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_amount_day")
    private Long officialAccountRegisterAmountDay;

    /**
     * 公众号内注册ROI。注册产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_roi_all")
    private Long officialAccountRegisterRoiAll;

    /**
     * 公众号内注册ROI。注册产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_roi_day")
    private Long officialAccountRegisterRoiDay;

    /**
     * 公众号内填单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_count_total")
    private Long officialAccountApplyCountTotal;

    /**
     * 公众号内填单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_count_day")
    private Long officialAccountApplyCountDay;

    /**
     * 公众号内填单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_user_count_total")
    private Long officialAccountApplyUserCountTotal;

    /**
     * 公众号内填单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_user_count_day")
    private Long officialAccountApplyUserCountDay;

    /**
     * 公众号内填单比例。公众号内填单的独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_rate_all")
    private Double officialAccountApplyRateAll;

    /**
     * 公众号内填单比例。公众号内填单的独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_rate_day")
    private Double officialAccountApplyRateDay;

    /**
     * 公众号内填单成本。广告花费/广告产生的填单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_cost_all")
    private Long officialAccountApplyCostAll;

    /**
     * 公众号内填单成本。广告花费/广告产生的填单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_cost_day")
    private Long officialAccountApplyCostDay;

    /**
     * 公众号内填单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_amount_total")
    private Long officialAccountApplyAmountTotal;

    /**
     * 公众号内填单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_amount_day")
    private Long officialAccountApplyAmountDay;

    /**
     * 公众号内填单ROI。填单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_roi_all")
    private Long officialAccountApplyRoiAll;

    /**
     * 公众号内填单ROI。填单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_roi_day")
    private Long officialAccountApplyRoiDay;

    /**
     * 公众号内下单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_count_total")
    private Long officialAccountOrderCountTotal;

    /**
     * 公众号内下单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_count_day")
    private Long officialAccountOrderCountDay;

    /**
     * 首日公众号内下单次数。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为数量。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_count_total")
    private Long officialAccountFirstDayOrderCountTotal;

    /**
     * 首日公众号内下单次数。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为数量。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_count_day")
    private Long officialAccountFirstDayOrderCountDay;

    /**
     * 公众号内下单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_user_count_total")
    private Long officialAccountOrderUserCountTotal;

    /**
     * 公众号内下单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_user_count_day")
    private Long officialAccountOrderUserCountDay;

    /**
     * 公众号内下单比例。公众号内下单独立用户数（UV）/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_rate_all")
    private Double officialAccountOrderRateAll;

    /**
     * 公众号内下单比例。公众号内下单独立用户数（UV）/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_rate_day")
    private Double officialAccountOrderRateDay;

    /**
     * 公众号内下单成本。广告花费/广告产生的下单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_cost_all")
    private Long officialAccountOrderCostAll;

    /**
     * 公众号内下单成本。广告花费/广告产生的下单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_cost_day")
    private Long officialAccountOrderCostDay;

    /**
     * 公众号内下单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_amount_total")
    private Long officialAccountOrderAmountTotal;

    /**
     * 公众号内下单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_amount_day")
    private Long officialAccountOrderAmountDay;

    /**
     * 首日公众号内下单金额。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_amount_total")
    private Long officialAccountFirstDayOrderAmountTotal;

    /**
     * 首日公众号内下单金额。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_amount_day")
    private Long officialAccountFirstDayOrderAmountDay;

    /**
     * 公众号内下单ROI。下单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_roi_all")
    private Long officialAccountOrderRoiAll;

    /**
     * 公众号内下单ROI。下单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_roi_day")
    private Long officialAccountOrderRoiDay;

    /**
     * 公众号内发消息人数。用户关注公众号后，在公众号对话框内发送消息的独立用户数。
     */
    @SerializedName("official_account_consult_count_total")
    private Long officialAccountConsultCountTotal;

    /**
     * 公众号内发消息人数。用户关注公众号后，在公众号对话框内发送消息的独立用户数。
     */
    @SerializedName("official_account_consult_count_day")
    private Long officialAccountConsultCountDay;

    /**
     * 阅读粉丝量。近3日新增的粉丝中产生阅读行为的用户数。
     */
    @SerializedName("official_account_reader_count_total")
    private Long officialAccountReaderCountTotal;

    /**
     * 阅读粉丝量。近3日新增的粉丝中产生阅读行为的用户数。
     */
    @SerializedName("official_account_reader_count_day")
    private Long officialAccountReaderCountDay;

    /**
     * 公众号内进件人数。在公众号内完整提交贷款申请资料的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_apply_user_count_total")
    private Long officialAccountCreditApplyUserCountTotal;

    /**
     * 公众号内进件人数。在公众号内完整提交贷款申请资料的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_apply_user_count_day")
    private Long officialAccountCreditApplyUserCountDay;

    /**
     * 公众号内授信人数。在公众号内完整提交贷款申请资料，并通过放款方的资质审核的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_user_count_total")
    private Long officialAccountCreditUserCountTotal;

    /**
     * 公众号内授信人数。在公众号内完整提交贷款申请资料，并通过放款方的资质审核的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_user_count_day")
    private Long officialAccountCreditUserCountDay;

    /**
     * 广告分享次数。用户将广告落地页分享给好友和朋友圈的次数。
     */
    @SerializedName("forward_count_total")
    private Long forwardCountTotal;

    /**
     * 广告分享次数。用户将广告落地页分享给好友和朋友圈的次数。
     */
    @SerializedName("forward_count_day")
    private Long forwardCountDay;

    /**
     * 广告分享人数。将广告落地页分享给好友和朋友圈的独立用户数。
     */
    @SerializedName("forward_user_count_total")
    private Long forwardUserCountTotal;

    /**
     * 广告分享人数。将广告落地页分享给好友和朋友圈的独立用户数。
     */
    @SerializedName("forward_user_count_day")
    private Long forwardUserCountDay;

    /**
     * 不感兴趣点击次数。用户点击“不感兴趣”的次数。
     */
    @SerializedName("no_interest_count_total")
    private Long noInterestCountTotal;

    /**
     * 不感兴趣点击次数。用户点击“不感兴趣”的次数。
     */
    @SerializedName("no_interest_count_day")
    private Long noInterestCountDay;

    /**
     * 聚合
     *
     * @param value1     之前聚合的值（可能为 null）
     * @param value2     新值
     * @param createTime 聚合时间
     * @return
     */
    public static PlanStatOfDayDWD reduce(PlanStatOfDayDWD value1, AdDataOfDayODS value2, long createTime) {
        PlanStatOfDayDWD result = new PlanStatOfDayDWD();
        BeanUtils.copyProperties(value2, result);
        result.setCreateTime(new Date(createTime));
        if (value1 == null) {
            Map<Long, Set<Long>> adGroupMap = new HashMap<>();
            Set<Long> adIdsTemp = new HashSet<>(3);
            adIdsTemp.add(value2.getAdId());
            adGroupMap.put(value2.getAdgroupId(), adIdsTemp);
            result.setAdGroupMap(adGroupMap);
            result.setAdGroupMapStr(PlanUtil.adGroupMapStr(adGroupMap));

            Set<Long> adIds = new HashSet<>(3);
            adIds.add(value2.getAdId());
            result.setAdIds(adIds);
            result.setAdIdsStr(PlanUtil.adIdsStr(value2.getAdId()));

            result.setCostDeviationRateTotal(value2.getCostDeviationRate());
            result.setCostDeviationRateDay(value2.getCostDeviationRate());
            result.setCostTotal(value2.getCost());
            result.setCostDay(value2.getCost());
            result.setCompensationAmountTotal(value2.getCompensationAmount());
            result.setCompensationAmountDay(value2.getCompensationAmount());
            result.setViewCountTotal(value2.getViewCount());
            result.setViewCountDay(value2.getViewCount());
            result.setThousandDisplayPriceAll(value2.getThousandDisplayPrice());
            result.setThousandDisplayPriceDay(value2.getThousandDisplayPrice());
            result.setViewUserCountTotal(value2.getViewUserCount());
            result.setViewUserCountDay(value2.getViewUserCount());
            result.setAvgViewPerUserAll(value2.getAvgViewPerUser());
            result.setAvgViewPerUserDay(value2.getAvgViewPerUser());
            result.setValidClickCountTotal(value2.getValidClickCount());
            result.setValidClickCountDay(value2.getValidClickCount());
            result.setClickUserCountTotal(value2.getClickUserCount());
            result.setClickUserCountDay(value2.getClickUserCount());
            result.setCtrAll(value2.getCtr());
            result.setCtrDay(value2.getCtr());
            result.setCpcAll(value2.getCpc());
            result.setCpcDay(value2.getCpc());
            result.setValuableClickCountTotal(value2.getValuableClickCount());
            result.setValuableClickCountDay(value2.getValuableClickCount());
            result.setValuableClickRateAll(value2.getValuableClickRate());
            result.setValuableClickRateDay(value2.getValuableClickRate());
            result.setValuableClickCostAll(value2.getValuableClickCost());
            result.setValuableClickCostDay(value2.getValuableClickCost());
            result.setConversionsCountTotal(value2.getConversionsCount());
            result.setConversionsCountDay(value2.getConversionsCount());
            result.setConversionsCostAll(value2.getConversionsCost());
            result.setConversionsCostDay(value2.getConversionsCost());
            result.setConversionsRateAll(value2.getConversionsRate());
            result.setConversionsRateDay(value2.getConversionsRate());
            result.setDeepConversionsCountTotal(value2.getDeepConversionsCount());
            result.setDeepConversionsCountDay(value2.getDeepConversionsCount());
            result.setDeepConversionsCostAll(value2.getDeepConversionsCost());
            result.setDeepConversionsCostDay(value2.getDeepConversionsCost());
            result.setDeepConversionsRateAll(value2.getDeepConversionsRate());
            result.setDeepConversionsRateDay(value2.getDeepConversionsRate());
            result.setKeyPageUvTotal(value2.getKeyPageUv());
            result.setKeyPageUvDay(value2.getKeyPageUv());
            result.setOrderCountTotal(value2.getOrderCount());
            result.setOrderCountDay(value2.getOrderCount());
            result.setFirstDayOrderCountTotal(value2.getFirstDayOrderCount());
            result.setFirstDayOrderCountDay(value2.getFirstDayOrderCount());
            result.setWebOrderCostAll(value2.getWebOrderCost());
            result.setWebOrderCostDay(value2.getWebOrderCost());
            result.setOrderRateAll(value2.getOrderRate());
            result.setOrderRateDay(value2.getOrderRate());
            result.setOrderAmountTotal(value2.getOrderAmount());
            result.setOrderAmountDay(value2.getOrderAmount());
            result.setFirstDayOrderAmountTotal(value2.getFirstDayOrderAmount());
            result.setFirstDayOrderAmountDay(value2.getFirstDayOrderAmount());
            result.setOrderUnitPriceAll(value2.getOrderUnitPrice());
            result.setOrderUnitPriceDay(value2.getOrderUnitPrice());
            result.setOrderRoiAll(value2.getOrderRoi());
            result.setOrderRoiDay(value2.getOrderRoi());
            result.setSignInCountTotal(value2.getSignInCount());
            result.setSignInCountDay(value2.getSignInCount());
            result.setAddWishlistCountTotal(value2.getAddWishlistCount());
            result.setAddWishlistCountDay(value2.getAddWishlistCount());
            result.setViewCommodityPageUvTotal(value2.getViewCommodityPageUv());
            result.setViewCommodityPageUvDay(value2.getViewCommodityPageUv());
            result.setPageReservationCountTotal(value2.getPageReservationCount());
            result.setPageReservationCountDay(value2.getPageReservationCount());
            result.setLeadsPurchaseUvTotal(value2.getLeadsPurchaseUv());
            result.setLeadsPurchaseUvDay(value2.getLeadsPurchaseUv());
            result.setLeadsPurchaseCostAll(value2.getLeadsPurchaseCost());
            result.setLeadsPurchaseCostDay(value2.getLeadsPurchaseCost());
            result.setLeadsPurchaseRateAll(value2.getLeadsPurchaseRate());
            result.setLeadsPurchaseRateDay(value2.getLeadsPurchaseRate());
            result.setScanFollowCountTotal(value2.getScanFollowCount());
            result.setScanFollowCountDay(value2.getScanFollowCount());
            result.setWechatAppRegisterUvTotal(value2.getWechatAppRegisterUv());
            result.setWechatAppRegisterUvDay(value2.getWechatAppRegisterUv());
            result.setWechatMinigameRegisterCostAll(value2.getWechatMinigameRegisterCost());
            result.setWechatMinigameRegisterCostDay(value2.getWechatMinigameRegisterCost());
            result.setWechatMinigameRegisterRateAll(value2.getWechatMinigameRegisterRate());
            result.setWechatMinigameRegisterRateDay(value2.getWechatMinigameRegisterRate());
            result.setWechatMinigameArpuAll(value2.getWechatMinigameArpu());
            result.setWechatMinigameArpuDay(value2.getWechatMinigameArpu());
            result.setWechatMinigameRetentionCountTotal(value2.getWechatMinigameRetentionCount());
            result.setWechatMinigameRetentionCountDay(value2.getWechatMinigameRetentionCount());
            result.setWechatMinigameCheckoutCountTotal(value2.getWechatMinigameCheckoutCount());
            result.setWechatMinigameCheckoutCountDay(value2.getWechatMinigameCheckoutCount());
            result.setWechatMinigameCheckoutAmountTotal(value2.getWechatMinigameCheckoutAmount());
            result.setWechatMinigameCheckoutAmountDay(value2.getWechatMinigameCheckoutAmount());
            result.setOfficialAccountFollowCountTotal(value2.getOfficialAccountFollowCount());
            result.setOfficialAccountFollowCountDay(value2.getOfficialAccountFollowCount());
            result.setOfficialAccountFollowCostAll(value2.getOfficialAccountFollowCost());
            result.setOfficialAccountFollowCostDay(value2.getOfficialAccountFollowCost());
            result.setOfficialAccountFollowRateAll(value2.getOfficialAccountFollowRate());
            result.setOfficialAccountFollowRateDay(value2.getOfficialAccountFollowRate());
            result.setOfficialAccountRegisterUserCountTotal(value2.getOfficialAccountRegisterUserCount());
            result.setOfficialAccountRegisterUserCountDay(value2.getOfficialAccountRegisterUserCount());
            result.setOfficialAccountRegisterRateAll(value2.getOfficialAccountRegisterRate());
            result.setOfficialAccountRegisterRateDay(value2.getOfficialAccountRegisterRate());
            result.setOfficialAccountRegisterCostAll(value2.getOfficialAccountRegisterCost());
            result.setOfficialAccountRegisterCostDay(value2.getOfficialAccountRegisterCost());
            result.setOfficialAccountRegisterAmountTotal(value2.getOfficialAccountRegisterAmount());
            result.setOfficialAccountRegisterAmountDay(value2.getOfficialAccountRegisterAmount());
            result.setOfficialAccountRegisterRoiAll(value2.getOfficialAccountRegisterRoi());
            result.setOfficialAccountRegisterRoiDay(value2.getOfficialAccountRegisterRoi());
            result.setOfficialAccountApplyCountTotal(value2.getOfficialAccountApplyCount());
            result.setOfficialAccountApplyCountDay(value2.getOfficialAccountApplyCount());
            result.setOfficialAccountApplyUserCountTotal(value2.getOfficialAccountApplyUserCount());
            result.setOfficialAccountApplyUserCountDay(value2.getOfficialAccountApplyUserCount());
            result.setOfficialAccountApplyRateAll(value2.getOfficialAccountApplyRate());
            result.setOfficialAccountApplyRateDay(value2.getOfficialAccountApplyRate());
            result.setOfficialAccountApplyCostAll(value2.getOfficialAccountApplyCost());
            result.setOfficialAccountApplyCostDay(value2.getOfficialAccountApplyCost());
            result.setOfficialAccountApplyAmountTotal(value2.getOfficialAccountApplyAmount());
            result.setOfficialAccountApplyAmountDay(value2.getOfficialAccountApplyAmount());
            result.setOfficialAccountApplyRoiAll(value2.getOfficialAccountApplyRoi());
            result.setOfficialAccountApplyRoiDay(value2.getOfficialAccountApplyRoi());
            result.setOfficialAccountOrderCountTotal(value2.getOfficialAccountOrderCount());
            result.setOfficialAccountOrderCountDay(value2.getOfficialAccountOrderCount());
            result.setOfficialAccountFirstDayOrderCountTotal(value2.getOfficialAccountFirstDayOrderCount());
            result.setOfficialAccountFirstDayOrderCountDay(value2.getOfficialAccountFirstDayOrderCount());
            result.setOfficialAccountOrderUserCountTotal(value2.getOfficialAccountOrderUserCount());
            result.setOfficialAccountOrderUserCountDay(value2.getOfficialAccountOrderUserCount());
            result.setOfficialAccountOrderRateAll(value2.getOfficialAccountOrderRate());
            result.setOfficialAccountOrderRateDay(value2.getOfficialAccountOrderRate());
            result.setOfficialAccountOrderCostAll(value2.getOfficialAccountOrderCost());
            result.setOfficialAccountOrderCostDay(value2.getOfficialAccountOrderCost());
            result.setOfficialAccountOrderAmountTotal(value2.getOfficialAccountOrderAmount());
            result.setOfficialAccountOrderAmountDay(value2.getOfficialAccountOrderAmount());
            result.setOfficialAccountFirstDayOrderAmountTotal(value2.getOfficialAccountFirstDayOrderAmount());
            result.setOfficialAccountFirstDayOrderAmountDay(value2.getOfficialAccountFirstDayOrderAmount());
            result.setOfficialAccountOrderRoiAll(value2.getOfficialAccountOrderRoi());
            result.setOfficialAccountOrderRoiDay(value2.getOfficialAccountOrderRoi());
            result.setOfficialAccountConsultCountTotal(value2.getOfficialAccountConsultCount());
            result.setOfficialAccountConsultCountDay(value2.getOfficialAccountConsultCount());
            result.setOfficialAccountReaderCountTotal(value2.getOfficialAccountReaderCount());
            result.setOfficialAccountReaderCountDay(value2.getOfficialAccountReaderCount());
            result.setOfficialAccountCreditApplyUserCountTotal(value2.getOfficialAccountCreditApplyUserCount());
            result.setOfficialAccountCreditApplyUserCountDay(value2.getOfficialAccountCreditApplyUserCount());
            result.setOfficialAccountCreditUserCountTotal(value2.getOfficialAccountCreditUserCount());
            result.setOfficialAccountCreditUserCountDay(value2.getOfficialAccountCreditUserCount());
            result.setForwardCountTotal(value2.getForwardCount());
            result.setForwardCountDay(value2.getForwardCount());
            result.setForwardUserCountTotal(value2.getForwardUserCount());
            result.setForwardUserCountDay(value2.getForwardUserCount());
            result.setNoInterestCountTotal(value2.getNoInterestCount());
            result.setNoInterestCountDay(value2.getNoInterestCount());
        } else {
            value1.getAdGroupMap().computeIfAbsent(value2.getAdgroupId(), key -> new HashSet<>(3)).add(value2.getAdId());
            value1.setAdGroupMapStr(PlanUtil.adGroupMapStr(value1.getAdGroupMap()));
            value1.getAdIds().add(value2.getAdId());
            value1.setAdIdsStr(PlanUtil.adIdsStr(value1.getAdIds()));

            result.setCostDeviationRateTotal(value1.getCostDeviationRateTotal() + value2.getCostDeviationRate());
            result.setCostDeviationRateDay(value2.getCostDeviationRate());
            result.setCostTotal(value1.getCostTotal() + value2.getCost());
            result.setCostDay(value2.getCost());
            result.setCompensationAmountTotal(value1.getCompensationAmountTotal() + value2.getCompensationAmount());
            result.setCompensationAmountDay(value2.getCompensationAmount());
            result.setViewCountTotal(value1.getViewCountTotal() + value2.getViewCount());
            result.setViewCountDay(value2.getViewCount());
            // 总消耗 / 总曝光
            result.setThousandDisplayPriceAll(result.getViewCountTotal() == 0 ? 0 : (result.getCostTotal() / result.getViewCountTotal() * 1000));
            result.setThousandDisplayPriceDay(value2.getThousandDisplayPrice());

            // 应该不准，因为跨天的用户无法去重
            result.setViewUserCountTotal(value1.getViewUserCountTotal() + value2.getViewUserCount());
            result.setViewUserCountDay(value2.getViewUserCount());
            // 曝光次数 / 曝光人数（不准）
            result.setAvgViewPerUserAll(result.getViewUserCountTotal() == 0 ? 0.0 : result.getViewCountTotal() / result.getViewUserCountTotal());
            result.setAvgViewPerUserDay(value2.getAvgViewPerUser());
            result.setValidClickCountTotal(value1.getValidClickCountTotal() + value2.getValidClickCount());
            result.setValidClickCountDay(value2.getValidClickCount());

            // 应该不准，因为跨天的用户无法去重
            result.setClickUserCountTotal(value1.getClickUserCountTotal() + value2.getClickUserCount());
            result.setClickUserCountDay(value2.getClickUserCount());
            // 广告点击次数 / 广告曝光次数
            result.setCtrAll(result.getViewCountTotal() == 0 ? 0.0 : result.getValidClickCountTotal() / result.getViewCountTotal());
            result.setCtrDay(value2.getCtr());
            // 广告花费/广告点击次数
            result.setCpcAll(result.getValidClickCountTotal() == 0 ? 0 : result.getCostTotal() / result.getValidClickCountTotal());
            result.setCpcDay(value2.getCpc());
            result.setValuableClickCountTotal(value1.getValuableClickCountTotal() + value2.getValuableClickCount());
            result.setValuableClickCountDay(value2.getValuableClickCount());
            // 广告可转化点击次数/广告曝光次数
            result.setValuableClickRateAll(result.getViewCountTotal() == 0 ? 0.0 : result.getValuableClickCountTotal() / result.getViewCountTotal());
            result.setValuableClickRateDay(value2.getValuableClickRate());
            // 广告花费/可转化点击次数
            result.setValuableClickCostAll(result.getValuableClickCountTotal() == 0 ? 0 : result.getCostTotal() / result.getValuableClickCountTotal());
            result.setValuableClickCostDay(value2.getValuableClickCost());
            result.setConversionsCountTotal(value1.getConversionsCountTotal() + value2.getConversionsCount());
            result.setConversionsCountDay(value2.getConversionsCount());
            // 广告花费/转化目标量
            result.setConversionsCostAll(result.getConversionsCountTotal() == 0 ? 0 : result.getCostTotal() / result.getConversionsCountTotal());
            result.setConversionsCostDay(value2.getConversionsCost());
            // 公众号：转化目标量/点击次数。
            result.setConversionsRateAll(result.getValidClickCountTotal() == 0 ? 0.0 : result.getConversionsCountTotal() / result.getValidClickCountTotal());
            result.setConversionsRateDay(value2.getConversionsRate());
            result.setDeepConversionsCountTotal(value1.getDeepConversionsCountTotal() + value2.getDeepConversionsCount());
            result.setDeepConversionsCountDay(value2.getDeepConversionsCount());
            // 广告花费/深度转化目标量
            result.setDeepConversionsCostAll(result.getDeepConversionsCountTotal() == 0 ? 0 : result.getCostTotal() / result.getDeepConversionsCountTotal());
            result.setDeepConversionsCostDay(value2.getDeepConversionsCost());
            // 深度转化目标量/可转化点击次数
            result.setDeepConversionsRateAll(result.getValuableClickCountTotal() == 0 ? 0.0 : result.getDeepConversionsCountTotal() / result.getValuableClickCountTotal());
            result.setDeepConversionsRateDay(value2.getDeepConversionsRate());
            result.setKeyPageUvTotal(value1.getKeyPageUvTotal() + value2.getKeyPageUv());
            result.setKeyPageUvDay(value2.getKeyPageUv());
            result.setOrderCountTotal(value1.getOrderCountTotal() + value2.getOrderCount());
            result.setOrderCountDay(value2.getOrderCount());
            result.setFirstDayOrderCountTotal(value1.getFirstDayOrderCountTotal() + value2.getFirstDayOrderCount());
            result.setFirstDayOrderCountDay(value2.getFirstDayOrderCount());
            // 广告花费/下单量
            result.setWebOrderCostAll(result.getOrderCountTotal() == 0 ? 0 : result.getCostTotal() / result.getOrderCountTotal());
            result.setWebOrderCostDay(value2.getWebOrderCost());
            // 下单量/点击次数
            result.setOrderRateAll(result.getValidClickCountTotal() == 0 ? 0.0 : result.getOrderCountTotal() / result.getValidClickCountTotal());
            result.setOrderRateDay(value2.getOrderRate());
            result.setOrderAmountTotal(value1.getOrderAmountTotal() + value2.getOrderAmount());
            result.setOrderAmountDay(value2.getOrderAmount());
            result.setFirstDayOrderAmountTotal(value1.getFirstDayOrderAmountTotal() + value2.getFirstDayOrderAmount());
            result.setFirstDayOrderAmountDay(value2.getFirstDayOrderAmount());
            // 下单金额/下单量
            result.setOrderUnitPriceAll(result.getOrderCountTotal() == 0 ? 0 : result.getOrderAmountTotal() / result.getOrderCountTotal());
            result.setOrderUnitPriceDay(value2.getOrderUnitPrice());
            // 下单金额/广告花费
            result.setOrderRoiAll(result.getCostTotal() == 0 ? 0.0 : result.getOrderAmountTotal() / result.getCostTotal());
            result.setOrderRoiDay(value2.getOrderRoi());
            result.setSignInCountTotal(value1.getSignInCountTotal() + value2.getSignInCount());
            result.setSignInCountDay(value2.getSignInCount());
            result.setAddWishlistCountTotal(value1.getAddWishlistCountTotal() + value2.getAddWishlistCount());
            result.setAddWishlistCountDay(value2.getAddWishlistCount());
            result.setViewCommodityPageUvTotal(value1.getViewCommodityPageUvTotal() + value2.getViewCommodityPageUv());
            result.setViewCommodityPageUvDay(value2.getViewCommodityPageUv());
            result.setPageReservationCountTotal(value1.getPageReservationCountTotal() + value2.getPageReservationCount());
            result.setPageReservationCountDay(value2.getPageReservationCount());

            // 应该不准，因为跨天的用户无法去重
            result.setLeadsPurchaseUvTotal(value1.getLeadsPurchaseUvTotal() + value2.getLeadsPurchaseUv());
            result.setLeadsPurchaseUvDay(value2.getLeadsPurchaseUv());
            // 广告消耗/首次付费人数
            result.setLeadsPurchaseCostAll(result.getLeadsPurchaseUvTotal() == 0 ? 0 : result.getCostTotal() / result.getLeadsPurchaseUvTotal());
            result.setLeadsPurchaseCostDay(value2.getLeadsPurchaseCost());
            // 首次付费人数/广告点击次数
            result.setLeadsPurchaseRateAll(result.getValidClickCountTotal() == 0 ? 0.0 : result.getLeadsPurchaseUvTotal() / result.getValidClickCountTotal());
            result.setLeadsPurchaseRateDay(value2.getLeadsPurchaseRate());
            result.setScanFollowCountTotal(value1.getScanFollowCountTotal() + value2.getScanFollowCount());
            result.setScanFollowCountDay(value2.getScanFollowCount());
            result.setWechatAppRegisterUvTotal(value1.getWechatAppRegisterUvTotal() + value2.getWechatAppRegisterUv());
            result.setWechatAppRegisterUvDay(value2.getWechatAppRegisterUv());
            // 广告消耗 / 小游戏注册人数
            result.setWechatMinigameRegisterCostAll(result.getWechatAppRegisterUvTotal() == 0 ? 0 : result.getCostTotal() / result.getWechatAppRegisterUvTotal());
            result.setWechatMinigameRegisterCostDay(value2.getWechatMinigameRegisterCost());
            // 小游戏注册人数 / 广告点击次数
            result.setWechatMinigameRegisterRateAll(result.getValidClickCountTotal() == 0 ? 0.0 : result.getWechatAppRegisterUvTotal() / result.getValidClickCountTotal());
            result.setWechatMinigameRegisterRateDay(value2.getWechatMinigameRegisterRate());
            // 总收益 / 总人数
            result.setWechatMinigameArpuAll(result.getWechatAppRegisterUvTotal() == 0 ? 0.0 : result.getOrderAmountTotal() / result.getWechatAppRegisterUvTotal());
            result.setWechatMinigameArpuDay(value2.getWechatMinigameArpu());
            result.setWechatMinigameRetentionCountTotal(value1.getWechatMinigameRetentionCountTotal() + value2.getWechatMinigameRetentionCount());
            result.setWechatMinigameRetentionCountDay(value2.getWechatMinigameRetentionCount());
            result.setWechatMinigameCheckoutCountTotal(value1.getWechatMinigameCheckoutCountTotal() + value2.getWechatMinigameCheckoutCount());
            result.setWechatMinigameCheckoutCountDay(value2.getWechatMinigameCheckoutCount());
            result.setWechatMinigameCheckoutAmountTotal(value1.getWechatMinigameCheckoutAmountTotal() + value2.getWechatMinigameCheckoutAmount());
            result.setWechatMinigameCheckoutAmountDay(value2.getWechatMinigameCheckoutAmount());
            result.setOfficialAccountFollowCountTotal(value1.getOfficialAccountFollowCountTotal() + value2.getOfficialAccountFollowCount());
            result.setOfficialAccountFollowCountDay(value2.getOfficialAccountFollowCount());
            // 广告消耗 / 关注次数
            result.setOfficialAccountFollowCostAll(result.getOfficialAccountFollowCountTotal() == 0 ? 0 : result.getCostTotal() / result.getOfficialAccountFollowCountTotal());
            result.setOfficialAccountFollowCostDay(value2.getOfficialAccountFollowCost());
            // 关注次数 / 点击次数
            result.setOfficialAccountFollowRateAll(result.getValidClickCountTotal() == 0 ? 0.0 : result.getOfficialAccountFollowCountTotal() / result.getValidClickCountTotal());
            result.setOfficialAccountFollowRateDay(value2.getOfficialAccountFollowRate());
            result.setOfficialAccountRegisterUserCountTotal(value1.getOfficialAccountRegisterUserCountTotal() + value2.getOfficialAccountRegisterUserCount());
            result.setOfficialAccountRegisterUserCountDay(value2.getOfficialAccountRegisterUserCount());
            // 公众号内注册人数 / 公众号关注次数
            result.setOfficialAccountRegisterRateAll(result.getOfficialAccountFollowCountTotal() == 0 ? 0.0 : result.getOfficialAccountRegisterUserCountTotal() / result.getOfficialAccountFollowCountTotal());
            result.setOfficialAccountRegisterRateDay(value2.getOfficialAccountRegisterRate());
            // 广告消耗 / 广告注册人数
            result.setOfficialAccountRegisterCostAll(result.getOfficialAccountRegisterUserCountTotal() == 0 ? 0 : result.getCostTotal() / result.getOfficialAccountRegisterUserCountTotal());
            result.setOfficialAccountRegisterCostDay(value2.getOfficialAccountRegisterCost());
            result.setOfficialAccountRegisterAmountTotal(value1.getOfficialAccountRegisterAmountTotal() + value2.getOfficialAccountRegisterAmount());
            result.setOfficialAccountRegisterAmountDay(value2.getOfficialAccountRegisterAmount());
            // 注册产生的订单金额累计/广告花费
            result.setOfficialAccountRegisterRoiAll(result.getCostTotal() == 0 ? 0 : result.getOfficialAccountRegisterAmountTotal() / result.getCostTotal());
            result.setOfficialAccountRegisterRoiDay(value2.getOfficialAccountRegisterRoi());
            result.setOfficialAccountApplyCountTotal(value1.getOfficialAccountApplyCountTotal() + value2.getOfficialAccountApplyCount());
            result.setOfficialAccountApplyCountDay(value2.getOfficialAccountApplyCount());
            result.setOfficialAccountApplyUserCountTotal(value1.getOfficialAccountApplyUserCountTotal() + value2.getOfficialAccountApplyUserCount());
            result.setOfficialAccountApplyUserCountDay(value2.getOfficialAccountApplyUserCount());
            // 公众号内填单的独立用户数/公众号关注次数
            result.setOfficialAccountApplyRateAll(result.getOfficialAccountFollowCountTotal() == 0 ? 0.0 : result.getOfficialAccountApplyUserCountTotal() / result.getOfficialAccountFollowCountTotal());
            result.setOfficialAccountApplyRateDay(value2.getOfficialAccountApplyRate());
            // 广告花费/广告产生的填单行为数量
            result.setOfficialAccountApplyCostAll(result.getOfficialAccountApplyUserCountTotal() == 0 ? 0 : result.getCostTotal() / result.getOfficialAccountApplyUserCountTotal());
            result.setOfficialAccountApplyCostDay(value2.getOfficialAccountApplyCost());
            result.setOfficialAccountApplyAmountTotal(value1.getOfficialAccountApplyAmountTotal() + value2.getOfficialAccountApplyAmount());
            result.setOfficialAccountApplyAmountDay(value2.getOfficialAccountApplyAmount());
            // 填单产生的订单金额累计/广告花费
            result.setOfficialAccountApplyRoiAll(result.getCostTotal() == 0 ? 0 : result.getOfficialAccountApplyAmountTotal() / result.getCostTotal());
            result.setOfficialAccountApplyRoiDay(value2.getOfficialAccountApplyRoi());
            result.setOfficialAccountOrderCountTotal(value1.getOfficialAccountOrderCountTotal() + value2.getOfficialAccountOrderCount());
            result.setOfficialAccountOrderCountDay(value2.getOfficialAccountOrderCount());
            result.setOfficialAccountFirstDayOrderCountTotal(value1.getOfficialAccountFirstDayOrderCountTotal() + value2.getOfficialAccountFirstDayOrderCount());
            result.setOfficialAccountFirstDayOrderCountDay(value2.getOfficialAccountFirstDayOrderCount());
            result.setOfficialAccountOrderUserCountTotal(value1.getOfficialAccountOrderUserCountTotal() + value2.getOfficialAccountOrderUserCount());
            result.setOfficialAccountOrderUserCountDay(value2.getOfficialAccountOrderUserCount());
            // 公众号内下单独立用户数（UV）/公众号关注次数
            result.setOfficialAccountOrderRateAll(result.getOfficialAccountFollowCountTotal() == 0 ? 0.0 : result.getOfficialAccountOrderUserCountTotal() / result.getOfficialAccountFollowCountTotal());
            result.setOfficialAccountOrderRateDay(value2.getOfficialAccountOrderRate());
            // 广告花费/广告产生的下单行为数量
            result.setOfficialAccountOrderCostAll(result.getOfficialAccountOrderCountTotal() == 0 ? 0 : result.getCostTotal() / result.getOfficialAccountOrderCountTotal());
            result.setOfficialAccountOrderCostDay(value2.getOfficialAccountOrderCost());
            result.setOfficialAccountOrderAmountTotal(value1.getOfficialAccountOrderAmountTotal() + value2.getOfficialAccountOrderAmount());
            result.setOfficialAccountOrderAmountDay(value2.getOfficialAccountOrderAmount());
            result.setOfficialAccountFirstDayOrderAmountTotal(value1.getOfficialAccountFirstDayOrderAmountTotal() + value2.getOfficialAccountFirstDayOrderAmount());
            result.setOfficialAccountFirstDayOrderAmountDay(value2.getOfficialAccountFirstDayOrderAmount());
            // 下单产生的订单金额累计/广告花费
            result.setOfficialAccountOrderRoiAll(result.getCostTotal() == 0 ? 0 : result.getOfficialAccountOrderAmountTotal() / result.getCostTotal());
            result.setOfficialAccountOrderRoiDay(value2.getOfficialAccountOrderRoi());
            result.setOfficialAccountConsultCountTotal(value1.getOfficialAccountConsultCountTotal() + value2.getOfficialAccountConsultCount());
            result.setOfficialAccountConsultCountDay(value2.getOfficialAccountConsultCount());
            result.setOfficialAccountReaderCountTotal(value1.getOfficialAccountReaderCountTotal() + value2.getOfficialAccountReaderCount());
            result.setOfficialAccountReaderCountDay(value2.getOfficialAccountReaderCount());
            result.setOfficialAccountCreditApplyUserCountTotal(value1.getOfficialAccountCreditApplyUserCountTotal() + value2.getOfficialAccountCreditApplyUserCount());
            result.setOfficialAccountCreditApplyUserCountDay(value2.getOfficialAccountCreditApplyUserCount());
            result.setOfficialAccountCreditUserCountTotal(value1.getOfficialAccountCreditUserCountTotal() + value2.getOfficialAccountCreditUserCount());
            result.setOfficialAccountCreditUserCountDay(value2.getOfficialAccountCreditUserCount());
            result.setForwardCountTotal(value1.getForwardCountTotal() + value2.getForwardCount());
            result.setForwardCountDay(value2.getForwardCount());
            result.setForwardUserCountTotal(value1.getForwardUserCountTotal() + value2.getForwardUserCount());
            result.setForwardUserCountDay(value2.getForwardUserCount());
            result.setNoInterestCountTotal(value1.getNoInterestCountTotal() + value2.getNoInterestCount());
            result.setNoInterestCountDay(value2.getNoInterestCount());
        }
        return result;
    }

    public static PlanStatOfDayDWD byMaxCompute(Record record) {
        PlanStatOfDayDWD result = new PlanStatOfDayDWD();
        result.setStatDay(ObjectUtil.toString(record.get("stat_day")));
        result.setAccountId(ObjectUtil.toLong(record.get("account_id")));
        result.setCampaignId(ObjectUtil.toLong(record.get("campaign_id")));
        result.setAgencyAccountId(ObjectUtil.toLong(record.get("agency_account_id")));
        result.setWechatAccountId(ObjectUtil.toString(record.get("wechat_account_id")));
        result.setWechatAgencyId(ObjectUtil.toString(record.get("wechat_agency_id")));

        result.setAdGroupMapStr(ObjectUtil.toString(record.get("ad_group_map_str")));
        result.setAdGroupMap(PlanUtil.parseAdGroupMapStr(result.getAdGroupMapStr()));
        result.setAdIdsStr(ObjectUtil.toString(record.get("ad_ids_str")));
        result.setAdIds(PlanUtil.parseAdStr(result.getAdIdsStr()));

        result.setCreateTime(ObjectUtil.toDate(record.get("create_time")));
        result.setCostDeviationRateTotal(ObjectUtil.toDouble(record.get("cost_deviation_rate_total")));
        result.setCostDeviationRateDay(ObjectUtil.toDouble(record.get("cost_deviation_rate_day")));
        result.setCostTotal(ObjectUtil.toLong(record.get("cost_total")));
        result.setCostDay(ObjectUtil.toLong(record.get("cost_day")));
        result.setCompensationAmountTotal(ObjectUtil.toLong(record.get("compensation_amount_total")));
        result.setCompensationAmountDay(ObjectUtil.toLong(record.get("compensation_amount_day")));
        result.setViewCountTotal(ObjectUtil.toLong(record.get("view_count_total")));
        result.setViewCountDay(ObjectUtil.toLong(record.get("view_count_day")));
        result.setThousandDisplayPriceAll(ObjectUtil.toLong(record.get("thousand_display_price_all")));
        result.setThousandDisplayPriceDay(ObjectUtil.toLong(record.get("thousand_display_price_day")));
        result.setViewUserCountTotal(ObjectUtil.toLong(record.get("view_user_count_total")));
        result.setViewUserCountDay(ObjectUtil.toLong(record.get("view_user_count_day")));
        result.setAvgViewPerUserAll(ObjectUtil.toDouble(record.get("avg_view_per_user_all")));
        result.setAvgViewPerUserDay(ObjectUtil.toDouble(record.get("avg_view_per_user_day")));
        result.setValidClickCountTotal(ObjectUtil.toLong(record.get("valid_click_count_total")));
        result.setValidClickCountDay(ObjectUtil.toLong(record.get("valid_click_count_day")));
        result.setClickUserCountTotal(ObjectUtil.toLong(record.get("click_user_count_total")));
        result.setClickUserCountDay(ObjectUtil.toLong(record.get("click_user_count_day")));
        result.setCtrAll(ObjectUtil.toDouble(record.get("ctr_all")));
        result.setCtrDay(ObjectUtil.toDouble(record.get("ctr_day")));
        result.setCpcAll(ObjectUtil.toLong(record.get("cpc_all")));
        result.setCpcDay(ObjectUtil.toLong(record.get("cpc_day")));
        result.setValuableClickCountTotal(ObjectUtil.toLong(record.get("valuable_click_count_total")));
        result.setValuableClickCountDay(ObjectUtil.toLong(record.get("valuable_click_count_day")));
        result.setValuableClickRateAll(ObjectUtil.toDouble(record.get("valuable_click_rate_all")));
        result.setValuableClickRateDay(ObjectUtil.toDouble(record.get("valuable_click_rate_day")));
        result.setValuableClickCostAll(ObjectUtil.toLong(record.get("valuable_click_cost_all")));
        result.setValuableClickCostDay(ObjectUtil.toLong(record.get("valuable_click_cost_day")));
        result.setConversionsCountTotal(ObjectUtil.toLong(record.get("conversions_count_total")));
        result.setConversionsCountDay(ObjectUtil.toLong(record.get("conversions_count_day")));
        result.setConversionsCostAll(ObjectUtil.toLong(record.get("conversions_cost_all")));
        result.setConversionsCostDay(ObjectUtil.toLong(record.get("conversions_cost_day")));
        result.setConversionsRateAll(ObjectUtil.toDouble(record.get("conversions_rate_all")));
        result.setConversionsRateDay(ObjectUtil.toDouble(record.get("conversions_rate_day")));
        result.setDeepConversionsCountTotal(ObjectUtil.toLong(record.get("deep_conversions_count_total")));
        result.setDeepConversionsCountDay(ObjectUtil.toLong(record.get("deep_conversions_count_day")));
        result.setDeepConversionsCostAll(ObjectUtil.toLong(record.get("deep_conversions_cost_all")));
        result.setDeepConversionsCostDay(ObjectUtil.toLong(record.get("deep_conversions_cost_day")));
        result.setDeepConversionsRateAll(ObjectUtil.toDouble(record.get("deep_conversions_rate_all")));
        result.setDeepConversionsRateDay(ObjectUtil.toDouble(record.get("deep_conversions_rate_day")));
        result.setKeyPageUvTotal(ObjectUtil.toLong(record.get("key_page_uv_total")));
        result.setKeyPageUvDay(ObjectUtil.toLong(record.get("key_page_uv_day")));
        result.setOrderCountTotal(ObjectUtil.toLong(record.get("order_count_total")));
        result.setOrderCountDay(ObjectUtil.toLong(record.get("order_count_day")));
        result.setFirstDayOrderCountTotal(ObjectUtil.toLong(record.get("first_day_order_count_total")));
        result.setFirstDayOrderCountDay(ObjectUtil.toLong(record.get("first_day_order_count_day")));
        result.setWebOrderCostAll(ObjectUtil.toLong(record.get("web_order_cost_all")));
        result.setWebOrderCostDay(ObjectUtil.toLong(record.get("web_order_cost_day")));
        result.setOrderRateAll(ObjectUtil.toDouble(record.get("order_rate_all")));
        result.setOrderRateDay(ObjectUtil.toDouble(record.get("order_rate_day")));
        result.setOrderAmountTotal(ObjectUtil.toLong(record.get("order_amount_total")));
        result.setOrderAmountDay(ObjectUtil.toLong(record.get("order_amount_day")));
        result.setFirstDayOrderAmountTotal(ObjectUtil.toLong(record.get("first_day_order_amount_total")));
        result.setFirstDayOrderAmountDay(ObjectUtil.toLong(record.get("first_day_order_amount_day")));
        result.setOrderUnitPriceAll(ObjectUtil.toLong(record.get("order_unit_price_all")));
        result.setOrderUnitPriceDay(ObjectUtil.toLong(record.get("order_unit_price_day")));
        result.setOrderRoiAll(ObjectUtil.toDouble(record.get("order_roi_all")));
        result.setOrderRoiDay(ObjectUtil.toDouble(record.get("order_roi_day")));
        result.setSignInCountTotal(ObjectUtil.toLong(record.get("sign_in_count_total")));
        result.setSignInCountDay(ObjectUtil.toLong(record.get("sign_in_count_day")));
        result.setAddWishlistCountTotal(ObjectUtil.toLong(record.get("add_wishlist_count_total")));
        result.setAddWishlistCountDay(ObjectUtil.toLong(record.get("add_wishlist_count_day")));
        result.setViewCommodityPageUvTotal(ObjectUtil.toLong(record.get("view_commodity_page_uv_total")));
        result.setViewCommodityPageUvDay(ObjectUtil.toLong(record.get("view_commodity_page_uv_day")));
        result.setPageReservationCountTotal(ObjectUtil.toLong(record.get("page_reservation_count_total")));
        result.setPageReservationCountDay(ObjectUtil.toLong(record.get("page_reservation_count_day")));
        result.setLeadsPurchaseUvTotal(ObjectUtil.toLong(record.get("leads_purchase_uv_total")));
        result.setLeadsPurchaseUvDay(ObjectUtil.toLong(record.get("leads_purchase_uv_day")));
        result.setLeadsPurchaseCostAll(ObjectUtil.toLong(record.get("leads_purchase_cost_all")));
        result.setLeadsPurchaseCostDay(ObjectUtil.toLong(record.get("leads_purchase_cost_day")));
        result.setLeadsPurchaseRateAll(ObjectUtil.toDouble(record.get("leads_purchase_rate_all")));
        result.setLeadsPurchaseRateDay(ObjectUtil.toDouble(record.get("leads_purchase_rate_day")));
        result.setScanFollowCountTotal(ObjectUtil.toLong(record.get("scan_follow_count_total")));
        result.setScanFollowCountDay(ObjectUtil.toLong(record.get("scan_follow_count_day")));
        result.setWechatAppRegisterUvTotal(ObjectUtil.toLong(record.get("wechat_app_register_uv_total")));
        result.setWechatAppRegisterUvDay(ObjectUtil.toLong(record.get("wechat_app_register_uv_day")));
        result.setWechatMinigameRegisterCostAll(ObjectUtil.toLong(record.get("wechat_minigame_register_cost_all")));
        result.setWechatMinigameRegisterCostDay(ObjectUtil.toLong(record.get("wechat_minigame_register_cost_day")));
        result.setWechatMinigameRegisterRateAll(ObjectUtil.toDouble(record.get("wechat_minigame_register_rate_all")));
        result.setWechatMinigameRegisterRateDay(ObjectUtil.toDouble(record.get("wechat_minigame_register_rate_day")));
        result.setWechatMinigameArpuAll(ObjectUtil.toDouble(record.get("wechat_minigame_arpu_all")));
        result.setWechatMinigameArpuDay(ObjectUtil.toDouble(record.get("wechat_minigame_arpu_day")));
        result.setWechatMinigameRetentionCountTotal(ObjectUtil.toLong(record.get("wechat_minigame_retention_count_total")));
        result.setWechatMinigameRetentionCountDay(ObjectUtil.toLong(record.get("wechat_minigame_retention_count_day")));
        result.setWechatMinigameCheckoutCountTotal(ObjectUtil.toLong(record.get("wechat_minigame_checkout_count_total")));
        result.setWechatMinigameCheckoutCountDay(ObjectUtil.toLong(record.get("wechat_minigame_checkout_count_day")));
        result.setWechatMinigameCheckoutAmountTotal(ObjectUtil.toLong(record.get("wechat_minigame_checkout_amount_total")));
        result.setWechatMinigameCheckoutAmountDay(ObjectUtil.toLong(record.get("wechat_minigame_checkout_amount_day")));
        result.setOfficialAccountFollowCountTotal(ObjectUtil.toLong(record.get("official_account_follow_count_total")));
        result.setOfficialAccountFollowCountDay(ObjectUtil.toLong(record.get("official_account_follow_count_day")));
        result.setOfficialAccountFollowCostAll(ObjectUtil.toLong(record.get("official_account_follow_cost_all")));
        result.setOfficialAccountFollowCostDay(ObjectUtil.toLong(record.get("official_account_follow_cost_day")));
        result.setOfficialAccountFollowRateAll(ObjectUtil.toDouble(record.get("official_account_follow_rate_all")));
        result.setOfficialAccountFollowRateDay(ObjectUtil.toDouble(record.get("official_account_follow_rate_day")));
        result.setOfficialAccountRegisterUserCountTotal(ObjectUtil.toLong(record.get("official_account_register_user_count_total")));
        result.setOfficialAccountRegisterUserCountDay(ObjectUtil.toLong(record.get("official_account_register_user_count_day")));
        result.setOfficialAccountRegisterRateAll(ObjectUtil.toDouble(record.get("official_account_register_rate_all")));
        result.setOfficialAccountRegisterRateDay(ObjectUtil.toDouble(record.get("official_account_register_rate_day")));
        result.setOfficialAccountRegisterCostAll(ObjectUtil.toLong(record.get("official_account_register_cost_all")));
        result.setOfficialAccountRegisterCostDay(ObjectUtil.toLong(record.get("official_account_register_cost_day")));
        result.setOfficialAccountRegisterAmountTotal(ObjectUtil.toLong(record.get("official_account_register_amount_total")));
        result.setOfficialAccountRegisterAmountDay(ObjectUtil.toLong(record.get("official_account_register_amount_day")));
        result.setOfficialAccountRegisterRoiAll(ObjectUtil.toLong(record.get("official_account_register_roi_all")));
        result.setOfficialAccountRegisterRoiDay(ObjectUtil.toLong(record.get("official_account_register_roi_day")));
        result.setOfficialAccountApplyCountTotal(ObjectUtil.toLong(record.get("official_account_apply_count_total")));
        result.setOfficialAccountApplyCountDay(ObjectUtil.toLong(record.get("official_account_apply_count_day")));
        result.setOfficialAccountApplyUserCountTotal(ObjectUtil.toLong(record.get("official_account_apply_user_count_total")));
        result.setOfficialAccountApplyUserCountDay(ObjectUtil.toLong(record.get("official_account_apply_user_count_day")));
        result.setOfficialAccountApplyRateAll(ObjectUtil.toDouble(record.get("official_account_apply_rate_all")));
        result.setOfficialAccountApplyRateDay(ObjectUtil.toDouble(record.get("official_account_apply_rate_day")));
        result.setOfficialAccountApplyCostAll(ObjectUtil.toLong(record.get("official_account_apply_cost_all")));
        result.setOfficialAccountApplyCostDay(ObjectUtil.toLong(record.get("official_account_apply_cost_day")));
        result.setOfficialAccountApplyAmountTotal(ObjectUtil.toLong(record.get("official_account_apply_amount_total")));
        result.setOfficialAccountApplyAmountDay(ObjectUtil.toLong(record.get("official_account_apply_amount_day")));
        result.setOfficialAccountApplyRoiAll(ObjectUtil.toLong(record.get("official_account_apply_roi_all")));
        result.setOfficialAccountApplyRoiDay(ObjectUtil.toLong(record.get("official_account_apply_roi_day")));
        result.setOfficialAccountOrderCountTotal(ObjectUtil.toLong(record.get("official_account_order_count_total")));
        result.setOfficialAccountOrderCountDay(ObjectUtil.toLong(record.get("official_account_order_count_day")));
        result.setOfficialAccountFirstDayOrderCountTotal(ObjectUtil.toLong(record.get("official_account_first_day_order_count_total")));
        result.setOfficialAccountFirstDayOrderCountDay(ObjectUtil.toLong(record.get("official_account_first_day_order_count_day")));
        result.setOfficialAccountOrderUserCountTotal(ObjectUtil.toLong(record.get("official_account_order_user_count_total")));
        result.setOfficialAccountOrderUserCountDay(ObjectUtil.toLong(record.get("official_account_order_user_count_day")));
        result.setOfficialAccountOrderRateAll(ObjectUtil.toDouble(record.get("official_account_order_rate_all")));
        result.setOfficialAccountOrderRateDay(ObjectUtil.toDouble(record.get("official_account_order_rate_day")));
        result.setOfficialAccountOrderCostAll(ObjectUtil.toLong(record.get("official_account_order_cost_all")));
        result.setOfficialAccountOrderCostDay(ObjectUtil.toLong(record.get("official_account_order_cost_day")));
        result.setOfficialAccountOrderAmountTotal(ObjectUtil.toLong(record.get("official_account_order_amount_total")));
        result.setOfficialAccountOrderAmountDay(ObjectUtil.toLong(record.get("official_account_order_amount_day")));
        result.setOfficialAccountFirstDayOrderAmountTotal(ObjectUtil.toLong(record.get("official_account_first_day_order_amount_total")));
        result.setOfficialAccountFirstDayOrderAmountDay(ObjectUtil.toLong(record.get("official_account_first_day_order_amount_day")));
        result.setOfficialAccountOrderRoiAll(ObjectUtil.toLong(record.get("official_account_order_roi_all")));
        result.setOfficialAccountOrderRoiDay(ObjectUtil.toLong(record.get("official_account_order_roi_day")));
        result.setOfficialAccountConsultCountTotal(ObjectUtil.toLong(record.get("official_account_consult_count_total")));
        result.setOfficialAccountConsultCountDay(ObjectUtil.toLong(record.get("official_account_consult_count_day")));
        result.setOfficialAccountReaderCountTotal(ObjectUtil.toLong(record.get("official_account_reader_count_total")));
        result.setOfficialAccountReaderCountDay(ObjectUtil.toLong(record.get("official_account_reader_count_day")));
        result.setOfficialAccountCreditApplyUserCountTotal(ObjectUtil.toLong(record.get("official_account_credit_apply_user_count_total")));
        result.setOfficialAccountCreditApplyUserCountDay(ObjectUtil.toLong(record.get("official_account_credit_apply_user_count_day")));
        result.setOfficialAccountCreditUserCountTotal(ObjectUtil.toLong(record.get("official_account_credit_user_count_total")));
        result.setOfficialAccountCreditUserCountDay(ObjectUtil.toLong(record.get("official_account_credit_user_count_day")));
        result.setForwardCountTotal(ObjectUtil.toLong(record.get("forward_count_total")));
        result.setForwardCountDay(ObjectUtil.toLong(record.get("forward_count_day")));
        result.setForwardUserCountTotal(ObjectUtil.toLong(record.get("forward_user_count_total")));
        result.setForwardUserCountDay(ObjectUtil.toLong(record.get("forward_user_count_day")));
        result.setNoInterestCountTotal(ObjectUtil.toLong(record.get("no_interest_count_total")));
        result.setNoInterestCountDay(ObjectUtil.toLong(record.get("no_interest_count_day")));
        return result;
    }
}
