package flink.zanxiangnet.ad.monitoring.pojo.entity;

import com.aliyun.odps.data.Record;
import com.google.gson.annotations.SerializedName;
import flink.zanxiangnet.ad.monitoring.maxcompute.bean.annotation.MaxComputeColumn;
import flink.zanxiangnet.ad.monitoring.maxcompute.bean.annotation.MaxComputeTable;
import flink.zanxiangnet.ad.monitoring.util.ObjectUtil;
import flink.zanxiangnet.ad.monitoring.util.PlanUtil;
import lombok.Data;
import org.springframework.beans.BeanUtils;

import java.util.*;

/**
 * 广告维度的小时统计数据
 */
@Data
@MaxComputeTable("plan_stat_of_hour_dwd")
public class PlanStatOfHourDWD {

    /**
     * 统计的日期（用于 MaxCompute分区）
     */
    @MaxComputeColumn(isPartitioned = true)
    @SerializedName("stat_day")
    private String statDay;

    /**
     * 统计的小时
     */
    @SerializedName("hour")
    private Integer hour;

    /**
     * 腾讯广告应用的账号 id
     */
    @SerializedName("account_id")
    private Long accountId;

    /**
     * 计划 id
     */
    @SerializedName("campaign_id")
    private Long campaignId;

    /**
     * 服务商账号 id
     */
    @SerializedName("agency_account_id")
    private Long agencyAccountId;

    /**
     * 微信账号id
     */
    @SerializedName("wechat_account_id")
    private String wechatAccountId;

    /**
     * 微信服务商id
     */
    @SerializedName("wechat_agency_id")
    private String wechatAgencyId;

    /**
     * 广告组与广告的映射关系
     */
    @MaxComputeColumn(ignore = true)
    @SerializedName("ad_group_map")
    private Map<Long, Set<Long>> adGroupMap;

    /**
     * 广告组与广告的映射关系
     */
    @SerializedName("ad_group_map_str")
    private String adGroupMapStr;

    /**
     * 广告 id列表
     */
    @MaxComputeColumn(ignore = true)
    @SerializedName("ad_ids")
    private Set<Long> adIds;

    /**
     * 广告 id列表
     */
    @SerializedName("ad_ids_str")
    private String adIdsStr;

    /**
     * 记录创建时间
     */
    @SerializedName("create_time")
    private Date createTime;

    /**
     * 当日成本偏差。反映广告今日的实际成本与目标成本直接的差异，注：该项成本相关数据按小时更新，与实时更新的「转化目标成本」数据存在出入属于正常情况。
     */
    @SerializedName("cost_deviation_rate_total")
    private Double costDeviationRateTotal;

    /**
     * 当日成本偏差。反映广告今日的实际成本与目标成本直接的差异，注：该项成本相关数据按小时更新，与实时更新的「转化目标成本」数据存在出入属于正常情况。
     */
    @SerializedName("cost_deviation_rate_day")
    private Double costDeviationRateDay;

    /**
     * 当日成本偏差。反映广告今日的实际成本与目标成本直接的差异，注：该项成本相关数据按小时更新，与实时更新的「转化目标成本」数据存在出入属于正常情况。
     */
    @SerializedName("cost_deviation_rate_hour")
    private Double costDeviationRateHour;

    /**
     * 消耗
     */
    @SerializedName("cost_total")
    private Long costTotal;

    /**
     * 消耗
     */
    @SerializedName("cost_day")
    private Long costDay;

    /**
     * 消耗
     */
    @SerializedName("cost_hour")
    private Long costHour;

    /**
     * 赔付金额。智能优化成本保障政策下，广告超成本时的赔付金额。
     */
    @SerializedName("compensation_amount_total")
    private Long compensationAmountTotal;

    /**
     * 赔付金额。智能优化成本保障政策下，广告超成本时的赔付金额。
     */
    @SerializedName("compensation_amount_day")
    private Long compensationAmountDay;

    /**
     * 赔付金额。智能优化成本保障政策下，广告超成本时的赔付金额。
     */
    @SerializedName("compensation_amount_hour")
    private Long compensationAmountHour;

    /**
     * 曝光次数。用户观看广告的次数。
     */
    @SerializedName("view_count_total")
    private Long viewCountTotal;

    /**
     * 曝光次数。用户观看广告的次数。
     */
    @SerializedName("view_count_day")
    private Long viewCountDay;

    /**
     * 曝光次数。用户观看广告的次数。
     */
    @SerializedName("view_count_hour")
    private Long viewCountHour;

    /**
     * 千次曝光成本。平均每千次曝光的花费。
     */
    @SerializedName("thousand_display_price_all")
    private Long thousandDisplayPriceAll;

    /**
     * 千次曝光成本。平均每千次曝光的花费。
     */
    @SerializedName("thousand_display_price_day")
    private Long thousandDisplayPriceDay;

    /**
     * 千次曝光成本。平均每千次曝光的花费。
     */
    @SerializedName("thousand_display_price_hour")
    private Long thousandDisplayPriceHour;

    /**
     * 人均曝光次数。每个用户观看广告的平均次数。
     */
    @SerializedName("avg_view_per_user_hour")
    private Double avgViewPerUserHour;

    /**
     * 点击次数。用户在广告外层进行点击操作的次数。包括点击图片/视频，及朋友圈广告“文字链、头像、昵称、门店、选择按钮”等所有广告外层区域的点击。
     */
    @SerializedName("valid_click_count_total")
    private Long validClickCountTotal;

    /**
     * 点击次数。用户在广告外层进行点击操作的次数。包括点击图片/视频，及朋友圈广告“文字链、头像、昵称、门店、选择按钮”等所有广告外层区域的点击。
     */
    @SerializedName("valid_click_count_day")
    private Long validClickCountDay;

    /**
     * 点击次数。用户在广告外层进行点击操作的次数。包括点击图片/视频，及朋友圈广告“文字链、头像、昵称、门店、选择按钮”等所有广告外层区域的点击。
     */
    @SerializedName("valid_click_count_hour")
    private Long validClickCountHour;

    /**
     * 点击率。看到广告后执行点击操作的百分比。计算逻辑：广告点击次数/广告曝光次数。
     */
    @SerializedName("ctr_all")
    private Double ctrAll;

    /**
     * 点击率。看到广告后执行点击操作的百分比。计算逻辑：广告点击次数/广告曝光次数。
     */
    @SerializedName("ctr_day")
    private Double ctrDay;

    /**
     * 点击率。看到广告后执行点击操作的百分比。计算逻辑：广告点击次数/广告曝光次数。
     */
    @SerializedName("ctr_hour")
    private Double ctrHour;

    /**
     * 点击均价。一次广告点击的平均花费。计算逻辑：广告花费/广告点击次数。
     */
    @SerializedName("cpc_all")
    private Long cpcAll;

    /**
     * 点击均价。一次广告点击的平均花费。计算逻辑：广告花费/广告点击次数。
     */
    @SerializedName("cpc_day")
    private Long cpcDay;

    /**
     * 点击均价。一次广告点击的平均花费。计算逻辑：广告花费/广告点击次数。
     */
    @SerializedName("cpc_hour")
    private Long cpcHour;

    /**
     * 可转化点击次数。朋友圈：可转化点击是指可能产生转化的外层点击次数。对于“公众号推广”的广告，包括外层的公众号头像、公众号昵称、详情页查看、原生推广页查看； 对于其他类型的广告，包括外层的详情页查看和原生推广页查看。公众号：可转化点击是指可能产生转化的点击次数。
     */
    @SerializedName("valuable_click_count_total")
    private Long valuableClickCountTotal;

    /**
     * 可转化点击次数。朋友圈：可转化点击是指可能产生转化的外层点击次数。对于“公众号推广”的广告，包括外层的公众号头像、公众号昵称、详情页查看、原生推广页查看； 对于其他类型的广告，包括外层的详情页查看和原生推广页查看。公众号：可转化点击是指可能产生转化的点击次数。
     */
    @SerializedName("valuable_click_count_day")
    private Long valuableClickCountDay;

    /**
     * 可转化点击次数。朋友圈：可转化点击是指可能产生转化的外层点击次数。对于“公众号推广”的广告，包括外层的公众号头像、公众号昵称、详情页查看、原生推广页查看； 对于其他类型的广告，包括外层的详情页查看和原生推广页查看。公众号：可转化点击是指可能产生转化的点击次数。
     */
    @SerializedName("valuable_click_count_hour")
    private Long valuableClickCountHour;

    /**
     * 可转化点击率。用户看到广告后执行可转化点击操作的百分比。计算逻辑：广告可转化点击次数/广告曝光次数。
     */
    @SerializedName("valuable_click_rate_all")
    private Double valuableClickRateAll;

    /**
     * 可转化点击率。用户看到广告后执行可转化点击操作的百分比。计算逻辑：广告可转化点击次数/广告曝光次数。
     */
    @SerializedName("valuable_click_rate_day")
    private Double valuableClickRateDay;

    /**
     * 可转化点击率。用户看到广告后执行可转化点击操作的百分比。计算逻辑：广告可转化点击次数/广告曝光次数。
     */
    @SerializedName("valuable_click_rate_hour")
    private Double valuableClickRateHour;

    /**
     * 可转化点击成本。一次可转化点击的平均花费。计算逻辑：广告花费/可转化点击次数。
     */
    @SerializedName("valuable_click_cost_all")
    private Long valuableClickCostAll;

    /**
     * 可转化点击成本。一次可转化点击的平均花费。计算逻辑：广告花费/可转化点击次数。
     */
    @SerializedName("valuable_click_cost_day")
    private Long valuableClickCostDay;

    /**
     * 可转化点击成本。一次可转化点击的平均花费。计算逻辑：广告花费/可转化点击次数。
     */
    @SerializedName("valuable_click_cost_hour")
    private Long valuableClickCostHour;

    /**
     * 转化目标量。「转化目标」的具体数量，代表该广告的转化效果量级。
     */
    @SerializedName("conversions_count_total")
    private Long conversionsCountTotal;

    /**
     * 转化目标量。「转化目标」的具体数量，代表该广告的转化效果量级。
     */
    @SerializedName("conversions_count_day")
    private Long conversionsCountDay;

    /**
     * 转化目标量。「转化目标」的具体数量，代表该广告的转化效果量级。
     */
    @SerializedName("conversions_count_hour")
    private Long conversionsCountHour;

    /**
     * 转化目标成本。广告产生一次转化目标的平均费用。计算逻辑：广告花费/转化目标量。
     */
    @SerializedName("conversions_cost_all")
    private Long conversionsCostAll;

    /**
     * 转化目标成本。广告产生一次转化目标的平均费用。计算逻辑：广告花费/转化目标量。
     */
    @SerializedName("conversions_cost_day")
    private Long conversionsCostDay;

    /**
     * 转化目标成本。广告产生一次转化目标的平均费用。计算逻辑：广告花费/转化目标量。
     */
    @SerializedName("conversions_cost_hour")
    private Long conversionsCostHour;

    /**
     * 目标转化率。朋友圈：转化目标量/可转化点击次数。公众号：转化目标量/点击次数。
     */
    @SerializedName("conversions_rate_all")
    private Double conversionsRateAll;

    /**
     * 目标转化率。朋友圈：转化目标量/可转化点击次数。公众号：转化目标量/点击次数。
     */
    @SerializedName("conversions_rate_day")
    private Double conversionsRateDay;

    /**
     * 目标转化率。朋友圈：转化目标量/可转化点击次数。公众号：转化目标量/点击次数。
     */
    @SerializedName("conversions_rate_hour")
    private Double conversionsRateHour;

    /**
     * 深度转化目标量-灰度中。根据您选择的深度智能优化目标，该广告对应的具体数量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_count_total")
    private Long deepConversionsCountTotal;

    /**
     * 深度转化目标量-灰度中。根据您选择的深度智能优化目标，该广告对应的具体数量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_count_day")
    private Long deepConversionsCountDay;

    /**
     * 深度转化目标量-灰度中。根据您选择的深度智能优化目标，该广告对应的具体数量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_count_hour")
    private Long deepConversionsCountHour;

    /**
     * 深度转化目标成本-灰度中。根据您选择的深度智能优化目标，该广告产生一次转化的平均费用。计算逻辑：广告花费/深度转化目标量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_cost_all")
    private Long deepConversionsCostAll;

    /**
     * 深度转化目标成本-灰度中。根据您选择的深度智能优化目标，该广告产生一次转化的平均费用。计算逻辑：广告花费/深度转化目标量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_cost_day")
    private Long deepConversionsCostDay;

    /**
     * 深度转化目标成本-灰度中。根据您选择的深度智能优化目标，该广告产生一次转化的平均费用。计算逻辑：广告花费/深度转化目标量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_cost_hour")
    private Long deepConversionsCostHour;

    /**
     * 深度目标转化率-灰度中。朋友圈：深度转化目标量/可转化点击次数。公众号：深度转化目标量/点击次数。指标随深度转化功能灰度中。接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_rate_all")
    private Double deepConversionsRateAll;

    /**
     * 深度目标转化率-灰度中。朋友圈：深度转化目标量/可转化点击次数。公众号：深度转化目标量/点击次数。指标随深度转化功能灰度中。接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_rate_day")
    private Double deepConversionsRateDay;

    /**
     * 深度目标转化率-灰度中。朋友圈：深度转化目标量/可转化点击次数。公众号：深度转化目标量/点击次数。指标随深度转化功能灰度中。接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_rate_hour")
    private Double deepConversionsRateHour;

    /**
     * 下单量。用户通过该广告进行商品成交（如下单提交、在线支付）的次数。接入转化跟踪后可统计。
     */
    @SerializedName("order_count_total")
    private Long orderCountTotal;

    /**
     * 下单量。用户通过该广告进行商品成交（如下单提交、在线支付）的次数。接入转化跟踪后可统计。
     */
    @SerializedName("order_count_day")
    private Long orderCountDay;

    /**
     * 下单量。用户通过该广告进行商品成交（如下单提交、在线支付）的次数。接入转化跟踪后可统计。
     */
    @SerializedName("order_count_hour")
    private Long orderCountHour;

    /**
     * 首日新增下单量。广告推广获取的用户，点击广告当日，带来的下单次数。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_count_total")
    private Long firstDayOrderCountTotal;

    /**
     * 首日新增下单量。广告推广获取的用户，点击广告当日，带来的下单次数。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_count_day")
    private Long firstDayOrderCountDay;

    /**
     * 首日新增下单量。广告推广获取的用户，点击广告当日，带来的下单次数。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_count_hour")
    private Long firstDayOrderCountHour;

    /**
     * 下单成本（次数）。产生一次下单的成本。
     */
    @SerializedName("web_order_cost_all")
    private Long webOrderCostAll;

    /**
     * 下单成本（次数）。产生一次下单的成本。
     */
    @SerializedName("web_order_cost_day")
    private Long webOrderCostDay;

    /**
     * 下单成本（次数）。产生一次下单的成本。
     */
    @SerializedName("web_order_cost_hour")
    private Long webOrderCostHour;

    /**
     * 下单率。一次点击到下单的转化率。
     */
    @SerializedName("order_rate_all")
    private Double orderRateAll;

    /**
     * 下单率。一次点击到下单的转化率。
     */
    @SerializedName("order_rate_day")
    private Double orderRateDay;

    /**
     * 下单率。一次点击到下单的转化率。
     */
    @SerializedName("order_rate_hour")
    private Double orderRateHour;

    /**
     * 下单金额。广告带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("order_amount_total")
    private Long orderAmountTotal;

    /**
     * 下单金额。广告带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("order_amount_day")
    private Long orderAmountDay;

    /**
     * 下单金额。广告带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("order_amount_hour")
    private Long orderAmountHour;

    /**
     * 首日新增下单金额。广告推广获取的用户，点击广告当日，带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_amount_total")
    private Long firstDayOrderAmountTotal;

    /**
     * 首日新增下单金额。广告推广获取的用户，点击广告当日，带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_amount_day")
    private Long firstDayOrderAmountDay;

    /**
     * 首日新增下单金额。广告推广获取的用户，点击广告当日，带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_amount_hour")
    private Long firstDayOrderAmountHour;

    /**
     * 下单客单价。下单金额/下单量。接入转化跟踪后可统计。
     */
    @SerializedName("order_unit_price_all")
    private Long orderUnitPriceAll;

    /**
     * 下单客单价。下单金额/下单量。接入转化跟踪后可统计。
     */
    @SerializedName("order_unit_price_day")
    private Long orderUnitPriceDay;

    /**
     * 下单客单价。下单金额/下单量。接入转化跟踪后可统计。
     */
    @SerializedName("order_unit_price_hour")
    private Long orderUnitPriceHour;

    /**
     * 下单ROI。下单金额/广告花费。接入转化跟踪后可统计。
     */
    @SerializedName("order_roi_all")
    private Double orderRoiAll;

    /**
     * 下单ROI。下单金额/广告花费。接入转化跟踪后可统计。
     */
    @SerializedName("order_roi_day")
    private Double orderRoiDay;

    /**
     * 下单ROI。下单金额/广告花费。接入转化跟踪后可统计。
     */
    @SerializedName("order_roi_hour")
    private Double orderRoiHour;

    /**
     * 签收次数。签收从广告主处购买的商品的次数。接入转化跟踪后可统计。
     */
    @SerializedName("sign_in_count_total")
    private Long signInCountTotal;

    /**
     * 签收次数。签收从广告主处购买的商品的次数。接入转化跟踪后可统计。
     */
    @SerializedName("sign_in_count_day")
    private Long signInCountDay;

    /**
     * 签收次数。签收从广告主处购买的商品的次数。接入转化跟踪后可统计。
     */
    @SerializedName("sign_in_count_hour")
    private Long signInCountHour;

    /**
     * 加企业微信客服人数。添加企业微信好友成功的独立用户数。
     */
    @SerializedName("scan_follow_count_total")
    private Long scanFollowCountTotal;

    /**
     * 加企业微信客服人数。添加企业微信好友成功的独立用户数。
     */
    @SerializedName("scan_follow_count_day")
    private Long scanFollowCountDay;

    /**
     * 加企业微信客服人数。添加企业微信好友成功的独立用户数。
     */
    @SerializedName("scan_follow_count_hour")
    private Long scanFollowCountHour;

    /**
     * 小游戏注册人数。通过广告首次登录小游戏的独立用户数。
     */
    @SerializedName("wechat_app_register_uv_total")
    private Long wechatAppRegisterUvTotal;

    /**
     * 小游戏注册人数。通过广告首次登录小游戏的独立用户数。
     */
    @SerializedName("wechat_app_register_uv_day")
    private Long wechatAppRegisterUvDay;

    /**
     * 小游戏注册人数。通过广告首次登录小游戏的独立用户数。
     */
    @SerializedName("wechat_app_register_uv_hour")
    private Long wechatAppRegisterUvHour;

    /**
     * 小游戏注册成本（人数）。产生一个小游戏注册人数的成本。
     */
    @SerializedName("wechat_minigame_register_cost_all")
    private Long wechatMinigameRegisterCostAll;

    /**
     * 小游戏注册成本（人数）。产生一个小游戏注册人数的成本。
     */
    @SerializedName("wechat_minigame_register_cost_day")
    private Long wechatMinigameRegisterCostDay;

    /**
     * 小游戏注册成本（人数）。产生一个小游戏注册人数的成本。
     */
    @SerializedName("wechat_minigame_register_cost_hour")
    private Long wechatMinigameRegisterCostHour;

    /**
     * 小游戏注册率。一次点击到小游戏注册的转化率。
     */
    @SerializedName("wechat_minigame_register_rate_all")
    private Double wechatMinigameRegisterRateAll;

    /**
     * 小游戏注册率。一次点击到小游戏注册的转化率。
     */
    @SerializedName("wechat_minigame_register_rate_day")
    private Double wechatMinigameRegisterRateDay;

    /**
     * 小游戏注册率。一次点击到小游戏注册的转化率。
     */
    @SerializedName("wechat_minigame_register_rate_hour")
    private Double wechatMinigameRegisterRateHour;

    /**
     * 首日新增广告ARPU。广告带来的注册用户，在注册当日，产生的平均广告变现收入。注：该指标天更新，可以查看昨天及以前的数据。
     */
    @SerializedName("wechat_minigame_arpu_all")
    private Double wechatMinigameArpuAll;

    /**
     * 首日新增广告ARPU。广告带来的注册用户，在注册当日，产生的平均广告变现收入。注：该指标天更新，可以查看昨天及以前的数据。
     */
    @SerializedName("wechat_minigame_arpu_day")
    private Double wechatMinigameArpuDay;

    /**
     * 首日新增广告ARPU。广告带来的注册用户，在注册当日，产生的平均广告变现收入。注：该指标天更新，可以查看昨天及以前的数据。
     */
    @SerializedName("wechat_minigame_arpu_hour")
    private Double wechatMinigameArpuHour;

    /**
     * 小游戏次留人数。通过广告首次登录小游戏，并在第二天再次登录的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_retention_count_total")
    private Long wechatMinigameRetentionCountTotal;

    /**
     * 小游戏次留人数。通过广告首次登录小游戏，并在第二天再次登录的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_retention_count_day")
    private Long wechatMinigameRetentionCountDay;

    /**
     * 小游戏次留人数。通过广告首次登录小游戏，并在第二天再次登录的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_retention_count_hour")
    private Long wechatMinigameRetentionCountHour;

    /**
     * 小游戏付费次数。通过广告进入小游戏并完成付费的次数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_count_total")
    private Long wechatMinigameCheckoutCountTotal;

    /**
     * 小游戏付费次数。通过广告进入小游戏并完成付费的次数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_count_day")
    private Long wechatMinigameCheckoutCountDay;

    /**
     * 小游戏付费次数。通过广告进入小游戏并完成付费的次数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_count_hour")
    private Long wechatMinigameCheckoutCountHour;

    /**
     * 小游戏付费金额。通过广告进入小游戏并完成付费的金额。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_amount_total")
    private Long wechatMinigameCheckoutAmountTotal;

    /**
     * 小游戏付费金额。通过广告进入小游戏并完成付费的金额。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_amount_day")
    private Long wechatMinigameCheckoutAmountDay;

    /**
     * 小游戏付费金额。通过广告进入小游戏并完成付费的金额。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_amount_hour")
    private Long wechatMinigameCheckoutAmountHour;

    /**
     * 公众号关注次数。用户通过广告关注公众号成功的次数。
     */
    @SerializedName("official_account_follow_count_total")
    private Long officialAccountFollowCountTotal;

    /**
     * 公众号关注次数。用户通过广告关注公众号成功的次数。
     */
    @SerializedName("official_account_follow_count_day")
    private Long officialAccountFollowCountDay;

    /**
     * 公众号关注次数。用户通过广告关注公众号成功的次数。
     */
    @SerializedName("official_account_follow_count_hour")
    private Long officialAccountFollowCountHour;

    /**
     * 公众号关注率。一次点击到公众号关注的转化率。
     */
    @SerializedName("official_account_follow_rate_all")
    private Double officialAccountFollowRateAll;

    /**
     * 公众号关注率。一次点击到公众号关注的转化率。
     */
    @SerializedName("official_account_follow_rate_day")
    private Double officialAccountFollowRateDay;

    /**
     * 公众号关注率。一次点击到公众号关注的转化率。
     */
    @SerializedName("official_account_follow_rate_hour")
    private Double officialAccountFollowRateHour;

    /**
     * 公众号内注册人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的注册行为的人数（UV）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_user_count_total")
    private Long officialAccountRegisterUserCountTotal;

    /**
     * 公众号内注册人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的注册行为的人数（UV）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_user_count_day")
    private Long officialAccountRegisterUserCountDay;

    /**
     * 公众号内注册人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的注册行为的人数（UV）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_user_count_hour")
    private Long officialAccountRegisterUserCountHour;

    /**
     * 公众号内注册比例。公众号内注册独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_rate_all")
    private Double officialAccountRegisterRateAll;

    /**
     * 公众号内注册比例。公众号内注册独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_rate_day")
    private Double officialAccountRegisterRateDay;

    /**
     * 公众号内注册比例。公众号内注册独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_rate_hour")
    private Double officialAccountRegisterRateHour;

    /**
     * 公众号内注册成本。广告花费/广告产生的注册行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_cost_all")
    private Long officialAccountRegisterCostAll;

    /**
     * 公众号内注册成本。广告花费/广告产生的注册行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_cost_day")
    private Long officialAccountRegisterCostDay;

    /**
     * 公众号内注册成本。广告花费/广告产生的注册行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_cost_hour")
    private Long officialAccountRegisterCostHour;

    /**
     * 公众号内注册订单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的订单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_amount_total")
    private Long officialAccountRegisterAmountTotal;

    /**
     * 公众号内注册订单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的订单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_amount_day")
    private Long officialAccountRegisterAmountDay;

    /**
     * 公众号内注册订单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的订单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_amount_hour")
    private Long officialAccountRegisterAmountHour;

    /**
     * 公众号内注册ROI。注册产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_roi_all")
    private Long officialAccountRegisterRoiAll;

    /**
     * 公众号内注册ROI。注册产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_roi_day")
    private Long officialAccountRegisterRoiDay;

    /**
     * 公众号内注册ROI。注册产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_roi_hour")
    private Long officialAccountRegisterRoiHour;

    /**
     * 公众号内填单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_count_total")
    private Long officialAccountApplyCountTotal;

    /**
     * 公众号内填单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_count_day")
    private Long officialAccountApplyCountDay;

    /**
     * 公众号内填单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_count_hour")
    private Long officialAccountApplyCountHour;

    /**
     * 公众号内填单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_user_count_total")
    private Long officialAccountApplyUserCountTotal;

    /**
     * 公众号内填单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_user_count_day")
    private Long officialAccountApplyUserCountDay;

    /**
     * 公众号内填单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_user_count_hour")
    private Long officialAccountApplyUserCountHour;

    /**
     * 公众号内填单比例。公众号内填单的独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_rate_all")
    private Double officialAccountApplyRateAll;

    /**
     * 公众号内填单比例。公众号内填单的独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_rate_day")
    private Double officialAccountApplyRateDay;

    /**
     * 公众号内填单比例。公众号内填单的独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_rate_hour")
    private Double officialAccountApplyRateHour;

    /**
     * 公众号内填单成本。广告花费/广告产生的填单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_cost_all")
    private Long officialAccountApplyCostAll;

    /**
     * 公众号内填单成本。广告花费/广告产生的填单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_cost_day")
    private Long officialAccountApplyCostDay;

    /**
     * 公众号内填单成本。广告花费/广告产生的填单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_cost_hour")
    private Long officialAccountApplyCostHour;

    /**
     * 公众号内填单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_amount_total")
    private Long officialAccountApplyAmountTotal;

    /**
     * 公众号内填单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_amount_day")
    private Long officialAccountApplyAmountDay;

    /**
     * 公众号内填单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_amount_hour")
    private Long officialAccountApplyAmountHour;

    /**
     * 公众号内填单ROI。填单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_roi_all")
    private Long officialAccountApplyRoiAll;

    /**
     * 公众号内填单ROI。填单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_roi_day")
    private Long officialAccountApplyRoiDay;

    /**
     * 公众号内填单ROI。填单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_roi_hour")
    private Long officialAccountApplyRoiHour;

    /**
     * 公众号内下单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_count_total")
    private Long officialAccountOrderCountTotal;

    /**
     * 公众号内下单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_count_day")
    private Long officialAccountOrderCountDay;

    /**
     * 公众号内下单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_count_hour")
    private Long officialAccountOrderCountHour;

    /**
     * 首日公众号内下单次数。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为数量。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_count_total")
    private Long officialAccountFirstDayOrderCountTotal;

    /**
     * 首日公众号内下单次数。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为数量。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_count_day")
    private Long officialAccountFirstDayOrderCountDay;

    /**
     * 首日公众号内下单次数。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为数量。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_count_hour")
    private Long officialAccountFirstDayOrderCountHour;

    /**
     * 公众号内下单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_user_count_total")
    private Long officialAccountOrderUserCountTotal;

    /**
     * 公众号内下单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_user_count_day")
    private Long officialAccountOrderUserCountDay;

    /**
     * 公众号内下单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_user_count_hour")
    private Long officialAccountOrderUserCountHour;

    /**
     * 公众号内下单比例。公众号内下单独立用户数（UV）/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_rate_all")
    private Double officialAccountOrderRateAll;

    /**
     * 公众号内下单比例。公众号内下单独立用户数（UV）/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_rate_day")
    private Double officialAccountOrderRateDay;

    /**
     * 公众号内下单比例。公众号内下单独立用户数（UV）/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_rate_hour")
    private Double officialAccountOrderRateHour;

    /**
     * 公众号内下单成本。广告花费/广告产生的下单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_cost_all")
    private Long officialAccountOrderCostAll;

    /**
     * 公众号内下单成本。广告花费/广告产生的下单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_cost_day")
    private Long officialAccountOrderCostDay;

    /**
     * 公众号内下单成本。广告花费/广告产生的下单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_cost_hour")
    private Long officialAccountOrderCostHour;

    /**
     * 公众号内下单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_amount_total")
    private Long officialAccountOrderAmountTotal;

    /**
     * 公众号内下单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_amount_day")
    private Long officialAccountOrderAmountDay;

    /**
     * 公众号内下单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_amount_hour")
    private Long officialAccountOrderAmountHour;

    /**
     * 首日公众号内下单金额。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_amount_total")
    private Long officialAccountFirstDayOrderAmountTotal;

    /**
     * 首日公众号内下单金额。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_amount_day")
    private Long officialAccountFirstDayOrderAmountDay;

    /**
     * 首日公众号内下单金额。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_amount_hour")
    private Long officialAccountFirstDayOrderAmountHour;

    /**
     * 公众号内下单ROI。下单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_roi_all")
    private Long officialAccountOrderRoiAll;

    /**
     * 公众号内下单ROI。下单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_roi_day")
    private Long officialAccountOrderRoiDay;

    /**
     * 公众号内下单ROI。下单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_roi_hour")
    private Long officialAccountOrderRoiHour;

    /**
     * 公众号内发消息人数。用户关注公众号后，在公众号对话框内发送消息的独立用户数。
     */
    @SerializedName("official_account_consult_count_total")
    private Long officialAccountConsultCountTotal;

    /**
     * 公众号内发消息人数。用户关注公众号后，在公众号对话框内发送消息的独立用户数。
     */
    @SerializedName("official_account_consult_count_day")
    private Long officialAccountConsultCountDay;

    /**
     * 公众号内发消息人数。用户关注公众号后，在公众号对话框内发送消息的独立用户数。
     */
    @SerializedName("official_account_consult_count_hour")
    private Long officialAccountConsultCountHour;

    /**
     * 阅读粉丝量。近3日新增的粉丝中产生阅读行为的用户数。
     */
    @SerializedName("official_account_reader_count_total")
    private Long officialAccountReaderCountTotal;

    /**
     * 阅读粉丝量。近3日新增的粉丝中产生阅读行为的用户数。
     */
    @SerializedName("official_account_reader_count_day")
    private Long officialAccountReaderCountDay;

    /**
     * 阅读粉丝量。近3日新增的粉丝中产生阅读行为的用户数。
     */
    @SerializedName("official_account_reader_count_hour")
    private Long officialAccountReaderCountHour;

    /**
     * 公众号内进件人数。在公众号内完整提交贷款申请资料的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_apply_user_count_total")
    private Long officialAccountCreditApplyUserCountTotal;

    /**
     * 公众号内进件人数。在公众号内完整提交贷款申请资料的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_apply_user_count_day")
    private Long officialAccountCreditApplyUserCountDay;

    /**
     * 公众号内进件人数。在公众号内完整提交贷款申请资料的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_apply_user_count_hour")
    private Long officialAccountCreditApplyUserCountHour;

    /**
     * 公众号内授信人数。在公众号内完整提交贷款申请资料，并通过放款方的资质审核的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_user_count_total")
    private Long officialAccountCreditUserCountTotal;

    /**
     * 公众号内授信人数。在公众号内完整提交贷款申请资料，并通过放款方的资质审核的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_user_count_day")
    private Long officialAccountCreditUserCountDay;

    /**
     * 公众号内授信人数。在公众号内完整提交贷款申请资料，并通过放款方的资质审核的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_user_count_hour")
    private Long officialAccountCreditUserCountHour;

    /**
     * 广告分享次数。用户将广告落地页分享给好友和朋友圈的次数。
     */
    @SerializedName("forward_count_total")
    private Long forwardCountTotal;

    /**
     * 广告分享次数。用户将广告落地页分享给好友和朋友圈的次数。
     */
    @SerializedName("forward_count_day")
    private Long forwardCountDay;

    /**
     * 广告分享次数。用户将广告落地页分享给好友和朋友圈的次数。
     */
    @SerializedName("forward_count_hour")
    private Long forwardCountHour;

    /**
     * 广告分享人数。将广告落地页分享给好友和朋友圈的独立用户数。
     */
    @SerializedName("forward_user_count_total")
    private Long forwardUserCountTotal;

    /**
     * 广告分享人数。将广告落地页分享给好友和朋友圈的独立用户数。
     */
    @SerializedName("forward_user_count_day")
    private Long forwardUserCountDay;

    /**
     * 广告分享人数。将广告落地页分享给好友和朋友圈的独立用户数。
     */
    @SerializedName("forward_user_count_hour")
    private Long forwardUserCountHour;

    /**
     * 不感兴趣点击次数。用户点击“不感兴趣”的次数。
     */
    @SerializedName("no_interest_count_total")
    private Long noInterestCountTotal;

    /**
     * 不感兴趣点击次数。用户点击“不感兴趣”的次数。
     */
    @SerializedName("no_interest_count_day")
    private Long noInterestCountDay;

    /**
     * 不感兴趣点击次数。用户点击“不感兴趣”的次数。
     */
    @SerializedName("no_interest_count_hour")
    private Long noInterestCountHour;

    public static PlanStatOfHourDWD reduce(PlanStatOfHourDWD value1, AdDataOfHourODS value2, long createTime) {
        PlanStatOfHourDWD result = new PlanStatOfHourDWD();
        BeanUtils.copyProperties(result, value2);
        result.setCreateTime(new Date(createTime));
        if (value1 == null) {
            Map<Long, Set<Long>> adGroupMap = new HashMap<>();
            Set<Long> adIdsTemp = new HashSet<>(3);
            adIdsTemp.add(value2.getAdId());
            adGroupMap.put(value2.getAdgroupId(), adIdsTemp);
            result.setAdGroupMap(adGroupMap);
            result.setAdGroupMapStr(PlanUtil.adGroupMapStr(adGroupMap));

            Set<Long> adIds = new HashSet<>(3);
            adIds.add(value2.getAdId());
            result.setAdIds(adIds);
            result.setAdIdsStr(PlanUtil.adIdsStr(value2.getAdId()));

            result.setCompensationAmountTotal(value2.getCompensationAmount());
            result.setCompensationAmountDay(value2.getCompensationAmount());
            result.setCompensationAmountHour(value2.getCompensationAmount());
            result.setViewCountTotal(value2.getViewCount());
            result.setViewCountDay(value2.getViewCount());
            result.setViewCountHour(value2.getViewCount());
            result.setThousandDisplayPriceAll(value2.getThousandDisplayPrice());
            result.setThousandDisplayPriceDay(value2.getThousandDisplayPrice());
            result.setThousandDisplayPriceHour(value2.getThousandDisplayPrice());
            result.setAvgViewPerUserHour(value2.getAvgViewPerUser());
            result.setValidClickCountTotal(value2.getValidClickCount());
            result.setValidClickCountDay(value2.getValidClickCount());
            result.setValidClickCountHour(value2.getValidClickCount());
            result.setCtrAll(value2.getCtr());
            result.setCtrDay(value2.getCtr());
            result.setCtrHour(value2.getCtr());
            result.setCpcAll(value2.getCpc());
            result.setCpcDay(value2.getCpc());
            result.setCpcHour(value2.getCpc());
            result.setValuableClickCountTotal(value2.getValuableClickCount());
            result.setValuableClickCountDay(value2.getValuableClickCount());
            result.setValuableClickCountHour(value2.getValuableClickCount());
            result.setValuableClickRateAll(value2.getValuableClickRate());
            result.setValuableClickRateDay(value2.getValuableClickRate());
            result.setValuableClickRateHour(value2.getValuableClickRate());
            result.setValuableClickCostAll(value2.getValuableClickCost());
            result.setValuableClickCostDay(value2.getValuableClickCost());
            result.setValuableClickCostHour(value2.getValuableClickCost());
            result.setConversionsCountTotal(value2.getConversionsCount());
            result.setConversionsCountDay(value2.getConversionsCount());
            result.setConversionsCountHour(value2.getConversionsCount());
            result.setConversionsCostAll(value2.getConversionsCost());
            result.setConversionsCostDay(value2.getConversionsCost());
            result.setConversionsCostHour(value2.getConversionsCost());
            result.setConversionsRateAll(value2.getConversionsRate());
            result.setConversionsRateDay(value2.getConversionsRate());
            result.setConversionsRateHour(value2.getConversionsRate());
            result.setDeepConversionsCountTotal(value2.getDeepConversionsCount());
            result.setDeepConversionsCountDay(value2.getDeepConversionsCount());
            result.setDeepConversionsCountHour(value2.getDeepConversionsCount());
            result.setDeepConversionsCostAll(value2.getDeepConversionsCost());
            result.setDeepConversionsCostDay(value2.getDeepConversionsCost());
            result.setDeepConversionsCostHour(value2.getDeepConversionsCost());
            result.setDeepConversionsRateAll(value2.getDeepConversionsRate());
            result.setDeepConversionsRateDay(value2.getDeepConversionsRate());
            result.setDeepConversionsRateHour(value2.getDeepConversionsRate());
            result.setOrderCountTotal(value2.getOrderCount());
            result.setOrderCountDay(value2.getOrderCount());
            result.setOrderCountHour(value2.getOrderCount());
            result.setFirstDayOrderCountTotal(value2.getFirstDayOrderCount());
            result.setFirstDayOrderCountDay(value2.getFirstDayOrderCount());
            result.setFirstDayOrderCountHour(value2.getFirstDayOrderCount());
            result.setWebOrderCostAll(value2.getWebOrderCost());
            result.setWebOrderCostDay(value2.getWebOrderCost());
            result.setWebOrderCostHour(value2.getWebOrderCost());
            result.setOrderRateAll(value2.getOrderRate());
            result.setOrderRateDay(value2.getOrderRate());
            result.setOrderRateHour(value2.getOrderRate());
            result.setOrderAmountTotal(value2.getOrderAmount());
            result.setOrderAmountDay(value2.getOrderAmount());
            result.setOrderAmountHour(value2.getOrderAmount());
            result.setFirstDayOrderAmountTotal(value2.getFirstDayOrderAmount());
            result.setFirstDayOrderAmountDay(value2.getFirstDayOrderAmount());
            result.setFirstDayOrderAmountHour(value2.getFirstDayOrderAmount());
            result.setOrderUnitPriceAll(value2.getOrderUnitPrice());
            result.setOrderUnitPriceDay(value2.getOrderUnitPrice());
            result.setOrderUnitPriceHour(value2.getOrderUnitPrice());
            result.setOrderRoiAll(value2.getOrderRoi());
            result.setOrderRoiDay(value2.getOrderRoi());
            result.setOrderRoiHour(value2.getOrderRoi());
            result.setSignInCountTotal(value2.getSignInCount());
            result.setSignInCountDay(value2.getSignInCount());
            result.setSignInCountHour(value2.getSignInCount());
            result.setScanFollowCountTotal(value2.getScanFollowCount());
            result.setScanFollowCountDay(value2.getScanFollowCount());
            result.setScanFollowCountHour(value2.getScanFollowCount());
            result.setWechatAppRegisterUvTotal(value2.getWechatAppRegisterUv());
            result.setWechatAppRegisterUvDay(value2.getWechatAppRegisterUv());
            result.setWechatAppRegisterUvHour(value2.getWechatAppRegisterUv());
            result.setWechatMinigameRegisterCostAll(value2.getWechatMinigameRegisterCost());
            result.setWechatMinigameRegisterCostDay(value2.getWechatMinigameRegisterCost());
            result.setWechatMinigameRegisterCostHour(value2.getWechatMinigameRegisterCost());
            result.setWechatMinigameRegisterRateAll(value2.getWechatMinigameRegisterRate());
            result.setWechatMinigameRegisterRateDay(value2.getWechatMinigameRegisterRate());
            result.setWechatMinigameRegisterRateHour(value2.getWechatMinigameRegisterRate());
            result.setWechatMinigameArpuAll(value2.getWechatMinigameArpu());
            result.setWechatMinigameArpuDay(value2.getWechatMinigameArpu());
            result.setWechatMinigameArpuHour(value2.getWechatMinigameArpu());
            result.setWechatMinigameRetentionCountTotal(value2.getWechatMinigameRetentionCount());
            result.setWechatMinigameRetentionCountDay(value2.getWechatMinigameRetentionCount());
            result.setWechatMinigameRetentionCountHour(value2.getWechatMinigameRetentionCount());
            result.setWechatMinigameCheckoutCountTotal(value2.getWechatMinigameCheckoutCount());
            result.setWechatMinigameCheckoutCountDay(value2.getWechatMinigameCheckoutCount());
            result.setWechatMinigameCheckoutCountHour(value2.getWechatMinigameCheckoutCount());
            result.setWechatMinigameCheckoutAmountTotal(value2.getWechatMinigameCheckoutAmount());
            result.setWechatMinigameCheckoutAmountDay(value2.getWechatMinigameCheckoutAmount());
            result.setWechatMinigameCheckoutAmountHour(value2.getWechatMinigameCheckoutAmount());
            result.setOfficialAccountFollowCountTotal(value2.getOfficialAccountFollowCount());
            result.setOfficialAccountFollowCountDay(value2.getOfficialAccountFollowCount());
            result.setOfficialAccountFollowCountHour(value2.getOfficialAccountFollowCount());
            result.setOfficialAccountFollowRateAll(value2.getOfficialAccountFollowRate());
            result.setOfficialAccountFollowRateDay(value2.getOfficialAccountFollowRate());
            result.setOfficialAccountFollowRateHour(value2.getOfficialAccountFollowRate());
            result.setOfficialAccountRegisterUserCountTotal(value2.getOfficialAccountRegisterUserCount());
            result.setOfficialAccountRegisterUserCountDay(value2.getOfficialAccountRegisterUserCount());
            result.setOfficialAccountRegisterUserCountHour(value2.getOfficialAccountRegisterUserCount());
            result.setOfficialAccountRegisterRateAll(value2.getOfficialAccountRegisterRate());
            result.setOfficialAccountRegisterRateDay(value2.getOfficialAccountRegisterRate());
            result.setOfficialAccountRegisterRateHour(value2.getOfficialAccountRegisterRate());
            result.setOfficialAccountRegisterCostAll(value2.getOfficialAccountRegisterCost());
            result.setOfficialAccountRegisterCostDay(value2.getOfficialAccountRegisterCost());
            result.setOfficialAccountRegisterCostHour(value2.getOfficialAccountRegisterCost());
            result.setOfficialAccountRegisterAmountTotal(value2.getOfficialAccountRegisterAmount());
            result.setOfficialAccountRegisterAmountDay(value2.getOfficialAccountRegisterAmount());
            result.setOfficialAccountRegisterAmountHour(value2.getOfficialAccountRegisterAmount());
            result.setOfficialAccountRegisterRoiAll(value2.getOfficialAccountRegisterRoi());
            result.setOfficialAccountRegisterRoiDay(value2.getOfficialAccountRegisterRoi());
            result.setOfficialAccountRegisterRoiHour(value2.getOfficialAccountRegisterRoi());
            result.setOfficialAccountApplyCountTotal(value2.getOfficialAccountApplyCount());
            result.setOfficialAccountApplyCountDay(value2.getOfficialAccountApplyCount());
            result.setOfficialAccountApplyCountHour(value2.getOfficialAccountApplyCount());
            result.setOfficialAccountApplyUserCountTotal(value2.getOfficialAccountApplyUserCount());
            result.setOfficialAccountApplyUserCountDay(value2.getOfficialAccountApplyUserCount());
            result.setOfficialAccountApplyUserCountHour(value2.getOfficialAccountApplyUserCount());
            result.setOfficialAccountApplyRateAll(value2.getOfficialAccountApplyRate());
            result.setOfficialAccountApplyRateDay(value2.getOfficialAccountApplyRate());
            result.setOfficialAccountApplyRateHour(value2.getOfficialAccountApplyRate());
            result.setOfficialAccountApplyCostAll(value2.getOfficialAccountApplyCost());
            result.setOfficialAccountApplyCostDay(value2.getOfficialAccountApplyCost());
            result.setOfficialAccountApplyCostHour(value2.getOfficialAccountApplyCost());
            result.setOfficialAccountApplyAmountTotal(value2.getOfficialAccountApplyAmount());
            result.setOfficialAccountApplyAmountDay(value2.getOfficialAccountApplyAmount());
            result.setOfficialAccountApplyAmountHour(value2.getOfficialAccountApplyAmount());
            result.setOfficialAccountApplyRoiAll(value2.getOfficialAccountApplyRoi());
            result.setOfficialAccountApplyRoiDay(value2.getOfficialAccountApplyRoi());
            result.setOfficialAccountApplyRoiHour(value2.getOfficialAccountApplyRoi());
            result.setOfficialAccountOrderCountTotal(value2.getOfficialAccountOrderCount());
            result.setOfficialAccountOrderCountDay(value2.getOfficialAccountOrderCount());
            result.setOfficialAccountOrderCountHour(value2.getOfficialAccountOrderCount());
            result.setOfficialAccountFirstDayOrderCountTotal(value2.getOfficialAccountFirstDayOrderCount());
            result.setOfficialAccountFirstDayOrderCountDay(value2.getOfficialAccountFirstDayOrderCount());
            result.setOfficialAccountFirstDayOrderCountHour(value2.getOfficialAccountFirstDayOrderCount());
            result.setOfficialAccountOrderUserCountTotal(value2.getOfficialAccountOrderUserCount());
            result.setOfficialAccountOrderUserCountDay(value2.getOfficialAccountOrderUserCount());
            result.setOfficialAccountOrderUserCountHour(value2.getOfficialAccountOrderUserCount());
            result.setOfficialAccountOrderRateAll(value2.getOfficialAccountOrderRate());
            result.setOfficialAccountOrderRateDay(value2.getOfficialAccountOrderRate());
            result.setOfficialAccountOrderRateHour(value2.getOfficialAccountOrderRate());
            result.setOfficialAccountOrderCostAll(value2.getOfficialAccountOrderCost());
            result.setOfficialAccountOrderCostDay(value2.getOfficialAccountOrderCost());
            result.setOfficialAccountOrderCostHour(value2.getOfficialAccountOrderCost());
            result.setOfficialAccountOrderAmountTotal(value2.getOfficialAccountOrderAmount());
            result.setOfficialAccountOrderAmountDay(value2.getOfficialAccountOrderAmount());
            result.setOfficialAccountOrderAmountHour(value2.getOfficialAccountOrderAmount());
            result.setOfficialAccountFirstDayOrderAmountTotal(value2.getOfficialAccountFirstDayOrderAmount());
            result.setOfficialAccountFirstDayOrderAmountDay(value2.getOfficialAccountFirstDayOrderAmount());
            result.setOfficialAccountFirstDayOrderAmountHour(value2.getOfficialAccountFirstDayOrderAmount());
            result.setOfficialAccountOrderRoiAll(value2.getOfficialAccountOrderRoi());
            result.setOfficialAccountOrderRoiDay(value2.getOfficialAccountOrderRoi());
            result.setOfficialAccountOrderRoiHour(value2.getOfficialAccountOrderRoi());
            result.setOfficialAccountConsultCountTotal(value2.getOfficialAccountConsultCount());
            result.setOfficialAccountConsultCountDay(value2.getOfficialAccountConsultCount());
            result.setOfficialAccountConsultCountHour(value2.getOfficialAccountConsultCount());
            result.setOfficialAccountReaderCountTotal(value2.getOfficialAccountReaderCount());
            result.setOfficialAccountReaderCountDay(value2.getOfficialAccountReaderCount());
            result.setOfficialAccountReaderCountHour(value2.getOfficialAccountReaderCount());
            result.setOfficialAccountCreditApplyUserCountTotal(value2.getOfficialAccountCreditApplyUserCount());
            result.setOfficialAccountCreditApplyUserCountDay(value2.getOfficialAccountCreditApplyUserCount());
            result.setOfficialAccountCreditApplyUserCountHour(value2.getOfficialAccountCreditApplyUserCount());
            result.setOfficialAccountCreditUserCountTotal(value2.getOfficialAccountCreditUserCount());
            result.setOfficialAccountCreditUserCountDay(value2.getOfficialAccountCreditUserCount());
            result.setOfficialAccountCreditUserCountHour(value2.getOfficialAccountCreditUserCount());
            result.setForwardCountTotal(value2.getForwardCount());
            result.setForwardCountDay(value2.getForwardCount());
            result.setForwardCountHour(value2.getForwardCount());
            result.setForwardUserCountTotal(value2.getForwardUserCount());
            result.setForwardUserCountDay(value2.getForwardUserCount());
            result.setForwardUserCountHour(value2.getForwardUserCount());
            result.setNoInterestCountTotal(value2.getNoInterestCount());
            result.setNoInterestCountDay(value2.getNoInterestCount());
            result.setNoInterestCountHour(value2.getNoInterestCount());
        } else {
            value1.getAdGroupMap().computeIfAbsent(value2.getAdgroupId(), key -> new HashSet<>(3)).add(value2.getAdId());
            value1.setAdGroupMapStr(PlanUtil.adGroupMapStr(value1.getAdGroupMap()));
            value1.getAdIds().add(value2.getAdId());
            value1.setAdIdsStr(PlanUtil.adIdsStr(value1.getAdIds()));

            // 是否是同一天
            boolean isUnSameDay = !value1.getStatDay().equals(value2.getStatDay());
            result.setCostDeviationRateTotal(value1.getCostDeviationRateTotal() + value2.getCostDeviationRate());
            result.setCostDeviationRateDay(isUnSameDay ? 0: value1.getCostDeviationRateDay() + value2.getCostDeviationRate());
            result.setCostDeviationRateHour(value2.getCostDeviationRate());
            result.setCostTotal(value1.getCostTotal() + value2.getCost());
            result.setCostDay(isUnSameDay ? 0: value1.getCostDay() + value2.getCost());
            result.setCostHour(value2.getCost());
            result.setCompensationAmountTotal(value1.getCompensationAmountTotal() + value2.getCompensationAmount());
            result.setCompensationAmountDay(isUnSameDay ? 0: value1.getCompensationAmountDay() + value2.getCompensationAmount());
            result.setCompensationAmountHour(value2.getCompensationAmount());
            result.setViewCountTotal(value1.getViewCountTotal() + value2.getViewCount());
            result.setViewCountDay(isUnSameDay ? 0: value1.getViewCountDay() + value2.getViewCount());
            result.setViewCountHour(value2.getViewCount());
            // 总消耗 / 总曝光
            result.setThousandDisplayPriceAll(result.getViewCountTotal() == 0 ? 0 : (result.getCostTotal() / result.getViewCountTotal() * 1000));
            result.setThousandDisplayPriceDay(isUnSameDay ? 0: result.getViewCountDay() == 0 ? 0 : (result.getCostDay() / result.getViewCountDay() * 1000));
            result.setThousandDisplayPriceHour(value2.getThousandDisplayPrice());
            // 曝光次数 / 曝光人数（拿不到曝光人数）
            result.setAvgViewPerUserHour(value2.getAvgViewPerUser());
            result.setValidClickCountTotal(value1.getValidClickCountTotal() + value2.getValidClickCount());
            result.setValidClickCountDay(isUnSameDay ? 0: value1.getValidClickCountDay() + value2.getValidClickCount());
            result.setValidClickCountHour(value2.getValidClickCount());
            // 广告点击次数 / 广告曝光次数
            result.setCtrAll(result.getViewCountTotal() == 0 ? 0.0 : result.getValidClickCountTotal() / result.getViewCountTotal());
            result.setCtrDay(isUnSameDay ? 0: result.getViewCountDay() == 0 ? 0.0 : result.getValidClickCountDay() / result.getViewCountDay());
            result.setCtrHour(value2.getCtr());
            // 广告花费/广告点击次数
            result.setCpcAll(result.getValidClickCountTotal() == 0 ? 0 : result.getCostTotal() / result.getValidClickCountTotal());
            result.setCpcDay(isUnSameDay ? 0: result.getValidClickCountDay() == 0 ? 0 : result.getCostDay() / result.getValidClickCountDay());
            result.setCpcHour(value2.getCpc());
            result.setValuableClickCountTotal(value1.getValuableClickCountTotal() + value2.getValuableClickCount());
            result.setValuableClickCountDay(isUnSameDay ? 0: value1.getValuableClickCountDay() + value2.getValuableClickCount());
            result.setValuableClickCountHour(value2.getValuableClickCount());
            // 广告可转化点击次数/广告曝光次数
            result.setValuableClickRateAll(result.getViewCountTotal() == 0 ? 0.0 : result.getValuableClickCountTotal() / result.getViewCountTotal());
            result.setValuableClickRateDay(isUnSameDay ? 0: result.getViewCountDay() == 0 ? 0.0 : result.getValuableClickCountDay() / result.getViewCountDay());
            result.setValuableClickRateHour(value2.getValuableClickRate());
            // 广告花费/可转化点击次数
            result.setValuableClickCostAll(result.getValuableClickCountTotal() == 0 ? 0 : result.getCostTotal() / result.getValuableClickCountTotal());
            result.setValuableClickCostDay(isUnSameDay ? 0: result.getValuableClickCountDay() == 0 ? 0 : result.getCostDay() / result.getValuableClickCountDay());
            result.setValuableClickCostHour(value2.getValuableClickCost());
            result.setConversionsCountTotal(value1.getConversionsCountTotal() + value2.getConversionsCount());
            result.setConversionsCountDay(isUnSameDay ? 0: value1.getConversionsCountDay() + value2.getConversionsCount());
            result.setConversionsCountHour(value2.getConversionsCount());
            // 广告花费/转化目标量
            result.setConversionsCostAll(result.getConversionsCountTotal() == 0 ? 0 : result.getCostTotal() / result.getConversionsCountTotal());
            result.setConversionsCostDay(isUnSameDay ? 0: result.getConversionsCountDay() == 0 ? 0 : result.getCostDay() / result.getConversionsCountDay());
            result.setConversionsCostHour(value2.getConversionsCost());
            // 公众号：转化目标量/点击次数。
            result.setConversionsRateAll(result.getValidClickCountTotal() == 0 ? 0.0 : result.getConversionsCountTotal() / result.getValidClickCountTotal());
            result.setConversionsRateDay(isUnSameDay ? 0: result.getValidClickCountDay() == 0 ? 0.0 : result.getConversionsCountDay() / result.getValidClickCountDay());
            result.setConversionsRateHour(value2.getConversionsRate());
            result.setDeepConversionsCountTotal(value1.getDeepConversionsCountTotal() + value2.getDeepConversionsCount());
            result.setDeepConversionsCountDay(isUnSameDay ? 0: value1.getDeepConversionsCountDay() + value2.getDeepConversionsCount());
            result.setDeepConversionsCountHour(value2.getDeepConversionsCount());
            // 广告花费/深度转化目标量
            result.setDeepConversionsCostAll(result.getDeepConversionsCountTotal() == 0 ? 0 : result.getCostTotal() / result.getDeepConversionsCountTotal());
            result.setDeepConversionsCostDay(isUnSameDay ? 0: result.getDeepConversionsCountDay() == 0 ? 0 : result.getCostDay() / result.getDeepConversionsCountDay());
            result.setDeepConversionsCostHour(value2.getDeepConversionsCost());
            // 深度转化目标量/可转化点击次数
            result.setDeepConversionsRateAll(result.getValuableClickCountTotal() == 0 ? 0.0 : result.getDeepConversionsCountTotal() / result.getValuableClickCountTotal());
            result.setDeepConversionsRateDay(isUnSameDay ? 0: result.getValuableClickCountDay() == 0 ? 0.0 : result.getDeepConversionsCountDay() / result.getValuableClickCountDay());
            result.setDeepConversionsRateHour(value2.getDeepConversionsRate());
            result.setOrderCountTotal(value1.getOrderCountTotal() + value2.getOrderCount());
            result.setOrderCountDay(isUnSameDay ? 0: value1.getOrderCountDay() + value2.getOrderCount());
            result.setOrderCountHour(value2.getOrderCount());
            result.setFirstDayOrderCountTotal(value1.getFirstDayOrderCountTotal() + value2.getFirstDayOrderCount());
            result.setFirstDayOrderCountDay(isUnSameDay ? 0: value1.getFirstDayOrderCountDay() + value2.getFirstDayOrderCount());
            result.setFirstDayOrderCountHour(value2.getFirstDayOrderCount());
            // 广告花费/下单量
            result.setWebOrderCostAll(result.getOrderCountTotal() == 0 ? 0 : result.getCostTotal() / result.getOrderCountTotal());
            result.setWebOrderCostDay(isUnSameDay ? 0: result.getOrderCountDay() == 0 ? 0 : result.getCostDay() / result.getOrderCountDay());
            result.setWebOrderCostHour(value2.getWebOrderCost());
            // 下单量/点击次数
            result.setOrderRateAll(result.getValidClickCountTotal() == 0 ? 0.0 : result.getOrderCountTotal() / result.getValidClickCountTotal());
            result.setOrderRateDay(isUnSameDay ? 0: result.getValidClickCountDay() == 0 ? 0.0 : result.getOrderCountDay() / result.getValidClickCountDay());
            result.setOrderRateHour(value2.getOrderRate());
            result.setOrderAmountTotal(value1.getOrderAmountTotal() + value2.getOrderAmount());
            result.setOrderAmountDay(isUnSameDay ? 0: value1.getOrderAmountDay() + value2.getOrderAmount());
            result.setOrderAmountHour(value2.getOrderAmount());
            result.setFirstDayOrderAmountTotal(value1.getFirstDayOrderAmountTotal() + value2.getFirstDayOrderAmount());
            result.setFirstDayOrderAmountDay(isUnSameDay ? 0: value1.getFirstDayOrderAmountDay() + value2.getFirstDayOrderAmount());
            result.setFirstDayOrderAmountHour(value2.getFirstDayOrderAmount());
            // 下单金额/下单量
            result.setOrderUnitPriceAll(result.getOrderCountTotal() == 0 ? 0 : result.getOrderAmountTotal() / result.getOrderCountTotal());
            result.setOrderUnitPriceDay(isUnSameDay ? 0: result.getOrderCountDay() == 0 ? 0 : result.getOrderAmountDay() / result.getOrderCountDay());
            result.setOrderUnitPriceHour(value2.getOrderUnitPrice());
            // 下单金额/广告花费
            result.setOrderRoiAll(result.getCostTotal() == 0 ? 0.0 : result.getOrderAmountTotal() / result.getCostTotal());
            result.setOrderRoiDay(isUnSameDay ? 0: result.getCostDay() == 0 ? 0.0 : result.getOrderAmountDay() / result.getCostDay());
            result.setOrderRoiHour(value2.getOrderRoi());
            result.setSignInCountTotal(value1.getSignInCountTotal() + value2.getSignInCount());
            result.setSignInCountDay(value1.getSignInCountDay() + value2.getSignInCount());
            result.setSignInCountHour(value2.getSignInCount());
            result.setScanFollowCountTotal(value1.getScanFollowCountTotal() + value2.getScanFollowCount());
            result.setScanFollowCountDay(isUnSameDay ? 0: value1.getScanFollowCountDay() + value2.getScanFollowCount());
            result.setScanFollowCountHour(value2.getScanFollowCount());
            result.setWechatAppRegisterUvTotal(value1.getWechatAppRegisterUvTotal() + value2.getWechatAppRegisterUv());
            result.setWechatAppRegisterUvDay(isUnSameDay ? 0: value1.getWechatAppRegisterUvDay() + value2.getWechatAppRegisterUv());
            result.setWechatAppRegisterUvHour(value2.getWechatAppRegisterUv());
            // 广告消耗 / 小游戏注册人数
            result.setWechatMinigameRegisterCostAll(result.getWechatAppRegisterUvTotal() == 0 ? 0 : result.getCostTotal() / result.getWechatAppRegisterUvTotal());
            result.setWechatMinigameRegisterCostDay(isUnSameDay ? 0: result.getWechatAppRegisterUvDay() == 0 ? 0 : result.getCostDay() / result.getWechatAppRegisterUvDay());
            result.setWechatMinigameRegisterCostHour(value2.getWechatMinigameRegisterCost());
            // 小游戏注册人数 / 广告点击次数
            result.setWechatMinigameRegisterRateAll(result.getValidClickCountTotal() == 0 ? 0.0 : result.getWechatAppRegisterUvTotal() / result.getValidClickCountTotal());
            result.setWechatMinigameRegisterRateDay(isUnSameDay ? 0: result.getValidClickCountDay() == 0 ? 0.0 : result.getWechatAppRegisterUvDay() / result.getValidClickCountDay());
            result.setWechatMinigameRegisterRateHour(value2.getWechatMinigameRegisterRate());
            // 总收益 / 总人数
            result.setWechatMinigameArpuAll(result.getWechatAppRegisterUvTotal() == 0 ? 0.0 : result.getOrderAmountTotal() / result.getWechatAppRegisterUvTotal());
            result.setWechatMinigameArpuDay(isUnSameDay ? 0: result.getWechatAppRegisterUvDay() == 0 ? 0.0 : result.getOrderAmountDay() / result.getWechatAppRegisterUvDay());
            result.setWechatMinigameArpuHour(value2.getWechatMinigameArpu());
            result.setWechatMinigameRetentionCountTotal(value1.getWechatMinigameRetentionCountTotal() + value2.getWechatMinigameRetentionCount());
            result.setWechatMinigameRetentionCountDay(isUnSameDay ? 0: value1.getWechatMinigameRetentionCountDay() + value2.getWechatMinigameRetentionCount());
            result.setWechatMinigameRetentionCountHour(value2.getWechatMinigameRetentionCount());
            result.setWechatMinigameCheckoutCountTotal(value1.getWechatMinigameCheckoutCountTotal() + value2.getWechatMinigameCheckoutCount());
            result.setWechatMinigameCheckoutCountDay(isUnSameDay ? 0: value1.getWechatMinigameCheckoutCountDay() + value2.getWechatMinigameCheckoutCount());
            result.setWechatMinigameCheckoutCountHour(value2.getWechatMinigameCheckoutCount());
            result.setWechatMinigameCheckoutAmountTotal(value1.getWechatMinigameCheckoutAmountTotal() + value2.getWechatMinigameCheckoutAmount());
            result.setWechatMinigameCheckoutAmountDay(isUnSameDay ? 0: value1.getWechatMinigameCheckoutAmountDay() + value2.getWechatMinigameCheckoutAmount());
            result.setWechatMinigameCheckoutAmountHour(value2.getWechatMinigameCheckoutAmount());
            result.setOfficialAccountFollowCountTotal(value1.getOfficialAccountFollowCountTotal() + value2.getOfficialAccountFollowCount());
            result.setOfficialAccountFollowCountDay(isUnSameDay ? 0: value1.getOfficialAccountFollowCountDay() + value2.getOfficialAccountFollowCount());
            result.setOfficialAccountFollowCountHour(value2.getOfficialAccountFollowCount());
            // 关注次数 / 点击次数
            result.setOfficialAccountFollowRateAll(result.getValidClickCountTotal() == 0 ? 0.0 : result.getOfficialAccountFollowCountTotal() / result.getValidClickCountTotal());
            result.setOfficialAccountFollowRateDay(isUnSameDay ? 0: result.getValidClickCountDay() == 0 ? 0.0 : result.getOfficialAccountFollowCountDay() / result.getValidClickCountDay());
            result.setOfficialAccountFollowRateHour(value2.getOfficialAccountFollowRate());
            result.setOfficialAccountRegisterUserCountTotal(value1.getOfficialAccountRegisterUserCountTotal() + value2.getOfficialAccountRegisterUserCount());
            result.setOfficialAccountRegisterUserCountDay(isUnSameDay ? 0: value1.getOfficialAccountRegisterUserCountDay() + value2.getOfficialAccountRegisterUserCount());
            result.setOfficialAccountRegisterUserCountHour(value2.getOfficialAccountRegisterUserCount());
            // 公众号内注册人数 / 公众号关注次数
            result.setOfficialAccountRegisterRateAll(result.getOfficialAccountFollowCountTotal() == 0 ? 0.0 : result.getOfficialAccountRegisterUserCountTotal() / result.getOfficialAccountFollowCountTotal());
            result.setOfficialAccountRegisterRateDay(isUnSameDay ? 0: result.getOfficialAccountFollowCountDay() == 0 ? 0.0 : result.getOfficialAccountRegisterUserCountDay() / result.getOfficialAccountFollowCountDay());
            result.setOfficialAccountRegisterRateHour(value2.getOfficialAccountRegisterRate());
            // 广告消耗 / 广告注册人数
            result.setOfficialAccountRegisterCostAll(result.getOfficialAccountRegisterUserCountTotal() == 0 ? 0 : result.getCostTotal() / result.getOfficialAccountRegisterUserCountTotal());
            result.setOfficialAccountRegisterCostDay(isUnSameDay ? 0: result.getOfficialAccountRegisterUserCountDay() == 0 ? 0 : result.getCostDay() / result.getOfficialAccountRegisterUserCountDay());
            result.setOfficialAccountRegisterCostHour(value2.getOfficialAccountRegisterCost());
            result.setOfficialAccountRegisterAmountTotal(value1.getOfficialAccountRegisterAmountTotal() + value2.getOfficialAccountRegisterAmount());
            result.setOfficialAccountRegisterAmountDay(isUnSameDay ? 0: value1.getOfficialAccountRegisterAmountDay() + value2.getOfficialAccountRegisterAmount());
            result.setOfficialAccountRegisterAmountHour(value2.getOfficialAccountRegisterAmount());
            // 注册产生的订单金额累计/广告花费
            result.setOfficialAccountRegisterRoiAll(result.getCostTotal() == 0 ? 0 : result.getOfficialAccountRegisterAmountTotal() / result.getCostTotal());
            result.setOfficialAccountRegisterRoiDay(isUnSameDay ? 0: result.getCostDay() == 0 ? 0 : result.getOfficialAccountRegisterAmountDay() / result.getCostDay());
            result.setOfficialAccountRegisterRoiHour(value2.getOfficialAccountRegisterRoi());
            result.setOfficialAccountApplyCountTotal(value1.getOfficialAccountApplyCountTotal() + value2.getOfficialAccountApplyCount());
            result.setOfficialAccountApplyCountDay(isUnSameDay ? 0: value1.getOfficialAccountApplyCountDay() + value2.getOfficialAccountApplyCount());
            result.setOfficialAccountApplyCountHour(value2.getOfficialAccountApplyCount());
            result.setOfficialAccountApplyUserCountTotal(value1.getOfficialAccountApplyUserCountTotal() + value2.getOfficialAccountApplyUserCount());
            result.setOfficialAccountApplyUserCountDay(isUnSameDay ? 0: value1.getOfficialAccountApplyUserCountDay() + value2.getOfficialAccountApplyUserCount());
            result.setOfficialAccountApplyUserCountHour(value2.getOfficialAccountApplyUserCount());
            // 公众号内填单的独立用户数/公众号关注次数
            result.setOfficialAccountApplyRateAll(result.getOfficialAccountFollowCountTotal() == 0 ? 0.0 : result.getOfficialAccountApplyUserCountTotal() / result.getOfficialAccountFollowCountTotal());
            result.setOfficialAccountApplyRateDay(isUnSameDay ? 0: result.getOfficialAccountFollowCountDay() == 0 ? 0.0 : result.getOfficialAccountApplyUserCountDay() / result.getOfficialAccountFollowCountDay());
            result.setOfficialAccountApplyRateHour(value2.getOfficialAccountApplyRate());
            // 广告花费/广告产生的填单行为数量
            result.setOfficialAccountApplyCostAll(result.getOfficialAccountApplyUserCountTotal() == 0 ? 0 : result.getCostTotal() / result.getOfficialAccountApplyUserCountTotal());
            result.setOfficialAccountApplyCostDay(isUnSameDay ? 0: result.getOfficialAccountApplyUserCountDay() == 0 ? 0 : result.getCostDay() / result.getOfficialAccountApplyUserCountDay());
            result.setOfficialAccountApplyCostHour(value2.getOfficialAccountApplyCost());
            result.setOfficialAccountApplyAmountTotal(value1.getOfficialAccountApplyAmountTotal() + value2.getOfficialAccountApplyAmount());
            result.setOfficialAccountApplyAmountDay(isUnSameDay ? 0: value1.getOfficialAccountApplyAmountDay() + value2.getOfficialAccountApplyAmount());
            result.setOfficialAccountApplyAmountHour(value2.getOfficialAccountApplyAmount());
            // 填单产生的订单金额累计/广告花费
            result.setOfficialAccountApplyRoiAll(result.getCostTotal() == 0 ? 0 : result.getOfficialAccountApplyAmountTotal() / result.getCostTotal());
            result.setOfficialAccountApplyRoiDay(isUnSameDay ? 0: result.getCostDay() == 0 ? 0 : result.getOfficialAccountApplyAmountDay() / result.getCostDay());
            result.setOfficialAccountApplyRoiHour(value2.getOfficialAccountApplyRoi());
            result.setOfficialAccountOrderCountTotal(value1.getOfficialAccountOrderCountTotal() + value2.getOfficialAccountOrderCount());
            result.setOfficialAccountOrderCountDay(isUnSameDay ? 0: value1.getOfficialAccountOrderCountDay() + value2.getOfficialAccountOrderCount());
            result.setOfficialAccountOrderCountHour(value2.getOfficialAccountOrderCount());
            result.setOfficialAccountFirstDayOrderCountTotal(value1.getOfficialAccountFirstDayOrderCountTotal() + value2.getOfficialAccountFirstDayOrderCount());
            result.setOfficialAccountFirstDayOrderCountDay(isUnSameDay ? 0: value1.getOfficialAccountFirstDayOrderCountDay() + value2.getOfficialAccountFirstDayOrderCount());
            result.setOfficialAccountFirstDayOrderCountHour(value2.getOfficialAccountFirstDayOrderCount());
            result.setOfficialAccountOrderUserCountTotal(value1.getOfficialAccountOrderUserCountTotal() + value2.getOfficialAccountOrderUserCount());
            result.setOfficialAccountOrderUserCountDay(isUnSameDay ? 0: value1.getOfficialAccountOrderUserCountDay() + value2.getOfficialAccountOrderUserCount());
            result.setOfficialAccountOrderUserCountHour(value2.getOfficialAccountOrderUserCount());
            // 公众号内下单独立用户数（UV）/公众号关注次数
            result.setOfficialAccountOrderRateAll(result.getOfficialAccountFollowCountTotal() == 0 ? 0.0 : result.getOfficialAccountOrderUserCountTotal() / result.getOfficialAccountFollowCountTotal());
            result.setOfficialAccountOrderRateDay(isUnSameDay ? 0: result.getOfficialAccountFollowCountDay() == 0 ? 0.0 : result.getOfficialAccountOrderUserCountDay() / result.getOfficialAccountFollowCountDay());
            result.setOfficialAccountOrderRateHour(value2.getOfficialAccountOrderRate());
            // 广告花费/广告产生的下单行为数量
            result.setOfficialAccountOrderCostAll(result.getOfficialAccountOrderCountTotal() == 0 ? 0 : result.getCostTotal() / result.getOfficialAccountOrderCountTotal());
            result.setOfficialAccountOrderCostDay(isUnSameDay ? 0: result.getOfficialAccountOrderCountDay() == 0 ? 0 : result.getCostDay() / result.getOfficialAccountOrderCountDay());
            result.setOfficialAccountOrderCostHour(value2.getOfficialAccountOrderCost());
            result.setOfficialAccountOrderAmountTotal(value1.getOfficialAccountOrderAmountTotal() + value2.getOfficialAccountOrderAmount());
            result.setOfficialAccountOrderAmountDay(isUnSameDay ? 0: value1.getOfficialAccountOrderAmountDay() + value2.getOfficialAccountOrderAmount());
            result.setOfficialAccountOrderAmountHour(value2.getOfficialAccountOrderAmount());
            result.setOfficialAccountFirstDayOrderAmountTotal(value1.getOfficialAccountFirstDayOrderAmountTotal() + value2.getOfficialAccountFirstDayOrderAmount());
            result.setOfficialAccountFirstDayOrderAmountDay(isUnSameDay ? 0: value1.getOfficialAccountFirstDayOrderAmountDay() + value2.getOfficialAccountFirstDayOrderAmount());
            result.setOfficialAccountFirstDayOrderAmountHour(value2.getOfficialAccountFirstDayOrderAmount());
            // 下单产生的订单金额累计/广告花费
            result.setOfficialAccountOrderRoiAll(result.getCostTotal() == 0 ? 0 : result.getOfficialAccountOrderAmountTotal() / result.getCostTotal());
            result.setOfficialAccountOrderRoiDay(isUnSameDay ? 0: result.getCostDay() == 0 ? 0 : result.getOfficialAccountOrderAmountDay() / result.getCostDay());
            result.setOfficialAccountOrderRoiHour(value2.getOfficialAccountOrderRoi());
            result.setOfficialAccountConsultCountTotal(value1.getOfficialAccountConsultCountTotal() + value2.getOfficialAccountConsultCount());
            result.setOfficialAccountConsultCountDay(isUnSameDay ? 0: value1.getOfficialAccountConsultCountDay() + value2.getOfficialAccountConsultCount());
            result.setOfficialAccountConsultCountHour(value2.getOfficialAccountConsultCount());
            result.setOfficialAccountReaderCountTotal(value1.getOfficialAccountReaderCountTotal() + value2.getOfficialAccountReaderCount());
            result.setOfficialAccountReaderCountDay(isUnSameDay ? 0: value1.getOfficialAccountReaderCountDay() + value2.getOfficialAccountReaderCount());
            result.setOfficialAccountReaderCountHour(value2.getOfficialAccountReaderCount());
            result.setOfficialAccountCreditApplyUserCountTotal(value1.getOfficialAccountCreditApplyUserCountTotal() + value2.getOfficialAccountCreditApplyUserCount());
            result.setOfficialAccountCreditApplyUserCountDay(isUnSameDay ? 0: value1.getOfficialAccountCreditApplyUserCountDay() + value2.getOfficialAccountCreditApplyUserCount());
            result.setOfficialAccountCreditApplyUserCountHour(value2.getOfficialAccountCreditApplyUserCount());
            result.setOfficialAccountCreditUserCountTotal(value1.getOfficialAccountCreditUserCountTotal() + value2.getOfficialAccountCreditUserCount());
            result.setOfficialAccountCreditUserCountDay(isUnSameDay ? 0: value1.getOfficialAccountCreditUserCountDay() + value2.getOfficialAccountCreditUserCount());
            result.setOfficialAccountCreditUserCountHour(value2.getOfficialAccountCreditUserCount());
            result.setForwardCountTotal(value1.getForwardCountTotal() + value2.getForwardCount());
            result.setForwardCountDay(isUnSameDay ? 0: value1.getForwardCountDay() + value2.getForwardCount());
            result.setForwardCountHour(value2.getForwardCount());
            result.setForwardUserCountTotal(value1.getForwardUserCountTotal() + value2.getForwardUserCount());
            result.setForwardUserCountDay(isUnSameDay ? 0: value1.getForwardUserCountDay() + value2.getForwardUserCount());
            result.setForwardUserCountHour(value2.getForwardUserCount());
            result.setNoInterestCountTotal(value1.getNoInterestCountTotal() + value2.getNoInterestCount());
            result.setNoInterestCountDay(isUnSameDay ? 0: value1.getNoInterestCountDay() + value2.getNoInterestCount());
            result.setNoInterestCountHour(value2.getNoInterestCount());
        }
        return result;
    }

    public static PlanStatOfHourDWD byMaxCompute(Record record) {
        PlanStatOfHourDWD result = new PlanStatOfHourDWD();
        result.setStatDay(ObjectUtil.toString(record.get("stat_day")));
        result.setHour(ObjectUtil.toInt(record.get("hour")));
        result.setAccountId(ObjectUtil.toLong(record.get("account_id")));
        result.setCampaignId(ObjectUtil.toLong(record.get("campaign_id")));
        result.setAgencyAccountId(ObjectUtil.toLong(record.get("agency_account_id")));
        result.setWechatAccountId(ObjectUtil.toString(record.get("wechat_account_id")));
        result.setWechatAgencyId(ObjectUtil.toString(record.get("wechat_agency_id")));

        result.setAdGroupMapStr(ObjectUtil.toString(record.get("ad_group_map_str")));
        result.setAdGroupMap(PlanUtil.parseAdGroupMapStr(result.getAdGroupMapStr()));
        result.setAdIdsStr(ObjectUtil.toString(record.get("ad_ids_str")));
        result.setAdIds(PlanUtil.parseAdStr(result.getAdIdsStr()));

        result.setCreateTime(ObjectUtil.toDate(record.get("create_time")));
        result.setCostDeviationRateTotal(ObjectUtil.toDouble(record.get("cost_deviation_rate_total")));
        result.setCostDeviationRateDay(ObjectUtil.toDouble(record.get("cost_deviation_rate_day")));
        result.setCostDeviationRateHour(ObjectUtil.toDouble(record.get("cost_deviation_rate_hour")));
        result.setCostTotal(ObjectUtil.toLong(record.get("cost_total")));
        result.setCostDay(ObjectUtil.toLong(record.get("cost_day")));
        result.setCostHour(ObjectUtil.toLong(record.get("cost_hour")));
        result.setCompensationAmountTotal(ObjectUtil.toLong(record.get("compensation_amount_total")));
        result.setCompensationAmountDay(ObjectUtil.toLong(record.get("compensation_amount_day")));
        result.setCompensationAmountHour(ObjectUtil.toLong(record.get("compensation_amount_hour")));
        result.setViewCountTotal(ObjectUtil.toLong(record.get("view_count_total")));
        result.setViewCountDay(ObjectUtil.toLong(record.get("view_count_day")));
        result.setViewCountHour(ObjectUtil.toLong(record.get("view_count_hour")));
        result.setThousandDisplayPriceAll(ObjectUtil.toLong(record.get("thousand_display_price_all")));
        result.setThousandDisplayPriceDay(ObjectUtil.toLong(record.get("thousand_display_price_day")));
        result.setThousandDisplayPriceHour(ObjectUtil.toLong(record.get("thousand_display_price_hour")));
        result.setAvgViewPerUserHour(ObjectUtil.toDouble(record.get("avg_view_per_user_hour")));
        result.setValidClickCountTotal(ObjectUtil.toLong(record.get("valid_click_count_total")));
        result.setValidClickCountDay(ObjectUtil.toLong(record.get("valid_click_count_day")));
        result.setValidClickCountHour(ObjectUtil.toLong(record.get("valid_click_count_hour")));
        result.setCtrAll(ObjectUtil.toDouble(record.get("ctr_all")));
        result.setCtrDay(ObjectUtil.toDouble(record.get("ctr_day")));
        result.setCtrHour(ObjectUtil.toDouble(record.get("ctr_hour")));
        result.setCpcAll(ObjectUtil.toLong(record.get("cpc_all")));
        result.setCpcDay(ObjectUtil.toLong(record.get("cpc_day")));
        result.setCpcHour(ObjectUtil.toLong(record.get("cpc_hour")));
        result.setValuableClickCountTotal(ObjectUtil.toLong(record.get("valuable_click_count_total")));
        result.setValuableClickCountDay(ObjectUtil.toLong(record.get("valuable_click_count_day")));
        result.setValuableClickCountHour(ObjectUtil.toLong(record.get("valuable_click_count_hour")));
        result.setValuableClickRateAll(ObjectUtil.toDouble(record.get("valuable_click_rate_all")));
        result.setValuableClickRateDay(ObjectUtil.toDouble(record.get("valuable_click_rate_day")));
        result.setValuableClickRateHour(ObjectUtil.toDouble(record.get("valuable_click_rate_hour")));
        result.setValuableClickCostAll(ObjectUtil.toLong(record.get("valuable_click_cost_all")));
        result.setValuableClickCostDay(ObjectUtil.toLong(record.get("valuable_click_cost_day")));
        result.setValuableClickCostHour(ObjectUtil.toLong(record.get("valuable_click_cost_hour")));
        result.setConversionsCountTotal(ObjectUtil.toLong(record.get("conversions_count_total")));
        result.setConversionsCountDay(ObjectUtil.toLong(record.get("conversions_count_day")));
        result.setConversionsCountHour(ObjectUtil.toLong(record.get("conversions_count_hour")));
        result.setConversionsCostAll(ObjectUtil.toLong(record.get("conversions_cost_all")));
        result.setConversionsCostDay(ObjectUtil.toLong(record.get("conversions_cost_day")));
        result.setConversionsCostHour(ObjectUtil.toLong(record.get("conversions_cost_hour")));
        result.setConversionsRateAll(ObjectUtil.toDouble(record.get("conversions_rate_all")));
        result.setConversionsRateDay(ObjectUtil.toDouble(record.get("conversions_rate_day")));
        result.setConversionsRateHour(ObjectUtil.toDouble(record.get("conversions_rate_hour")));
        result.setDeepConversionsCountTotal(ObjectUtil.toLong(record.get("deep_conversions_count_total")));
        result.setDeepConversionsCountDay(ObjectUtil.toLong(record.get("deep_conversions_count_day")));
        result.setDeepConversionsCountHour(ObjectUtil.toLong(record.get("deep_conversions_count_hour")));
        result.setDeepConversionsCostAll(ObjectUtil.toLong(record.get("deep_conversions_cost_all")));
        result.setDeepConversionsCostDay(ObjectUtil.toLong(record.get("deep_conversions_cost_day")));
        result.setDeepConversionsCostHour(ObjectUtil.toLong(record.get("deep_conversions_cost_hour")));
        result.setDeepConversionsRateAll(ObjectUtil.toDouble(record.get("deep_conversions_rate_all")));
        result.setDeepConversionsRateDay(ObjectUtil.toDouble(record.get("deep_conversions_rate_day")));
        result.setDeepConversionsRateHour(ObjectUtil.toDouble(record.get("deep_conversions_rate_hour")));
        result.setOrderCountTotal(ObjectUtil.toLong(record.get("order_count_total")));
        result.setOrderCountDay(ObjectUtil.toLong(record.get("order_count_day")));
        result.setOrderCountHour(ObjectUtil.toLong(record.get("order_count_hour")));
        result.setFirstDayOrderCountTotal(ObjectUtil.toLong(record.get("first_day_order_count_total")));
        result.setFirstDayOrderCountDay(ObjectUtil.toLong(record.get("first_day_order_count_day")));
        result.setFirstDayOrderCountHour(ObjectUtil.toLong(record.get("first_day_order_count_hour")));
        result.setWebOrderCostAll(ObjectUtil.toLong(record.get("web_order_cost_all")));
        result.setWebOrderCostDay(ObjectUtil.toLong(record.get("web_order_cost_day")));
        result.setWebOrderCostHour(ObjectUtil.toLong(record.get("web_order_cost_hour")));
        result.setOrderRateAll(ObjectUtil.toDouble(record.get("order_rate_all")));
        result.setOrderRateDay(ObjectUtil.toDouble(record.get("order_rate_day")));
        result.setOrderRateHour(ObjectUtil.toDouble(record.get("order_rate_hour")));
        result.setOrderAmountTotal(ObjectUtil.toLong(record.get("order_amount_total")));
        result.setOrderAmountDay(ObjectUtil.toLong(record.get("order_amount_day")));
        result.setOrderAmountHour(ObjectUtil.toLong(record.get("order_amount_hour")));
        result.setFirstDayOrderAmountTotal(ObjectUtil.toLong(record.get("first_day_order_amount_total")));
        result.setFirstDayOrderAmountDay(ObjectUtil.toLong(record.get("first_day_order_amount_day")));
        result.setFirstDayOrderAmountHour(ObjectUtil.toLong(record.get("first_day_order_amount_hour")));
        result.setOrderUnitPriceAll(ObjectUtil.toLong(record.get("order_unit_price_all")));
        result.setOrderUnitPriceDay(ObjectUtil.toLong(record.get("order_unit_price_day")));
        result.setOrderUnitPriceHour(ObjectUtil.toLong(record.get("order_unit_price_hour")));
        result.setOrderRoiAll(ObjectUtil.toDouble(record.get("order_roi_all")));
        result.setOrderRoiDay(ObjectUtil.toDouble(record.get("order_roi_day")));
        result.setOrderRoiHour(ObjectUtil.toDouble(record.get("order_roi_hour")));
        result.setSignInCountTotal(ObjectUtil.toLong(record.get("sign_in_count_total")));
        result.setSignInCountDay(ObjectUtil.toLong(record.get("sign_in_count_day")));
        result.setSignInCountHour(ObjectUtil.toLong(record.get("sign_in_count_hour")));
        result.setScanFollowCountTotal(ObjectUtil.toLong(record.get("scan_follow_count_total")));
        result.setScanFollowCountDay(ObjectUtil.toLong(record.get("scan_follow_count_day")));
        result.setScanFollowCountHour(ObjectUtil.toLong(record.get("scan_follow_count_hour")));
        result.setWechatAppRegisterUvTotal(ObjectUtil.toLong(record.get("wechat_app_register_uv_total")));
        result.setWechatAppRegisterUvDay(ObjectUtil.toLong(record.get("wechat_app_register_uv_day")));
        result.setWechatAppRegisterUvHour(ObjectUtil.toLong(record.get("wechat_app_register_uv_hour")));
        result.setWechatMinigameRegisterCostAll(ObjectUtil.toLong(record.get("wechat_minigame_register_cost_all")));
        result.setWechatMinigameRegisterCostDay(ObjectUtil.toLong(record.get("wechat_minigame_register_cost_day")));
        result.setWechatMinigameRegisterCostHour(ObjectUtil.toLong(record.get("wechat_minigame_register_cost_hour")));
        result.setWechatMinigameRegisterRateAll(ObjectUtil.toDouble(record.get("wechat_minigame_register_rate_all")));
        result.setWechatMinigameRegisterRateDay(ObjectUtil.toDouble(record.get("wechat_minigame_register_rate_day")));
        result.setWechatMinigameRegisterRateHour(ObjectUtil.toDouble(record.get("wechat_minigame_register_rate_hour")));
        result.setWechatMinigameArpuAll(ObjectUtil.toDouble(record.get("wechat_minigame_arpu_all")));
        result.setWechatMinigameArpuDay(ObjectUtil.toDouble(record.get("wechat_minigame_arpu_day")));
        result.setWechatMinigameArpuHour(ObjectUtil.toDouble(record.get("wechat_minigame_arpu_hour")));
        result.setWechatMinigameRetentionCountTotal(ObjectUtil.toLong(record.get("wechat_minigame_retention_count_total")));
        result.setWechatMinigameRetentionCountDay(ObjectUtil.toLong(record.get("wechat_minigame_retention_count_day")));
        result.setWechatMinigameRetentionCountHour(ObjectUtil.toLong(record.get("wechat_minigame_retention_count_hour")));
        result.setWechatMinigameCheckoutCountTotal(ObjectUtil.toLong(record.get("wechat_minigame_checkout_count_total")));
        result.setWechatMinigameCheckoutCountDay(ObjectUtil.toLong(record.get("wechat_minigame_checkout_count_day")));
        result.setWechatMinigameCheckoutCountHour(ObjectUtil.toLong(record.get("wechat_minigame_checkout_count_hour")));
        result.setWechatMinigameCheckoutAmountTotal(ObjectUtil.toLong(record.get("wechat_minigame_checkout_amount_total")));
        result.setWechatMinigameCheckoutAmountDay(ObjectUtil.toLong(record.get("wechat_minigame_checkout_amount_day")));
        result.setWechatMinigameCheckoutAmountHour(ObjectUtil.toLong(record.get("wechat_minigame_checkout_amount_hour")));
        result.setOfficialAccountFollowCountTotal(ObjectUtil.toLong(record.get("official_account_follow_count_total")));
        result.setOfficialAccountFollowCountDay(ObjectUtil.toLong(record.get("official_account_follow_count_day")));
        result.setOfficialAccountFollowCountHour(ObjectUtil.toLong(record.get("official_account_follow_count_hour")));
        result.setOfficialAccountFollowRateAll(ObjectUtil.toDouble(record.get("official_account_follow_rate_all")));
        result.setOfficialAccountFollowRateDay(ObjectUtil.toDouble(record.get("official_account_follow_rate_day")));
        result.setOfficialAccountFollowRateHour(ObjectUtil.toDouble(record.get("official_account_follow_rate_hour")));
        result.setOfficialAccountRegisterUserCountTotal(ObjectUtil.toLong(record.get("official_account_register_user_count_total")));
        result.setOfficialAccountRegisterUserCountDay(ObjectUtil.toLong(record.get("official_account_register_user_count_day")));
        result.setOfficialAccountRegisterUserCountHour(ObjectUtil.toLong(record.get("official_account_register_user_count_hour")));
        result.setOfficialAccountRegisterRateAll(ObjectUtil.toDouble(record.get("official_account_register_rate_all")));
        result.setOfficialAccountRegisterRateDay(ObjectUtil.toDouble(record.get("official_account_register_rate_day")));
        result.setOfficialAccountRegisterRateHour(ObjectUtil.toDouble(record.get("official_account_register_rate_hour")));
        result.setOfficialAccountRegisterCostAll(ObjectUtil.toLong(record.get("official_account_register_cost_all")));
        result.setOfficialAccountRegisterCostDay(ObjectUtil.toLong(record.get("official_account_register_cost_day")));
        result.setOfficialAccountRegisterCostHour(ObjectUtil.toLong(record.get("official_account_register_cost_hour")));
        result.setOfficialAccountRegisterAmountTotal(ObjectUtil.toLong(record.get("official_account_register_amount_total")));
        result.setOfficialAccountRegisterAmountDay(ObjectUtil.toLong(record.get("official_account_register_amount_day")));
        result.setOfficialAccountRegisterAmountHour(ObjectUtil.toLong(record.get("official_account_register_amount_hour")));
        result.setOfficialAccountRegisterRoiAll(ObjectUtil.toLong(record.get("official_account_register_roi_all")));
        result.setOfficialAccountRegisterRoiDay(ObjectUtil.toLong(record.get("official_account_register_roi_day")));
        result.setOfficialAccountRegisterRoiHour(ObjectUtil.toLong(record.get("official_account_register_roi_hour")));
        result.setOfficialAccountApplyCountTotal(ObjectUtil.toLong(record.get("official_account_apply_count_total")));
        result.setOfficialAccountApplyCountDay(ObjectUtil.toLong(record.get("official_account_apply_count_day")));
        result.setOfficialAccountApplyCountHour(ObjectUtil.toLong(record.get("official_account_apply_count_hour")));
        result.setOfficialAccountApplyUserCountTotal(ObjectUtil.toLong(record.get("official_account_apply_user_count_total")));
        result.setOfficialAccountApplyUserCountDay(ObjectUtil.toLong(record.get("official_account_apply_user_count_day")));
        result.setOfficialAccountApplyUserCountHour(ObjectUtil.toLong(record.get("official_account_apply_user_count_hour")));
        result.setOfficialAccountApplyRateAll(ObjectUtil.toDouble(record.get("official_account_apply_rate_all")));
        result.setOfficialAccountApplyRateDay(ObjectUtil.toDouble(record.get("official_account_apply_rate_day")));
        result.setOfficialAccountApplyRateHour(ObjectUtil.toDouble(record.get("official_account_apply_rate_hour")));
        result.setOfficialAccountApplyCostAll(ObjectUtil.toLong(record.get("official_account_apply_cost_all")));
        result.setOfficialAccountApplyCostDay(ObjectUtil.toLong(record.get("official_account_apply_cost_day")));
        result.setOfficialAccountApplyCostHour(ObjectUtil.toLong(record.get("official_account_apply_cost_hour")));
        result.setOfficialAccountApplyAmountTotal(ObjectUtil.toLong(record.get("official_account_apply_amount_total")));
        result.setOfficialAccountApplyAmountDay(ObjectUtil.toLong(record.get("official_account_apply_amount_day")));
        result.setOfficialAccountApplyAmountHour(ObjectUtil.toLong(record.get("official_account_apply_amount_hour")));
        result.setOfficialAccountApplyRoiAll(ObjectUtil.toLong(record.get("official_account_apply_roi_all")));
        result.setOfficialAccountApplyRoiDay(ObjectUtil.toLong(record.get("official_account_apply_roi_day")));
        result.setOfficialAccountApplyRoiHour(ObjectUtil.toLong(record.get("official_account_apply_roi_hour")));
        result.setOfficialAccountOrderCountTotal(ObjectUtil.toLong(record.get("official_account_order_count_total")));
        result.setOfficialAccountOrderCountDay(ObjectUtil.toLong(record.get("official_account_order_count_day")));
        result.setOfficialAccountOrderCountHour(ObjectUtil.toLong(record.get("official_account_order_count_hour")));
        result.setOfficialAccountFirstDayOrderCountTotal(ObjectUtil.toLong(record.get("official_account_first_day_order_count_total")));
        result.setOfficialAccountFirstDayOrderCountDay(ObjectUtil.toLong(record.get("official_account_first_day_order_count_day")));
        result.setOfficialAccountFirstDayOrderCountHour(ObjectUtil.toLong(record.get("official_account_first_day_order_count_hour")));
        result.setOfficialAccountOrderUserCountTotal(ObjectUtil.toLong(record.get("official_account_order_user_count_total")));
        result.setOfficialAccountOrderUserCountDay(ObjectUtil.toLong(record.get("official_account_order_user_count_day")));
        result.setOfficialAccountOrderUserCountHour(ObjectUtil.toLong(record.get("official_account_order_user_count_hour")));
        result.setOfficialAccountOrderRateAll(ObjectUtil.toDouble(record.get("official_account_order_rate_all")));
        result.setOfficialAccountOrderRateDay(ObjectUtil.toDouble(record.get("official_account_order_rate_day")));
        result.setOfficialAccountOrderRateHour(ObjectUtil.toDouble(record.get("official_account_order_rate_hour")));
        result.setOfficialAccountOrderCostAll(ObjectUtil.toLong(record.get("official_account_order_cost_all")));
        result.setOfficialAccountOrderCostDay(ObjectUtil.toLong(record.get("official_account_order_cost_day")));
        result.setOfficialAccountOrderCostHour(ObjectUtil.toLong(record.get("official_account_order_cost_hour")));
        result.setOfficialAccountOrderAmountTotal(ObjectUtil.toLong(record.get("official_account_order_amount_total")));
        result.setOfficialAccountOrderAmountDay(ObjectUtil.toLong(record.get("official_account_order_amount_day")));
        result.setOfficialAccountOrderAmountHour(ObjectUtil.toLong(record.get("official_account_order_amount_hour")));
        result.setOfficialAccountFirstDayOrderAmountTotal(ObjectUtil.toLong(record.get("official_account_first_day_order_amount_total")));
        result.setOfficialAccountFirstDayOrderAmountDay(ObjectUtil.toLong(record.get("official_account_first_day_order_amount_day")));
        result.setOfficialAccountFirstDayOrderAmountHour(ObjectUtil.toLong(record.get("official_account_first_day_order_amount_hour")));
        result.setOfficialAccountOrderRoiAll(ObjectUtil.toLong(record.get("official_account_order_roi_all")));
        result.setOfficialAccountOrderRoiDay(ObjectUtil.toLong(record.get("official_account_order_roi_day")));
        result.setOfficialAccountOrderRoiHour(ObjectUtil.toLong(record.get("official_account_order_roi_hour")));
        result.setOfficialAccountConsultCountTotal(ObjectUtil.toLong(record.get("official_account_consult_count_total")));
        result.setOfficialAccountConsultCountDay(ObjectUtil.toLong(record.get("official_account_consult_count_day")));
        result.setOfficialAccountConsultCountHour(ObjectUtil.toLong(record.get("official_account_consult_count_hour")));
        result.setOfficialAccountReaderCountTotal(ObjectUtil.toLong(record.get("official_account_reader_count_total")));
        result.setOfficialAccountReaderCountDay(ObjectUtil.toLong(record.get("official_account_reader_count_day")));
        result.setOfficialAccountReaderCountHour(ObjectUtil.toLong(record.get("official_account_reader_count_hour")));
        result.setOfficialAccountCreditApplyUserCountTotal(ObjectUtil.toLong(record.get("official_account_credit_apply_user_count_total")));
        result.setOfficialAccountCreditApplyUserCountDay(ObjectUtil.toLong(record.get("official_account_credit_apply_user_count_day")));
        result.setOfficialAccountCreditApplyUserCountHour(ObjectUtil.toLong(record.get("official_account_credit_apply_user_count_hour")));
        result.setOfficialAccountCreditUserCountTotal(ObjectUtil.toLong(record.get("official_account_credit_user_count_total")));
        result.setOfficialAccountCreditUserCountDay(ObjectUtil.toLong(record.get("official_account_credit_user_count_day")));
        result.setOfficialAccountCreditUserCountHour(ObjectUtil.toLong(record.get("official_account_credit_user_count_hour")));
        result.setForwardCountTotal(ObjectUtil.toLong(record.get("forward_count_total")));
        result.setForwardCountDay(ObjectUtil.toLong(record.get("forward_count_day")));
        result.setForwardCountHour(ObjectUtil.toLong(record.get("forward_count_hour")));
        result.setForwardUserCountTotal(ObjectUtil.toLong(record.get("forward_user_count_total")));
        result.setForwardUserCountDay(ObjectUtil.toLong(record.get("forward_user_count_day")));
        result.setForwardUserCountHour(ObjectUtil.toLong(record.get("forward_user_count_hour")));
        result.setNoInterestCountTotal(ObjectUtil.toLong(record.get("no_interest_count_total")));
        result.setNoInterestCountDay(ObjectUtil.toLong(record.get("no_interest_count_day")));
        result.setNoInterestCountHour(ObjectUtil.toLong(record.get("no_interest_count_hour")));
        return result;
    }
}
